<?php
namespace Adminer;

Lang::$translations = array(
	'Login' => 'Intră',
	'Logout successful.' => 'Ați ieșit cu succes.',
	'Invalid credentials.' => 'Numele de utilizator sau parola este greșită.',
	'Server' => 'Server',
	'Username' => 'Nume de utilizator',
	'Password' => 'Parola',
	'Select database' => 'Alege baza de date',
	'Invalid database.' => 'Bază de deate invalidă.',
	'Table has been dropped.' => 'Tabelul a fost șters.',
	'Table has been altered.' => 'Tabelul a fost modificat.',
	'Table has been created.' => 'Tabelul a fost creat.',
	'Alter table' => 'Modifică tabelul',
	'Create table' => 'Crează tabel',
	'Table name' => 'Denumirea tabelului',
	'engine' => 'tip',
	'collation' => 'colaționarea',
	'Column name' => 'Denumirea coloanei',
	'Type' => 'Tip',
	'Length' => 'Lungime',
	'Auto Increment' => 'Creșterea automată',
	'Options' => 'Acțiune',
	'Save' => 'Salvează',
	'Drop' => 'Șterge',
	'Database has been dropped.' => 'Baza de date a fost ștearsă.',
	'Database has been created.' => 'Baza de date a fost creată.',
	'Database has been renamed.' => 'Baza de date a fost redenumită.',
	'Database has been altered.' => 'Baza de date a fost modificată.',
	'Alter database' => 'Modifică baza de date',
	'Create database' => 'Crează baza de date',
	'SQL command' => 'SQL query',
	'Logout' => 'Ieșire',
	'Use' => 'Alege',
	'No tables.' => 'În baza de date nu sunt tabele.',
	'select' => 'selectează',
	'Item has been deleted.' => 'Înregistrare a fost ștearsă.',
	'Item has been updated.' => 'Înregistrare a fost înnoită.',
	'Item%s has been inserted.' => 'Înregistrarea%s a fost inserată.',
	'Edit' => 'Editează',
	'Insert' => 'Inserează',
	'Save and insert next' => 'Salvează și mai inserează',
	'Delete' => 'Șterge',
	'Database' => 'Baza de date',
	'Routines' => 'Proceduri și funcții salvate',
	'Indexes have been altered.' => 'Indexurile au fost modificate.',
	'Indexes' => 'Indexuri',
	'Alter indexes' => 'Modifică indexuri',
	'Add next' => 'Adaugă încă',
	'Language' => 'Limba',
	'Select' => 'Selectează',
	'New item' => 'Înscriere nouă',
	'Search' => 'Căutare',
	'Sort' => 'Sortare',
	'descending' => 'descrescător',
	'Limit' => 'Limit',
	'No rows.' => 'Nu sunt înscrieri.',
	'Action' => 'Acțiune',
	'edit' => 'editare',
	'Page' => 'Pagina',
	'Query executed OK, %d row(s) affected.' => array('Query executat, %d înscriere modificată.', 'Query executat, %d înscrieri modificate.'),
	'Error in query' => 'Greșeală în query',
	'Execute' => 'Execută',
	'Table' => 'Tabel',
	'Foreign keys' => 'Chei externe',
	'Triggers' => 'Declanșatoare',
	'View' => 'Reprezentare',
	'Unable to select the table' => 'Nu am putut selecta date din tabel',
	'Invalid CSRF token. Send the form again.' => 'CSRF token imposibil. Retrimite forma.',
	'Comment' => 'Comentariu',
	'Default values' => 'Valoarea inițială',
	'%d byte(s)' => array('%d octet', '%d octeți'),
	'No commands to execute.' => 'Nu sunt comenzi de executat.',
	'Unable to upload a file.' => 'Nu am putut încărca fișierul pe server.',
	'File upload' => 'Încarcă fișierul',
	'File uploads are disabled.' => 'Încărcarea fișierelor este interzisă.',
	'Routine has been called, %d row(s) affected.' => array('A fost executată procedura, %d înscriere a fost modificată.', 'A fost executată procedura, %d înscrieri au fost modificate.'),
	'Call' => 'Apelează',
	'No extension' => 'Nu este extensie',
	'None of the supported PHP extensions (%s) are available.' => 'Nu este aviabilă nici o extensie suportată (%s).',
	'Session support must be enabled.' => 'Sesiunile trebuie să fie pornite.',
	'Session expired, please login again.' => 'Timpul sesiunii a expirat, rog să vă conectați din nou.',
	'Text length' => 'Lungimea textului',
	'Foreign key has been dropped.' => 'Cheia externă a fost ștearsă.',
	'Foreign key has been altered.' => 'Cheia externă a fost modificată.',
	'Foreign key has been created.' => 'Cheia externă a fost creată.',
	'Foreign key' => 'Cheie externă',
	'Target table' => 'Tabela scop',
	'Change' => 'Modifică',
	'Source' => 'Sursă',
	'Target' => 'Scop',
	'Add column' => 'Adaugă coloană',
	'Alter' => 'Modifică',
	'Add foreign key' => 'Adaugă cheie externă',
	'ON DELETE' => 'La ștergere',
	'ON UPDATE' => 'La modificare',
	'Index Type' => 'Tipul indexului',
	'length' => 'lungimea',
	'View has been dropped.' => 'Reprezentarea a fost ștearsă.',
	'View has been altered.' => 'Reprezentarea a fost modificată.',
	'View has been created.' => 'Reprezentarea a fost creată.',
	'Alter view' => 'Modifică reprezentarea',
	'Create view' => 'Crează reprezentare',
	'Name' => 'Titlu',
	'Process list' => 'Lista proceselor',
	'%d process(es) have been killed.' => array('A fost terminat %d proces.', 'Au fost terminate %d procese.'),
	'Kill' => 'Termină',
	'Parameter name' => 'Numele parametrului',
	'Database schema' => 'Schema bazei de date',
	'Create procedure' => 'Crează procedură',
	'Create function' => 'Crează funcție',
	'Routine has been dropped.' => 'Procedura a fost ștearsă.',
	'Routine has been altered.' => 'Procedura a fost modificată.',
	'Routine has been created.' => 'Procedura a fost creată.',
	'Alter function' => 'Modifică funcția',
	'Alter procedure' => 'Modifică procedura',
	'Return type' => 'Tipul returnării',
	'Add trigger' => 'Adaugă trigger (declanșator)',
	'Trigger has been dropped.' => 'Triggerul a fost șters.',
	'Trigger has been altered.' => 'Triggerul a fost modificat.',
	'Trigger has been created.' => 'Triggerul a fost creat.',
	'Alter trigger' => 'Modifică trigger',
	'Create trigger' => 'Crează trigger',
	'Time' => 'Timp',
	'Event' => 'Eveniment',
	'%s version: %s through PHP extension %s' => 'Versiunea %s: %s cu extensia PHP %s',
	'%d row(s)' => array('%d înscriere', '%d înscrieri'),
	'Remove' => 'Șterge',
	'Are you sure?' => 'Sunteți sigur(ă)?',
	'Privileges' => 'Privilegii',
	'Create user' => 'Crează utilizator',
	'User has been dropped.' => 'Utilizatorul a fost șters.',
	'User has been altered.' => 'Utilizatorul a fost modificat.',
	'User has been created.' => 'Utilizatorul a fost creat.',
	'Hashed' => 'Hashed',
	'Column' => 'Coloană',
	'Routine' => 'Procedură',
	'Grant' => 'Permite',
	'Revoke' => 'Interzice',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Mesajul POST este prea mare. Trimiteți mai puține date sau măriți parametrul configurației directivei %s.',
	'Logged as: %s' => 'Ați intrat ca: %s',
	'Move up' => 'Mișcă în sus',
	'Move down' => 'Mișcă în jos',
	'Functions' => 'Funcții',
	'Aggregation' => 'Agregare',
	'Export' => 'Export',
	'Output' => 'Date de ieșire',
	'open' => 'deschide',
	'save' => 'salvează',
	'Format' => 'Format',
	'Tables' => 'Tabele',
	'Data' => 'Date',
	'Event has been dropped.' => 'Evenimentul a fost șters.',
	'Event has been altered.' => 'Evenimentul a fost modificat.',
	'Event has been created.' => 'Evenimentul a fost adăugat.',
	'Alter event' => 'Modifică eveniment',
	'Create event' => 'Creează evenimet',
	'At given time' => 'În timpul curent',
	'Every' => 'Fiecare',
	'Events' => 'Evenimente',
	'Schedule' => 'Program',
	'Start' => 'Început',
	'End' => 'Sfârșit',
	'Status' => 'Stare',
	'On completion preserve' => 'Salvează după finisare',
	'Tables and views' => 'Tabele și reprezentări',
	'Data Length' => 'Cantitatea de date',
	'Index Length' => 'Cantitatea de indecși',
	'Data Free' => 'Spațiu liber',
	'Collation' => 'Colaționare',
	'Analyze' => 'Analizează',
	'Optimize' => 'Optimizează',
	'Check' => 'Controlează',
	'Repair' => 'Repară',
	'Truncate' => 'Curăță',
	'Tables have been truncated.' => 'Tabelele au fost curățate.',
	'Rows' => 'Înscrieri',
	',' => ',',
	'0123456789' => '0123456789',
	'Tables have been moved.' => 'Tabelele au fost mutate.',
	'Move to other database' => 'Mută în altă bază de date',
	'Move' => 'Mută',
	'Engine' => 'Tip',
	'Save and continue edit' => 'Salvează și continuă editarea',
	'original' => 'original',
	'%d item(s) have been affected.' => array('A fost modificată %d înscriere.', 'Au fost modificate %d înscrieri.'),
	'Whole result' => 'Tot rezultatul',
	'Tables have been dropped.' => 'Tabelele au fost șterse.',
	'Clone' => 'Clonează',
	'Partition by' => 'Împarte',
	'Partitions' => 'Secțiuni',
	'Partition name' => 'Denumirea secțiunii',
	'Values' => 'Parametru',
	'%d row(s) have been imported.' => array('%d rînd importat.', '%d rînduri importate.'),
	'Import' => 'Importă',
	'Stop on error' => 'Se oprește la greșeală',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Numărul maxim de înscrieri disponibile a fost atins. Majorați %s.',
	'anywhere' => 'oriunde',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5.$3.$1',
	'[yyyy]-mm-dd' => 'dd.mm.[yyyy]',
	'History' => 'Istoria',
	'Variables' => 'Variabile',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Coloanele ar trebui să aibă aceleaşi tipuri de date, trebuie să existe date de referinţă și un index pe coloanela-ţintă.',
	'Relations' => 'Relații',
	'Run file' => 'Execută fișier',
	'Clear' => 'Curăță',
	'Maximum allowed file size is %sB.' => 'Fișierul maxim admis - %sO.',
	'Numbers' => 'Număr',
	'Date and time' => 'Data și timpul',
	'Strings' => 'Șiruri de caractere',
	'Binary' => 'Tip binar',
	'Lists' => 'Liste',
	'Editor' => 'Editor',
	'Webserver file %s' => 'Fișierul %s pe server',
	'File does not exist.' => 'Acest fișier nu există.',
	'%d in total' => 'În total %d',
	'Permanent login' => 'Logare permanentă',
	'Databases have been dropped.' => 'Bazele de date au fost șterse.',
	'Search data in tables' => 'Caută în tabele',
	'Schema' => 'Schema',
	'Alter schema' => 'Modifică schema',
	'Create schema' => 'Crează o schemă',
	'Schema has been dropped.' => 'Schema a fost ștearsă.',
	'Schema has been created.' => 'Schema a fost creată.',
	'Schema has been altered.' => 'Schema a fost modificată.',
	'Sequences' => '«Secvențe»',
	'Create sequence' => 'Crează «secvență»',
	'Alter sequence' => 'Modifică «secvență»',
	'Sequence has been dropped.' => '«secvența» a fost ștearsă.',
	'Sequence has been created.' => '«secvența» a fost creată.',
	'Sequence has been altered.' => '«secvența» a fost modificată.',
	'User types' => 'Tipuri de utilizatori',
	'Create type' => 'Crează tip noi',
	'Alter type' => 'Modifică tip',
	'Type has been dropped.' => 'Tiipul a fost șters.',
	'Type has been created.' => 'Crează tip nou.',
	'Ctrl+click on a value to modify it.' => 'Ctrl+click pe o valoare pentru a o modifica.',
	'Use edit link to modify this value.' => 'Valoare poate fi modificată cu ajutorul butonului «modifică».',
	'last' => 'ultima',
	'From server' => 'De pe server',
	'System' => 'Sistem',
	'Select data' => 'Selectează',
	'Show structure' => 'Arată structura',
	'empty' => 'gol',
	'Network' => 'Rețea',
	'Geometry' => 'Geometrie',
	'File exists.' => 'Fișierul există deja.',
	'%d query(s) executed OK.' => array('%d query executat.', '%d query-uri executate cu succes.'),
	'Show only errors' => 'Arată doar greșeli',
	'Refresh' => 'Împrospătează',
	'Invalid schema.' => 'Schemă incorectă.',
	'Please use one of the extensions %s.' => 'Folosiți una din următoarele extensii %s.',
	'now' => 'acum',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'Tabelele au fost copiate.',
	'Copy' => 'Copiază',
	'Permanent link' => 'Adresă permanentă',
	'Edit all' => 'Editează tot',
	'HH:MM:SS' => 'HH:MM:SS',
);

// run `php ../../lang.php ro` to update this file
