<?php
namespace Adminer;

Lang::$translations = array(
	'Login' => 'Ieiet',
	'Logout successful.' => 'Jūs veiksmīgi izgājāt no sistēmas.',
	'Invalid credentials.' => 'Nepareizs lietotāja vārds vai parole.',
	'Server' => 'Serveris',
	'Username' => 'Lietotājs',
	'Password' => 'Parole',
	'Select database' => 'Izvēlēties datubāzi',
	'Invalid database.' => 'Nederīga datubāze.',
	'Table has been dropped.' => 'Tabula dzēsta.',
	'Table has been altered.' => 'Tabula mainīta.',
	'Table has been created.' => 'Tabula izveidota.',
	'Alter table' => 'Mainīt tabulu',
	'Create table' => 'Izveidot tabulu',
	'Table name' => 'Tabulas nosaukums',
	'engine' => 'Tabulas tips',
	'collation' => 'Kolācija',
	'Column name' => 'Lauka nosaukums',
	'Type' => 'Tips',
	'Length' => 'Garums',
	'Auto Increment' => 'Auto inkrements',
	'Options' => 'Opcijas',
	'Save' => 'Saglabāt',
	'Drop' => 'Dzēst',
	'Database has been dropped.' => 'Datubāze tika nodzēsta.',
	'Database has been created.' => 'Datubāze tika izveidota.',
	'Database has been renamed.' => 'Datubāze tika pārsaukta.',
	'Database has been altered.' => 'Datubāze tika mainīta.',
	'Alter database' => 'Mainīt datubāzi',
	'Create database' => 'Izveidot datubāzi',
	'SQL command' => 'SQL pieprasījums',
	'Logout' => 'Iziet',
	'Use' => 'Lietot',
	'No tables.' => 'Datubāzē nav tabulu.',
	'select' => 'izvēlēties',
	'Item has been deleted.' => 'Ieraksts dzests.',
	'Item has been updated.' => 'Ieraksts atjaunots.',
	'Item%s has been inserted.' => 'Ieraksti%s tika ievietoti.',
	'Edit' => 'Rediģēt',
	'Insert' => 'Ievietot',
	'Save and insert next' => 'Saglabāt un ievietot nākamo',
	'Delete' => 'Dzēst',
	'Database' => 'Datubāze',
	'Routines' => 'Procedūras un funkcijas',
	'Indexes have been altered.' => 'Indeksi mainīti.',
	'Indexes' => 'Indeksi',
	'Alter indexes' => 'Izmainīt indeksus',
	'Add next' => 'Pievienot vēl',
	'Language' => 'Valoda',
	'Select' => 'Izvēlēties',
	'New item' => 'Jauns ieraksts',
	'Search' => 'Meklēšana',
	'Sort' => 'Kārtošana',
	'descending' => 'dilstoši',
	'Limit' => 'Limits',
	'No rows.' => 'Nav rindu.',
	'Action' => 'Darbība',
	'edit' => 'rediģēt',
	'Page' => 'Lapa',
	'Query executed OK, %d row(s) affected.' => array('Pieprasījums pabeigts, izmainīts %d ieraksts.', 'Pieprasījums pabeigts, izmainīti %d ieraksti.', 'Pieprasījums pabeigts, izmainīti %d ieraksti.'),
	'Error in query' => 'Kļūda pieprasījumā',
	'Execute' => 'Izpidīt',
	'Table' => 'Tabula',
	'Foreign keys' => 'Ārejā atslēgas',
	'Triggers' => 'Trigeri',
	'View' => 'Skats',
	'Unable to select the table' => 'Tabula nav pieejama',
	'Invalid CSRF token. Send the form again.' => 'Nederīgs CSRF žetons. Nosūtiet formu vēl vienu reizi.',
	'Comment' => 'Komentārs',
	'Default values' => 'Noklusētā vērtība',
	'%d byte(s)' => array('%d baits', '%d baiti', '%d baiti'),
	'No commands to execute.' => 'Nav izpildāmu komandu.',
	'Unable to upload a file.' => 'Neizdevās ielādēt failu uz servera.',
	'File upload' => 'Augšupielāde',
	'File uploads are disabled.' => 'Augšupielādes aizliegtas.',
	'Routine has been called, %d row(s) affected.' => array('Procedūra izsaukta, izmainīts %d ieraksts.', 'Procedūra izsaukta, izmainīti %d ieraksti.', 'Procedūra izsaukta, izmainīti %d ieraksti.'),
	'Call' => 'Izsaukt',
	'No extension' => 'Nav paplašinājuma',
	'None of the supported PHP extensions (%s) are available.' => 'Neviens PHP no atbalstītajiem paplašinājumiem (%s) nav pieejams.',
	'Session support must be enabled.' => 'Sesiju atbalstam jābūt ieslēgtam.',
	'Session expired, please login again.' => 'Sesijas laiks ir beidzies, piesakies no jauna sistēmā.',
	'Text length' => 'Teksta garums',
	'Foreign key has been dropped.' => 'Ārejā atslēga dzēsta.',
	'Foreign key has been altered.' => 'Ārejā atslēga izmainīta.',
	'Foreign key has been created.' => 'Ārejā atslēga izveidota.',
	'Foreign key' => 'Ārejā atslēga',
	'Target table' => 'Mērķa tabula',
	'Change' => 'Mainīt',
	'Source' => 'Avots',
	'Target' => 'Mērķis',
	'Add column' => 'Pievienot lauku',
	'Alter' => 'Izmainīt',
	'Add foreign key' => 'Pievienot ārējo atslēgu',
	'ON DELETE' => 'Pie dzēšanas',
	'ON UPDATE' => 'Pie atjaunošanas',
	'Index Type' => 'Indeksa tips',
	'length' => 'garums',
	'View has been dropped.' => 'Skats dzēsts.',
	'View has been altered.' => 'Skats izmainīts.',
	'View has been created.' => 'Skats izveidots.',
	'Alter view' => 'Izmainīt skatu',
	'Create view' => 'Izveidot skatu',
	'Name' => 'Nosaukums',
	'Process list' => 'Procesu saraksts',
	'%d process(es) have been killed.' => array('Pabeigts %d process.', 'Pabeigti %d procesi.', 'Pabeigti %d procesi.'),
	'Kill' => 'Nobeigt',
	'Parameter name' => 'Parametra nosaukums',
	'Database schema' => 'Datubāzes shēma',
	'Create procedure' => 'Izveidot procedūru',
	'Create function' => 'Izveidot funkciju',
	'Routine has been dropped.' => 'Procedūru dzēsta.',
	'Routine has been altered.' => 'Procedūru izmainīta.',
	'Routine has been created.' => 'Procedūru izveidota.',
	'Alter function' => 'Mainīt funkciju',
	'Alter procedure' => 'Mainīt procedūru',
	'Return type' => 'Atgriezt tips',
	'Add trigger' => 'Pievienot trigeri',
	'Trigger has been dropped.' => 'Trigeris dzēsts.',
	'Trigger has been altered.' => 'Trigeris izmainīts.',
	'Trigger has been created.' => 'Trigeris izveidots.',
	'Alter trigger' => 'Izmainīt trigeri',
	'Create trigger' => 'Izveidot trigeri',
	'Time' => 'Laiks',
	'Event' => 'Notikums',
	'%s version: %s through PHP extension %s' => 'Versija %s: %s ar PHP paplašinājumu %s',
	'%d row(s)' => array('%d rinda', '%d rindas', '%d rindu'),
	'Remove' => 'Noņemt',
	'Are you sure?' => 'Vai Tu esi pārliecināts?',
	'Privileges' => 'Tiesības',
	'Create user' => 'Izveidot lietotāju',
	'User has been dropped.' => 'Lietotājs dzests.',
	'User has been altered.' => 'Lietotājs izmainīts.',
	'User has been created.' => 'Lietotājs izveidots.',
	'Hashed' => 'Sajaukts',
	'Column' => 'Lauks',
	'Routine' => 'Procedūra',
	'Grant' => 'Atļaut',
	'Revoke' => 'Aizliegt',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST metodes pieprasījums apjoms par lielu. Atsūtiet mazāka apjoma pieprasījumu kā konfigurācijas %s.',
	'Logged as: %s' => 'Ielogojies kā: %s',
	'Move up' => 'Pārvietot uz augšu',
	'Move down' => 'Pārvietot uz leju',
	'Functions' => 'Funkcijas',
	'Aggregation' => 'Agregācija',
	'Export' => 'Eksports',
	'Output' => 'Izejas dati',
	'open' => 'atvērt',
	'save' => 'saglabāt',
	'Format' => 'Formāts',
	'Tables' => 'Tabulas',
	'Data' => 'Dati',
	'Event has been dropped.' => 'Notikums dzēsts.',
	'Event has been altered.' => 'Notikums izmainīts.',
	'Event has been created.' => 'Notikums izveidots.',
	'Alter event' => 'Izmainīt notikumu',
	'Create event' => 'Izveidot notikumu',
	'At given time' => 'Norāditā laikā',
	'Every' => 'Katru',
	'Events' => 'Notikumi',
	'Schedule' => 'Grafiks',
	'Start' => 'Sākums',
	'End' => 'Beigas',
	'Status' => 'Statuss',
	'On completion preserve' => 'Beigās saglabāt',
	'Tables and views' => 'Tabulas un skati',
	'Data Length' => 'Datu apjoms',
	'Index Length' => 'Indeksu izmērs',
	'Data Free' => 'Brīvā vieta',
	'Collation' => 'Kolācija',
	'Analyze' => 'Analizēt',
	'Optimize' => 'Optimizēt',
	'Check' => 'Pārbaudīt',
	'Repair' => 'Salabot',
	'Truncate' => 'Iztīrīt',
	'Tables have been truncated.' => 'Tabulas iztīrītas.',
	'Rows' => 'Rindas',
	',' => ' ',
	'0123456789' => '0123456789',
	'Tables have been moved.' => 'Tabulas pārvietotas.',
	'Move to other database' => 'Pārvietot uz citu datubāzi',
	'Move' => 'Pārvietot',
	'Engine' => 'Dzinējs',
	'Save and continue edit' => 'Saglabāt un turpināt rediģēt',
	'original' => 'oriģināls',
	'%d item(s) have been affected.' => array('Izmainīts %d ieraksts.', 'Izmainīti %d ieraksti.', 'Izmainīti %d ieraksti.'),
	'Whole result' => 'Viss rezultāts',
	'Tables have been dropped.' => 'Tabulas dzēstas.',
	'Clone' => 'Klonēt',
	'Partition by' => 'Sadalīt pēc',
	'Partitions' => 'Partīcijas',
	'Partition name' => 'Partīcijas nosaukums',
	'Values' => 'Vērtības',
	'%d row(s) have been imported.' => array('Importēta %d rinda.', 'Importētas %d rindas.', 'Importētas %d rindas.'),
	'Import' => 'Imports',
	'Stop on error' => 'Astāties kļūdas gadījumā',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Sasniegts maksimālais lauku skaita ierobežojums. Palieliniet %s.',
	'anywhere' => 'jebkurā vietā',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5.$3.$1',
	'[yyyy]-mm-dd' => 'dd.mm.[gggg]',
	'History' => 'Vēsture',
	'Variables' => 'Mainīgie',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Lauku tipiem jābūt vienādiem, rezultējošā laukā jābut indeksa datiem.',
	'Relations' => 'Relācijas',
	'Run file' => 'Izpildīt failu',
	'Clear' => 'Notīrīt',
	'Maximum allowed file size is %sB.' => 'Faila maksimālais izmērs — %sB.',
	'Numbers' => 'Skaitļi',
	'Date and time' => 'Datums un laiks',
	'Strings' => 'Virknes',
	'Binary' => 'Binārie',
	'Lists' => 'Saraksti',
	'Editor' => 'Redaktors',
	'Webserver file %s' => 'Fails %s uz servera',
	'File does not exist.' => 'Fails neeksistē.',
	'%d in total' => 'Kopā %d',
	'Permanent login' => 'Atcerēties mani',
	'Databases have been dropped.' => 'Datubāzes dzēstas.',
	'Search data in tables' => 'Meklēt tabulās',
	'Schema' => 'Shēma',
	'Alter schema' => 'Izmainīt shēmu',
	'Create schema' => 'Jauna shēma',
	'Schema has been dropped.' => 'Shēma dzēsta.',
	'Schema has been created.' => 'Izveidota jauna shēma.',
	'Schema has been altered.' => 'Shēma izmainīta.',
	'Sequences' => 'Virknes',
	'Create sequence' => 'Izveidot virkni',
	'Alter sequence' => 'Izmainīt virkni',
	'Sequence has been dropped.' => 'Virkne dzēsta.',
	'Sequence has been created.' => 'Izveidota virkne.',
	'Sequence has been altered.' => 'Virkne izmainīta.',
	'User types' => 'Lietotāju tipi',
	'Create type' => 'Izveidot tipu',
	'Alter type' => 'Izmainīt tipu',
	'Type has been dropped.' => 'Tips dzēsts.',
	'Type has been created.' => 'Tips izveidots.',
	'Ctrl+click on a value to modify it.' => 'Lai izmainītu vērtību, izmanto Ctrl + peles klikšķi.',
	'Use edit link to modify this value.' => 'Izmainīt vērtību var tikai ar saiti \'Izmainīt\'.',
	'last' => 'pēdējā',
	'From server' => 'No servera',
	'System' => 'Sistēma',
	'Select data' => 'Izvēlēties datus',
	'Show structure' => 'Parādīt struktūru',
	'empty' => 'tukšs',
	'Network' => 'Tīkls',
	'Geometry' => 'Ģeometrija',
	'File exists.' => 'Fails eksistē.',
	'%d query(s) executed OK.' => array('%d pieprasījums veiksmīgs.', '%d pieprasījumi veiksmīgi.', '%d pieprasījumi veiksmīgi.'),
	'Show only errors' => 'Rādīt tikai kļūdas',
	'Refresh' => 'Atjaunot',
	'Invalid schema.' => 'Nederīga shēma.',
	'Please use one of the extensions %s.' => 'Izmainojiet kādu no paplašinājumiem %s.',
	'now' => 'tagad',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'Tabulas nokopētas.',
	'Copy' => 'kopēt',
	'Permanent link' => 'Pastāvīga saite',
	'Edit all' => 'Rediģēt visus',
	'HH:MM:SS' => 'HH:MM:SS',
	'Tables have been optimized.' => 'Tabulas optimizētas.',
	'Materialized view' => 'Matrializēts skats',
	'Vacuum' => 'Vakums',
	'Selected' => 'Izvēlētie',
	'File must be in UTF-8 encoding.' => 'Failam jābūt UTF-8 kodējumam.',
	'Modify' => 'Izmainīt',
	'Loading' => 'Ielāde',
	'Load more data' => 'Ielādēt vēl datus',
	'ATTACH queries are not supported.' => 'ATTACH-pieprasījumi nav atbalstīti.',
	'%d / ' => '%d / ',
	'Limit rows' => 'Rindu limits',
	'Default value' => 'Noklusētā vērtība',
	'Full table scan' => 'Pilna tabulas analīze',
	'Too many unsuccessful logins, try again in %d minute(s).' => array('Pieteikšanās mēģinājumu skaits par lielu. Mēginiet pēc %d minūtes.', 'Pieteikšanās mēģinājumu skaits par lielu. Mēginiet pēc %d minūtēm.', 'Pieteikšanās mēģinājumu skaits par lielu. Mēginiet pēc %d minūtēm.'),
	'Master password expired. <a href="https://www.adminer.org/en/extension/"%s>Implement</a> %s method to make it permanent.' => 'Master-parole nav derīga. <a href="https://www.adminer.org/en/extension/"%s>Implementējiet</a> metodi %s, lai padarīgu šo par ierastu metodi.',
	'If you did not send this request from Adminer then close this page.' => 'Ja nesūtījāt šo pieprasījumu no Adminer, tad aizveriet pārlūka logu.',
	'You can upload a big SQL file via FTP and import it from server.' => 'Varat ielādēt lielu SQL failu uz servera un tad importēt to.',
	'Size' => 'Izmērs',
	'Compute' => 'Izskaitļot',
	'You are offline.' => 'Jūs est bezsasaistē.',
	'You have no privileges to update this table.' => 'jums nav pieejas labot šo tabulu.',
	'Saving' => 'Saglabāšana',
	'yes' => 'Jā',
	'no' => 'Nē',
	'Drop %s?' => 'Dzēst %s?',
	'overwrite' => 'pārrakstīt',
	'DB' => 'DB',
	'Warnings' => 'Brīdinājumi',
	'Adminer does not support accessing a database without a password, <a href="https://www.adminer.org/en/password/"%s>more information</a>.' => 'Adminer neatbalsta pieeju bez paroles, <a href="https://www.adminer.org/en/password/"%s>vairāk informācijas šeit</a>.',
	'Thanks for using Adminer, consider <a href="https://www.adminer.org/en/donation/">donating</a>.' => 'Paldies, ka izmantoji Adminer, vai vēlies veikt <a href="https://www.adminer.org/en/donation/">ziedojumu</a>.',
	'The action will be performed after successful login with the same credentials.' => 'Darbība tiks pabeigta pēc derīgas pieteikšanās sistēmā.',
	'Connecting to privileged ports is not allowed.' => 'Pieeja priviliģētiem portiem nav atļauta.',
	'There is a space in the input password which might be the cause.' => 'Parole satur atstarpi, kas varētu būt lieka.',
	'Unknown error.' => 'Nezināma kļūda.',
	'Database does not support password.' => 'Datubāze neatbalsta paroli.',
);

// run `php ../../lang.php lv` to update this file
