<?php
namespace Adminer;

Lang::$translations = array(
	'Login' => 'تسجيل الدخول',
	'Logout successful.' => 'تم تسجيل الخروج بنجاح.',
	'Invalid credentials.' => 'بيانات الدخول غير صالحة.',
	'Server' => 'الخادم',
	'Username' => 'اسم المستخدم',
	'Password' => 'كلمة المرور',
	'Select database' => 'اختر قاعدة البيانات',
	'Invalid database.' => 'قاعدة البيانات غير صالحة.',
	'Table has been dropped.' => 'تم حذف الجدول.',
	'Table has been altered.' => 'تم تعديل الجدول.',
	'Table has been created.' => 'تم إنشاء الجدول.',
	'Alter table' => 'تعديل الجدول',
	'Create table' => 'إنشاء جدول',
	'Table name' => 'اسم الجدول',
	'engine' => 'المحرك',
	'collation' => 'الترتيب',
	'Column name' => 'اسم العمود',
	'Type' => 'النوع',
	'Length' => 'الطول',
	'Auto Increment' => 'تزايد تلقائي',
	'Options' => 'خيارات',
	'Save' => 'حفظ',
	'Drop' => 'حذف',
	'Database has been created.' => 'تم إنشاء قاعدة البيانات.',
	'Database has been renamed.' => 'تمت إعادة تسمية فاعدة البيانات.',
	'Database has been altered.' => 'تم تعديل قاعدة البيانات.',
	'Alter database' => 'تعديل قاعدة البيانات',
	'Create database' => 'إنشاء قاعدة بيانات',
	'SQL command' => 'استعلام SQL',
	'Logout' => 'تسجيل الخروج',
	'Use' => 'استعمال',
	'No tables.' => 'لا توجد جداول.',
	'select' => 'تحديد',
	'Item has been deleted.' => 'تم حذف العنصر.',
	'Item has been updated.' => 'تم تعديل العنصر.',
	'Edit' => 'تعديل',
	'Insert' => 'إنشاء',
	'Save and insert next' => 'جفظ و إنشاء التالي',
	'Delete' => 'مسح',
	'Database' => 'قاعدة بيانات',
	'Routines' => 'الروتينات',
	'Indexes have been altered.' => 'تم تعديل المؤشر.',
	'Indexes' => 'المؤشرات',
	'Alter indexes' => 'تعديل المؤشرات',
	'Add next' => 'إضافة التالي',
	'Language' => 'اللغة',
	'Select' => 'اختيار',
	'New item' => 'عنصر جديد',
	'Search' => 'بحث',
	'Sort' => 'ترتيب',
	'descending' => 'تنازلي',
	'Limit' => 'حد',
	'No rows.' => 'لا توجد نتائج.',
	'Action' => 'الإجراء',
	'edit' => 'تعديل',
	'Page' => 'صفحة',
	'Query executed OK, %d row(s) affected.' => 'تم تنفسذ الاستعلام, %d عدد الأسطر المعدلة.',
	'Error in query' => 'هناك خطأ في الاستعلام',
	'Execute' => 'تنفيذ',
	'Table' => 'جدول',
	'Foreign keys' => 'مفاتيح أجنبية',
	'Triggers' => 'الزنادات',
	'View' => 'عرض',
	'Unable to select the table' => 'يتعذر اختيار الجدول',
	'Invalid CSRF token. Send the form again.' => 'رمز CSRF غير صالح. المرجو إرسال الاستمارة مرة أخرى.',
	'Comment' => 'تعليق',
	'Default values' => 'القيم الافتراضية',
	'%d byte(s)' => '%d بايت',
	'No commands to execute.' => 'لا توجد أوامر للتنفيذ.',
	'Unable to upload a file.' => 'يتعذر رفع ملف ما.',
	'File upload' => 'رفع ملف',
	'File uploads are disabled.' => 'رفع الملفات غير مشغل.',
	'Routine has been called, %d row(s) affected.' => 'تم استدعاء الروتين, عدد الأسطر المعدلة %d.',
	'Call' => 'استدعاء',
	'No extension' => 'امتداد غير موجود',
	'None of the supported PHP extensions (%s) are available.' => 'إمتدادات php (%s) المدعومة غير موجودة.',
	'Session support must be enabled.' => 'عليك تفعيل نظام الجلسات.',
	'Session expired, please login again.' => 'إنتهت الجلسة، من فضلك أعد تسجيل الدخول.',
	'Text length' => 'طول النص',
	'Foreign key has been dropped.' => 'تم مسح المفتاح الأجنبي.',
	'Foreign key has been altered.' => 'تم تعديل المفتاح الأجنبي.',
	'Foreign key has been created.' => 'تم إنشاء المفتاح الأجنبي.',
	'Foreign key' => 'مفتاح أجنبي',
	'Target table' => 'الجدول المستهدف',
	'Change' => 'تعديل',
	'Source' => 'المصدر',
	'Target' => 'الهدف',
	'Add column' => 'إضافة عمودا',
	'Alter' => 'تعديل',
	'Add foreign key' => 'إضافة مفتاح أجنبي',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'نوع المؤشر',
	'length' => 'الطول',
	'View has been dropped.' => 'تم مسح العرض.',
	'View has been altered.' => 'تم تعديل العرض.',
	'View has been created.' => 'تم إنشاء العرض.',
	'Alter view' => 'تعديل عرض',
	'Create view' => 'إنشاء عرض',
	'Name' => 'الاسم',
	'Process list' => 'قائمة الإجراءات',
	'%d process(es) have been killed.' => 'عدد الإجراءات التي تم إيقافها %d.',
	'Kill' => 'إيقاف',
	'Parameter name' => 'اسم المتغير',
	'Database schema' => 'مخطط فاعدة البيانات',
	'Create procedure' => 'إنشاء إجراء',
	'Create function' => 'إنشاء دالة',
	'Routine has been dropped.' => 'تم حذف الروتين.',
	'Routine has been altered.' => 'تم تعديل الروتين.',
	'Routine has been created.' => 'تم إنشاء الروتين.',
	'Alter function' => 'تعديل الدالة',
	'Alter procedure' => 'تعديل الإجراء',
	'Return type' => 'نوع العودة',
	'Add trigger' => 'إضافة زناد',
	'Trigger has been dropped.' => 'تم حذف الزناد.',
	'Trigger has been altered.' => 'تم تعديل الزناد.',
	'Trigger has been created.' => 'تم إنشاء الزناد.',
	'Alter trigger' => 'تعديل زناد',
	'Create trigger' => 'إنشاء زناد',
	'Time' => 'الوقت',
	'Event' => 'الحدث',
	'%d row(s)' => '%d أسطر',
	'Remove' => 'مسح',
	'Are you sure?' => 'هل أنت متأكد؟',
	'Privileges' => 'الإمتيازات',
	'Create user' => 'إنشاء مستخدم',
	'User has been dropped.' => 'تم حذف المستخدم.',
	'User has been altered.' => 'تم تعديل المستخدم.',
	'User has been created.' => 'تم إنشاء المستخدم.',
	'Hashed' => 'تلبيد',
	'Column' => 'عمود',
	'Routine' => 'روتين',
	'Grant' => 'موافق',
	'Revoke' => 'إلغاء',
	'%s version: %s through PHP extension %s' => 'النسخة %s : %s عن طريق إمتداد ال PHP %s',
	'Logged as: %s' => 'تم تسجيل الدخول باسم %s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'معلومات POST كبيرة جدا. قم بتقليص حجم المعلومات أو قم بزيادة قيمة %s في خيارات ال PHP.',
	'Move up' => 'نقل للأعلى',
	'Move down' => 'نقل للأسفل',
	'Export' => 'تصدير',
	'Tables' => 'جداول',
	'Data' => 'معلومات',
	'Output' => 'إخراج',
	'open' => 'فتح',
	'save' => 'حفظ',
	'Format' => 'الصيغة',
	'Functions' => 'الدوال',
	'Aggregation' => 'تجميع',
	'Event has been dropped.' => 'تم مسح الحدث.',
	'Event has been altered.' => 'تم تعديل الحدث.',
	'Event has been created.' => 'تم إنشاء الحدث.',
	'Alter event' => 'تعديل حدث',
	'Create event' => 'إنشاء حدث',
	'Start' => 'إبدأ',
	'End' => 'إنهاء',
	'Every' => 'كل',
	'Status' => 'حالة',
	'On completion preserve' => 'حفظ عند الإنتهاء',
	'Events' => 'الأحداث',
	'Schedule' => 'مواعيد',
	'At given time' => 'في وقت محدد',
	'Save and continue edit' => 'إحفظ و واصل التعديل',
	'original' => 'الأصلي',
	'Tables have been truncated.' => 'تم قطع الجداول.',
	'Tables have been moved.' => 'تم نقل الجداول.',
	'Tables have been dropped.' => 'تم حذف الجداول.',
	'Tables and views' => 'الجداول و العروض',
	'Engine' => 'المحرك',
	'Collation' => 'ترتيب',
	'Data Length' => 'طول المعطيات',
	'Index Length' => 'طول المؤشر',
	'Data Free' => 'المساحة الحرة',
	'Rows' => 'الأسطر',
	',' => ',',
	'0123456789' => '0123456789',
	'Analyze' => 'تحليل',
	'Optimize' => 'تحسين',
	'Check' => 'فحص',
	'Repair' => 'إصلاح',
	'Truncate' => 'قطع',
	'Move to other database' => 'نقل إلى قاعدة بيانات أخرى',
	'Move' => 'نقل',
	'%d item(s) have been affected.' => 'عدد العناصر المعدلة هو %d.',
	'Whole result' => 'نتيجة كاملة',
	'Clone' => 'نسخ',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'لقد تجاوزت العدد الأقصى للحقول. يرجى الرفع من %s.',
	'Partition by' => 'مقسم بواسطة',
	'Partitions' => 'التقسيمات',
	'Partition name' => 'اسم التقسيم',
	'Values' => 'القيم',
	'%d row(s) have been imported.' => 'تم استيراد %d سطرا.',
	'anywhere' => 'في اي مكان',
	'Import' => 'استيراد',
	'Stop on error' => 'أوقف في حالة حدوث خطأ',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'jj/mm/[aaaa]',
	'History' => 'تاريخ',
	'Variables' => 'متغيرات',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'أعمدة المصدر و الهدف يجب أن تكون بنفس النوع, يجب أن يكون هناك مؤشر في أعمدة الهدف و البيانات المرجعية يجب ان تكون موجودة.',
	'Relations' => 'علاقات',
	'Run file' => 'نفذ الملف',
	'Clear' => 'مسح',
	'Maximum allowed file size is %sB.' => 'حجم الملف الأقصى هو %sB.',
	'Numbers' => 'أعداد',
	'Date and time' => 'التاريخ و الوقت',
	'Strings' => 'سلاسل',
	'Binary' => 'ثنائية',
	'Lists' => 'قوائم',
	'Editor' => 'المحرر',
	'Webserver file %s' => 'ملف %s من خادم الويب',
	'File does not exist.' => 'الملف غير موجود.',
	'%d in total' => '%d في المجموع',
	'Permanent login' => 'تسجيل دخول دائم',
	'Databases have been dropped.' => 'تم حذف قواعد البيانات.',
	'Database has been dropped.' => 'تم حذف قاعدة البيانات.',
	'Search data in tables' => 'بحث في الجداول',
	'Schema' => 'المخطط',
	'Alter schema' => 'تعديل المخطط',
	'Create schema' => 'إنشاء مخطط',
	'Schema has been dropped.' => 'تم حذف المخطط.',
	'Schema has been created.' => 'تم إنشاء المخطط.',
	'Schema has been altered.' => 'تم تعديل المخطط.',
	'Sequences' => 'السلاسل',
	'Create sequence' => 'إنشاء سلسلة',
	'Alter sequence' => 'تعديل سلسلة',
	'Sequence has been dropped.' => 'تم حذف السلسلة.',
	'Sequence has been created.' => 'تم إنشاء السلسلة.',
	'Sequence has been altered.' => 'تم تعديل السلسلة.',
	'User types' => 'نوع المستخدم',
	'Create type' => 'إنشاء نوع',
	'Alter type' => 'تعديل نوع',
	'Type has been dropped.' => 'تم حذف النوع.',
	'Type has been created.' => 'تم إنشاء النوع.',
	'Use edit link to modify this value.' => 'استعمل الرابط "تعديل" لتعديل هذه القيمة.',
	'last' => 'الأخيرة',
	'From server' => 'من الخادم',
	'System' => 'النظام',
	'Select data' => 'عرض البيانات',
	'Show structure' => 'عرض التركيبة',
	'empty' => 'فارغ',
	'Network' => 'شبكة',
	'Geometry' => 'هندسة',
	'File exists.' => 'الملف موجود.',
	'Item%s has been inserted.' => '%sتم إدراج العنصر.',
	'now' => 'الآن',
	'%d query(s) executed OK.' => array('تم تنفيذ الاستعلام %d بنجاح.', 'تم تنفيذ الاستعلامات %d بنجاح.'),
	'Show only errors' => 'إظهار الأخطاء فقط',
	'Refresh' => 'تحديث',
	'Invalid schema.' => 'مخطط غير صالح.',
	'Please use one of the extensions %s.' => 'المرجو استخدام إحدى الامتدادات %s.',
	'ltr' => 'rtl',
	'Tables have been copied.' => 'تم نسخ الجداول.',
	'Copy' => 'نسخ',
	'Permanent link' => 'رابط دائم',
	'Edit all' => 'تعديل الكل',
	'HH:MM:SS' => 'HH:MM:SS',
);

// run `php ../../lang.php ar` to update this file
