<?php
namespace Adminer;

Lang::$translations = array(
	'Login' => 'เข้าสู่ระบบ',
	'Logout successful.' => 'ออกจากระบบเรียบร้อยแล้ว.',
	'Invalid credentials.' => 'ข้อมูลไม่ถูกต้อง.',
	'Server' => 'เซอเวอร์',
	'Username' => 'ชื่อผู้ใช้งาน',
	'Password' => 'รหัสผ่าน',
	'Select database' => 'เลือกฐานข้อมูล',
	'Invalid database.' => 'ฐานข้อมูลไม่ถูกต้อง.',
	'Table has been dropped.' => 'ลบตารางแล้ว.',
	'Table has been altered.' => 'แก้ไขตารางแล้ว.',
	'Table has been created.' => 'สร้างตารางใหม่แล้ว.',
	'Alter table' => 'เปลี่ยนแปลงตารางแล้ว',
	'Create table' => 'สร้างตารางใหม่',
	'Table name' => 'ชื่อตาราง',
	'engine' => 'ชนิดของฐานข้อมูล',
	'collation' => 'การตรวจทาน',
	'Column name' => 'ชื่อคอลัมน์',
	'Type' => 'ชนิด',
	'Length' => 'ความยาว',
	'Auto Increment' => 'เพิ่มลำดับโดยอัตโนมัติ',
	'Options' => 'ตัวเลือก',
	'Save' => 'บันทึก',
	'Drop' => 'ลบ',
	'Database has been dropped.' => 'ฐานข้อมูลถูกลบแล้ว.',
	'Database has been created.' => 'สร้างฐานข้อมูลใหม่แล้ว.',
	'Database has been renamed.' => 'เปลี่ยนชื่อฐานข้อมูลแล้ว.',
	'Database has been altered.' => 'เปลี่ยนแปลงฐานข้อมูลแล้ว.',
	'Alter database' => 'เปลี่ยนแปลงฐานข้อมูล',
	'Create database' => 'สร้างฐานข้อมูล',
	'SQL command' => 'คำสั่ง SQL',
	'Logout' => 'ออกจากระบบ',
	'Use' => 'ใช้งาน',
	'No tables.' => 'ไม่พบตาราง.',
	'select' => 'เลือก',
	'Item has been deleted.' => 'รายการถูกลบแล้ว.',
	'Item has been updated.' => 'ปรับปรุงรายการแล้ว.',
	'Item%s has been inserted.' => 'มี%s รายการ ถูกเพิ่มแล้ว.',
	'Edit' => 'แก้ไข',
	'Insert' => 'เพิ่ม',
	'Save and insert next' => 'บันทึกแล้วเพิ่มรายการถัดไป',
	'Delete' => 'ลบ',
	'Database' => 'ฐานข้อมูล',
	'Routines' => 'รูทีน',
	'Indexes have been altered.' => 'เปลี่ยนแปลงดัชนีแล้ว.',
	'Indexes' => 'ดัชนี',
	'Alter indexes' => 'เปลี่ยนแปลงดัชนี',
	'Add next' => 'เพิ่มรายการถัดไป',
	'Language' => 'ภาษา',
	'Select' => 'เลือก',
	'New item' => 'รายการใหม่',
	'Search' => 'ค้นหา',
	'Sort' => 'เรียงลำดับ',
	'descending' => 'มากไปน้อย',
	'Limit' => 'จำกัด',
	'No rows.' => 'ไม่มีแถวของตาราง.',
	'Action' => 'ดำเนินการ',
	'edit' => 'แก้ไข',
	'Page' => 'หน้า',
	'Query executed OK, %d row(s) affected.' => 'ประมวลผลคำสั่งแล้ว มี %d ถูกดำเนินการ.',
	'Error in query' => 'คำสั่งไม่ถูกต้อง',
	'Execute' => 'ประมวลผล',
	'Table' => 'ตาราง',
	'Foreign keys' => 'คีย์คู่แข่ง',
	'Triggers' => 'ทริกเกอร์',
	'View' => 'วิว',
	'Unable to select the table' => 'ไม่สามารถเลือกตารางได้',
	'Invalid CSRF token. Send the form again.' => 'เครื่องหมาย CSRF ไม่ถูกต้อง ส่งข้อมูลใหม่อีกครั้ง.',
	'Comment' => 'หมายเหตุ',
	'Default values' => 'ค่าเริ่มต้น',
	'%d byte(s)' => '%d ไบท์',
	'No commands to execute.' => 'ไม่มีคำสั่งที่จะประมวลผล.',
	'Unable to upload a file.' => 'ไม่สามารถอัปโหลดไฟล์ได้.',
	'File upload' => 'อัปโหลดไฟล์',
	'File uploads are disabled.' => 'การอัปโหลดไฟล์ถูกปิดการใช้งาน.',
	'Routine has been called, %d row(s) affected.' => 'รูทีนถูกเรียกใช้งาน มี %d แถวถูกดำเนินการ.',
	'Call' => 'เรียกใช้งาน',
	'No extension' => 'ไม่พบส่วนเสริม',
	'None of the supported PHP extensions (%s) are available.' => 'ไม่มีส่วนเสริมของ PHP (%s) ที่สามารถใช้งานได้.',
	'Session support must be enabled.' => 'ต้องเปิดใช้งาน Session.',
	'Session expired, please login again.' => 'Session หมดอายุแล้ว กรุณาเข้าสู่ระบบใหม่อีกครั้ง.',
	'Text length' => 'ความยาวของอักษร',
	'Foreign key has been dropped.' => 'คีย์คู่แข่งถูกลบแล้ว.',
	'Foreign key has been altered.' => 'คีย์คู่แข่งถูกเปลี่ยนแปลงแล้ว.',
	'Foreign key has been created.' => 'คีย์คู่แข่งถูกสร้างแล้ว.',
	'Foreign key' => 'คีย์คู่แข่ง',
	'Target table' => 'คารางเป้าหมาย',
	'Change' => 'แก้ไข',
	'Source' => 'แหล่งข้อมูล',
	'Target' => 'เป้าหมาย',
	'Add column' => 'เพิ่มคอลัมน์',
	'Alter' => 'เปลี่ยนแปลง',
	'Add foreign key' => 'เพิ่มคีย์คู่แข่ง',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'ชนิดของดัชนี',
	'length' => 'ความยาว',
	'View has been dropped.' => 'วิวถูกลบแล้ว.',
	'View has been altered.' => 'วิวถูกเปลี่ยนแปลงแล้ว.',
	'View has been created.' => 'วิวถูกสร้างแล้ว.',
	'Alter view' => 'เปลี่ยนแปลงวิว',
	'Create view' => 'เพิ่มวิว',
	'Name' => 'ชื่อ',
	'Process list' => 'รายการของกระบวนการ',
	'%d process(es) have been killed.' => 'มี %d กระบวนการถูกทำลายแล้ว.',
	'Kill' => 'ทำลาย',
	'Parameter name' => 'ชื่อพารามิเตอร์',
	'Database schema' => 'Schema ของฐานข้อมูล',
	'Create procedure' => 'สร้าง procedure',
	'Create function' => 'สร้าง Function',
	'Routine has been dropped.' => 'Routine ถูกลบแล้ว.',
	'Routine has been altered.' => 'Routine ถูกเปลี่ยนแปลงแล้ว.',
	'Routine has been created.' => 'Routine ถูกสร้างแล้ว.',
	'Alter function' => 'เปลี่ยนแปลง Function',
	'Alter procedure' => 'เปลี่ยนแปลง procedure',
	'Return type' => 'ประเภทของค่าที่คืนกลับ',
	'Add trigger' => 'เพิ่ม trigger',
	'Trigger has been dropped.' => 'Trigger ถูกลบแล้ว.',
	'Trigger has been altered.' => 'Trigger ถูกเปลี่ยนแปลงแล้ว.',
	'Trigger has been created.' => 'Trigger ถูกสร้างแล้ว.',
	'Alter trigger' => 'เปลี่ยนแปลง Trigger',
	'Create trigger' => 'สร้าง Trigger',
	'Time' => 'เวลา',
	'Event' => 'เหตุการณ์',
	'%s version: %s through PHP extension %s' => '%s รุ่น: %s ผ่านส่วนขยาย PHP %s',
	'%d row(s)' => '%d แถว',
	'Remove' => 'ลบ',
	'Are you sure?' => 'คุณแน่ใจแล้วหรือ',
	'Privileges' => 'สิทธิ์',
	'Create user' => 'สร้างผู้ใช้งาน',
	'User has been dropped.' => 'ลบผู้ใช้งานแล้ว.',
	'User has been altered.' => 'เปลี่ยนแปลงผู้ใช้งานแล้ว.',
	'User has been created.' => 'สร้างผู้ใช้งานแล้ว.',
	'Hashed' => 'Hash',
	'Column' => 'คอลัมน์',
	'Routine' => 'รูทีน',
	'Grant' => 'การอนุญาต',
	'Revoke' => 'ยกเลิก',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'ข้อมูลที่ส่งเข้ามีขนาดใหญ่เกิน คุณสามารถ เพิ่ม-ลดขนาดได้ที่ %s คำสั่งการตั้งค่า.',
	'Logged as: %s' => 'สวัสดีคุณ: %s',
	'Move up' => 'ย้ายไปข้างบน',
	'Move down' => 'ย้ายลงล่าง',
	'Functions' => 'ฟังก์ชั่น',
	'Aggregation' => 'รวบรวม',
	'Export' => 'ส่งออก',
	'Output' => 'ข้อมูลที่ส่งออก',
	'open' => 'เปิด',
	'save' => 'บันทึก',
	'Format' => 'รูปแบบ',
	'Tables' => 'ตาราง',
	'Data' => 'ข้อมูล',
	'Event has been dropped.' => 'เหตุการณ์ถูกลบแล้ว.',
	'Event has been altered.' => 'เหตุการณ์ถูกเปลี่ยนแปลงแล้ว.',
	'Event has been created.' => 'เหตุการณ์ถูกสร้างแล้ว.',
	'Alter event' => 'เปลี่ยนแปลงเหตุการณ์',
	'Create event' => 'สร้างเหตุการณ์',
	'At given time' => 'ในเวลาที่กำหนด',
	'Every' => 'ทุกๆ',
	'Events' => 'เหตุการณ์',
	'Schedule' => 'กำหนดการณ์',
	'Start' => 'เริ่มต้น',
	'End' => 'สิ้นสุด',
	'Status' => 'สถานะ',
	'On completion preserve' => 'เมื่อเสร็จสิ้นการสงวน',
	'Tables and views' => 'ตารางและวิว',
	'Data Length' => 'ความยาวของข้อมูล',
	'Index Length' => 'ความยาวของดัชนี',
	'Data Free' => 'พื้นที่ว่าง',
	'Collation' => 'การตรวจทาน',
	'Analyze' => 'วิเคราะห์',
	'Optimize' => 'เพิ่มประสิทธิภาพ',
	'Check' => 'ตรวจสอบ',
	'Repair' => 'ซ่อมแซม',
	'Truncate' => 'ตัดทิ้ง',
	'Tables have been truncated.' => 'เคลียร์ตารางแล้ว (truncate).',
	'Rows' => 'แถว',
	',' => ' ',
	'0123456789' => '0123456789',
	'Tables have been moved.' => 'ตารางถูกย้ายแล้ว.',
	'Move to other database' => 'ย้ายไปยังฐานข้อมูลอื่น',
	'Move' => 'ย้าย',
	'Engine' => 'ชนิดของฐานข้อมูล',
	'Save and continue edit' => 'บันทึกและแก้ไขข้อมูลอื่นๆต่อ',
	'original' => 'ต้นฉบับ',
	'Tables have been dropped.' => 'ตารางถูกลบแล้ว.',
	'%d item(s) have been affected.' => 'มี %d รายการถูกดำเนินการแล้ว.',
	'Whole result' => 'รวมผล',
	'Clone' => 'ทำซ้ำ',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'จำนวนสูงสุดของฟิลด์อนุญาตให้เกิน กรุณาเพิ่มอีก %s.',
	'Partition by' => 'พาร์ทิชันโดย',
	'Partitions' => 'พาร์ทิชัน',
	'Partition name' => 'ชื่อของพาร์ทิชัน',
	'Values' => 'ค่า',
	'%d row(s) have been imported.' => '%d แถวถูกนำเข้าแล้ว.',
	'anywhere' => 'ทุกแห่ง',
	'Import' => 'นำเข้า',
	'Stop on error' => 'หยุดการทำงานเมื่อเออเรอ',
	'%.3f s' => '%.3f วินาที',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'วันที่/เดือน/[ปี]',
	'History' => 'ประวัติ',
	'Variables' => 'ตัวแปร',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'แหล่งที่มาและเป้าหมายของคอลมัน์ต้องมีชนิดข้อมูลเดียวกัน คือต้องมีดัชนีและข้อมูลอ้างอิงของคอลัมน์เป้าหมาย.',
	'Relations' => 'ความสำพันธ์',
	'Run file' => 'ทำงานจากไฟล์',
	'Clear' => 'เคลียร์',
	'Maximum allowed file size is %sB.' => 'ขนาดไฟล์สูงสุดที่อนุญาตให้ใช้งานคือ %sB.',
	'Numbers' => 'ตัวเลข',
	'Date and time' => 'วันและเวลา',
	'Strings' => 'ตัวอักษร',
	'Binary' => 'เลขฐานสอง',
	'Lists' => 'รายการ',
	'Editor' => 'ผู้แก้ไข',
	'Webserver file %s' => 'Webserver file %s',
	'File does not exist.' => 'ไม่มีไฟล์.',
	'%d in total' => '%d ของทั้งหมด',
	'Permanent login' => 'จดจำการเข้าสู่ระบบตลอดไป',
	'Databases have been dropped.' => 'ฐานข้อมูลถูกลบแล้ว.',
	'Search data in tables' => 'ค้นหาในตาราง',
	'Schema' => 'Schema',
	'Alter schema' => 'เปลี่ยนแปลง schema',
	'Create schema' => 'สร้าง schema',
	'Schema has been dropped.' => 'Schema ถูกลบแล้ว.',
	'Schema has been created.' => 'Schema ถูกสร้างแล้ว.',
	'Schema has been altered.' => 'Schema ถูกเปลี่ยนแปลงแล้ว.',
	'Sequences' => 'Sequences',
	'Create sequence' => 'Sequence ถูกสร้างแล้ว',
	'Alter sequence' => 'Sequence ถูกเปลี่ยนแปลงแล้ว',
	'Sequence has been dropped.' => 'Sequence ถูกลบแล้ว.',
	'Sequence has been created.' => 'Sequence ถูกสร้างแล้ว.',
	'Sequence has been altered.' => 'Sequence ถูกเปลี่ยนแปลงแล้ว.',
	'User types' => 'ประเภทผู้ใช้งาน',
	'Create type' => 'สร้างประเภทผู้ใช้งาน',
	'Alter type' => 'แก้ไขประเภท',
	'Type has been dropped.' => 'ประเภทถูกลบแล้ว.',
	'Type has been created.' => 'ประเภทถูกสร้างแล้ว.',
	'Ctrl+click on a value to modify it.' => 'กด Ctrl+click เพื่อแก้ไขค่า.',
	'Use edit link to modify this value.' => 'ใช้ลิงค์ แก้ไข เพื่อปรับเปลี่ยนค่านี้.',
	'last' => 'ล่าสุด',
	'From server' => 'จากเซเวอร์',
	'System' => 'ระบบ',
	'Select data' => 'เลือกข้อมูล',
	'Show structure' => 'แสดงโครงสร้าง',
	'empty' => 'ว่างเปล่า',
	'Network' => 'เครื่องข่าย',
	'Geometry' => 'เรขาคณิต',
	'File exists.' => 'มีไฟล์นี้อยู่แล้ว.',
	'%d query(s) executed OK.' => '%d คำสั่งถูกดำเนินการแล้ว.',
	'Show only errors' => 'แสดงเฉพาะเออเรอ',
	'Refresh' => 'โหลดใหม่',
	'Invalid schema.' => 'schema ไม่ถูกต้อง.',
	'Please use one of the extensions %s.' => 'กรุณาใช้ส่วนเสริมอย่างน้อย 1 ส่วนเสริมจากทั้งหมด %s.',
	'now' => 'ตอนนี้',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'ทำซ้ำตารางฐานข้อมูลแล้ว.',
	'Copy' => 'ทำซ้ำ',
	'Permanent link' => 'ลิงค์ถาวร',
	'Edit all' => 'แก้ไขทั้งหมด',
	'HH:MM:SS' => 'HH:MM:SS',
);

// run `php ../../lang.php th` to update this file
