<?php
namespace Adminer;

Lang::$translations = array(
	'Login' => 'Autenticazione',
	'Logout successful.' => 'Uscita effettuata con successo.',
	'Invalid credentials.' => 'Credenziali non valide.',
	'Server' => 'Server',
	'Username' => 'Utente',
	'Password' => 'Password',
	'Select database' => 'Seleziona database',
	'Invalid database.' => 'Database non valido.',
	'Table has been dropped.' => 'Tabella eliminata.',
	'Table has been altered.' => 'Tabella modificata.',
	'Table has been created.' => 'Tabella creata.',
	'Alter table' => 'Modifica tabella',
	'Create table' => 'Crea tabella',
	'Table name' => 'Nome tabella',
	'engine' => 'motore',
	'collation' => 'collazione',
	'Column name' => 'Nome colonna',
	'Type' => 'Tipo',
	'Length' => 'Lunghezza',
	'Auto Increment' => 'Auto incremento',
	'Options' => 'Opzioni',
	'Save' => 'Salva',
	'Drop' => 'Elimina',
	'Database has been dropped.' => 'Database eliminato.',
	'Database has been created.' => 'Database creato.',
	'Database has been renamed.' => 'Database rinominato.',
	'Database has been altered.' => 'Database modificato.',
	'Alter database' => 'Modifica database',
	'Create database' => 'Crea database',
	'SQL command' => 'Comando SQL',
	'Logout' => 'Esci',
	'Use' => 'Usa',
	'No tables.' => 'No tabelle.',
	'select' => 'seleziona',
	'Item has been deleted.' => 'Elemento eliminato.',
	'Item has been updated.' => 'Elemento aggiornato.',
	'Item%s has been inserted.' => 'Elemento%s inserito.',
	'Edit' => 'Modifica',
	'Insert' => 'Inserisci',
	'Save and insert next' => 'Salva e inserisci un altro',
	'Delete' => 'Elimina',
	'Database' => 'Database',
	'Routines' => 'Routine',
	'Indexes have been altered.' => 'Indici modificati.',
	'Indexes' => 'Indici',
	'Alter indexes' => 'Modifica indici',
	'Add next' => 'Aggiungi altro',
	'Language' => 'Lingua',
	'Select' => 'Seleziona',
	'New item' => 'Nuovo elemento',
	'Search' => 'Cerca',
	'Sort' => 'Ordina',
	'descending' => 'discendente',
	'Limit' => 'Limite',
	'No rows.' => 'Nessuna riga.',
	'Action' => 'Azione',
	'edit' => 'modifica',
	'Page' => 'Pagina',
	'Query executed OK, %d row(s) affected.' => array('Esecuzione della query OK, %d riga interessata.', 'Esecuzione della query OK, %d righe interessate.'),
	'Error in query' => 'Errore nella query',
	'Execute' => 'Esegui',
	'Table' => 'Tabella',
	'Foreign keys' => 'Chiavi esterne',
	'Triggers' => 'Trigger',
	'View' => 'Vedi',
	'Unable to select the table' => 'Selezione della tabella non riuscita',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF non valido. Reinvia la richiesta.',
	'Comment' => 'Commento',
	'Default values' => 'Valori predefiniti',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'Nessun commando da eseguire.',
	'Unable to upload a file.' => 'Caricamento del file non riuscito.',
	'File upload' => 'Caricamento file',
	'File uploads are disabled.' => 'Caricamento file disabilitato.',
	'Routine has been called, %d row(s) affected.' => array('Routine chiamata, %d riga interessata.', 'Routine chiamata, %d righe interessate.'),
	'Call' => 'Chiama',
	'No extension' => 'Estensioni non presenti',
	'None of the supported PHP extensions (%s) are available.' => 'Nessuna delle estensioni PHP supportate (%s) disponibile.',
	'Session support must be enabled.' => 'Le sessioni devono essere abilitate.',
	'Session expired, please login again.' => 'Sessione scaduta, autenticarsi di nuovo.',
	'Text length' => 'Lunghezza testo',
	'Foreign key has been dropped.' => 'Foreign key eliminata.',
	'Foreign key has been altered.' => 'Foreign key modificata.',
	'Foreign key has been created.' => 'Foreign key creata.',
	'Foreign key' => 'Foreign key',
	'Target table' => 'Tabella obiettivo',
	'Change' => 'Cambia',
	'Source' => 'Sorgente',
	'Target' => 'Obiettivo',
	'Add column' => 'Aggiungi colonna',
	'Alter' => 'Modifica',
	'Add foreign key' => 'Aggiungi foreign key',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Tipo indice',
	'length' => 'lunghezza',
	'View has been dropped.' => 'Vista eliminata.',
	'View has been altered.' => 'Vista modificata.',
	'View has been created.' => 'Vista creata.',
	'Alter view' => 'Modifica vista',
	'Create view' => 'Crea vista',
	'Name' => 'Nome',
	'Process list' => 'Elenco processi',
	'%d process(es) have been killed.' => array('%d processo interrotto.', '%d processi interrotti.'),
	'Kill' => 'Interrompi',
	'Parameter name' => 'Nome parametro',
	'Database schema' => 'Schema database',
	'Create procedure' => 'Crea procedura',
	'Create function' => 'Crea funzione',
	'Routine has been dropped.' => 'Routine eliminata.',
	'Routine has been altered.' => 'Routine modificata.',
	'Routine has been created.' => 'Routine creata.',
	'Alter function' => 'Modifica funzione',
	'Alter procedure' => 'Modifica procedura',
	'Return type' => 'Return type',
	'Add trigger' => 'Aggiungi trigger',
	'Trigger has been dropped.' => 'Trigger eliminato.',
	'Trigger has been altered.' => 'Trigger modificato.',
	'Trigger has been created.' => 'Trigger creato.',
	'Alter trigger' => 'Modifica trigger',
	'Create trigger' => 'Crea trigger',
	'Time' => 'Orario',
	'Event' => 'Evento',
	'%s version: %s through PHP extension %s' => 'Versione %s: %s via estensione PHP %s',
	'%d row(s)' => array('%d riga', '%d righe'),
	'Remove' => 'Rimuovi',
	'Are you sure?' => 'Sicuro?',
	'Privileges' => 'Privilegi',
	'Create user' => 'Crea utente',
	'User has been dropped.' => 'Utente eliminato.',
	'User has been altered.' => 'Utente modificato.',
	'User has been created.' => 'Utente creato.',
	'Hashed' => 'Hashed',
	'Column' => 'Colonna',
	'Routine' => 'Routine',
	'Grant' => 'Permetti',
	'Revoke' => 'Revoca',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Troppi dati via POST. Ridurre i dati o aumentare la direttiva di configurazione %s.',
	'Logged as: %s' => 'Autenticato come: %s',
	'Move up' => 'Sposta su',
	'Move down' => 'Sposta giu',
	'Functions' => 'Funzioni',
	'Aggregation' => 'Aggregazione',
	'Export' => 'Esporta',
	'Output' => 'Risultato',
	'open' => 'apri',
	'save' => 'salva',
	'Format' => 'Formato',
	'Tables' => 'Tabelle',
	'Data' => 'Dati',
	'Event has been dropped.' => 'Evento eliminato.',
	'Event has been altered.' => 'Evento modificato.',
	'Event has been created.' => 'Evento creato.',
	'Alter event' => 'Modifica evento',
	'Create event' => 'Crea evento',
	'Start' => 'Inizio',
	'End' => 'Fine',
	'Every' => 'Ogni',
	'Status' => 'Stato',
	'On completion preserve' => 'Al termine preservare',
	'Events' => 'Eventi',
	'Schedule' => 'Pianifica',
	'At given time' => 'A tempo prestabilito',
	'Save and continue edit' => 'Salva e continua',
	'original' => 'originale',
	'Tables have been truncated.' => 'Le tabelle sono state svuotate.',
	'Tables have been moved.' => 'Le tabelle sono state spostate.',
	'Tables have been dropped.' => 'Le tabelle sono state eliminate.',
	'Tables and views' => 'Tabelle e viste',
	'Engine' => 'Motore',
	'Collation' => 'Collazione',
	'Data Length' => 'Lunghezza dato',
	'Index Length' => 'Lunghezza indice',
	'Data Free' => 'Dati liberi',
	'Rows' => 'Righe',
	',' => '.',
	'0123456789' => '0123456789',
	'Analyze' => 'Analizza',
	'Optimize' => 'Ottimizza',
	'Check' => 'Controlla',
	'Repair' => 'Ripara',
	'Truncate' => 'Svuota',
	'Move to other database' => 'Sposta in altro database',
	'Move' => 'Sposta',
	'%d item(s) have been affected.' => array('Il risultato consiste in %d elemento.', 'Il risultato consiste in %d elementi.'),
	'Whole result' => 'Intero risultato',
	'Clone' => 'Clona',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Troppi campi. Per favore aumentare %s.',
	'Partition by' => 'Partiziona per',
	'Partitions' => 'Partizioni',
	'Partition name' => 'Nome partizione',
	'Values' => 'Valori',
	'%d row(s) have been imported.' => array('%d riga importata.', '%d righe importate.'),
	'anywhere' => 'ovunque',
	'Import' => 'Importa',
	'Stop on error' => 'Stop su errore',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'dd/mm/[yyyy]',
	'History' => 'Storico',
	'Variables' => 'Variabili',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Le colonne sorgente e destinazione devono essere dello stesso tipo e ci deve essere un indice sulla colonna di destinazione e sui dati referenziati.',
	'Relations' => 'Relazioni',
	'Run file' => 'Esegui file',
	'Clear' => 'Pulisci',
	'Maximum allowed file size is %sB.' => 'La dimensione massima del file è %sB.',
	'Numbers' => 'Numeri',
	'Date and time' => 'Data e ora',
	'Strings' => 'Stringhe',
	'Binary' => 'Binari',
	'Lists' => 'Liste',
	'Editor' => 'Editor',
	'Webserver file %s' => 'Webserver file %s',
	'File does not exist.' => 'Il file non esiste.',
	'%d in total' => '%d in totale',
	'Permanent login' => 'Login permanente',
	'Databases have been dropped.' => 'Database eliminati.',
	'Search data in tables' => 'Cerca nelle tabelle',
	'Schema' => 'Schema',
	'Alter schema' => 'Modifica schema',
	'Create schema' => 'Crea schema',
	'Schema has been dropped.' => 'Schema eliminato.',
	'Schema has been created.' => 'Schema creato.',
	'Schema has been altered.' => 'Schema modificato.',
	'Sequences' => 'Sequenza',
	'Create sequence' => 'Crea sequenza',
	'Alter sequence' => 'Modifica sequenza',
	'Sequence has been dropped.' => 'Sequenza eliminata.',
	'Sequence has been created.' => 'Sequenza creata.',
	'Sequence has been altered.' => 'Sequenza modificata.',
	'User types' => 'Tipi definiti dall\'utente',
	'Create type' => 'Crea tipo definito dall\'utente',
	'Alter type' => 'Modifica tipo definito dall\'utente',
	'Type has been dropped.' => 'Tipo definito dall\'utente eliminato.',
	'Type has been created.' => 'Tipo definito dall\'utente creato.',
	'Ctrl+click on a value to modify it.' => 'Fai Ctrl+click su un valore per modificarlo.',
	'Use edit link to modify this value.' => 'Usa il link modifica per modificare questo valore.',
	'last' => 'ultima',
	'From server' => 'Dal server',
	'System' => 'Sistema',
	'Select data' => 'Visualizza dati',
	'Show structure' => 'Visualizza struttura',
	'empty' => 'vuoto',
	'Network' => 'Rete',
	'Geometry' => 'Geometria',
	'File exists.' => 'Il file esiste già.',
	'%d query(s) executed OK.' => array('%d query eseguita con successo.', '%d query eseguite con successo.'),
	'Show only errors' => 'Mostra solo gli errori',
	'Refresh' => 'Aggiorna',
	'Invalid schema.' => 'Schema non valido.',
	'Please use one of the extensions %s.' => 'Usa una delle estensioni %s.',
	'now' => 'adesso',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'Le tabelle sono state copiate.',
	'Copy' => 'Copia',
	'Permanent link' => 'Link permanente',
	'Edit all' => 'Modifica tutto',
	'HH:MM:SS' => 'HH:MM:SS',
	'Drop %s?' => 'Scartare %s?',
	'Tables have been optimized.' => 'Le tabelle sono state ottimizzate.',
	'Materialized view' => 'Vista materializzata',
	'Vacuum' => 'Aspira',
	'Selected' => 'Selezionato',
	'overwrite' => 'sovrascrivi',
	'DB' => 'DB',
	'File must be in UTF-8 encoding.' => 'Il file deve avere codifica UTF-8.',
	'Modify' => 'Modifica',
	'Load more data' => 'Carica piú dati',
	'Loading' => 'Caricamento',
	'ATTACH queries are not supported.' => 'ATTACH queries non sono supportate.',
	'Warnings' => 'Attenzione',
	'%d / ' => '%d / ',
	'Limit rows' => 'Limite righe',
	'Adminer does not support accessing a database without a password, <a href="https://www.adminer.org/en/password/"%s>more information</a>.' => 'Adminer non supporta accesso a databse senza password, <a href="https://www.adminer.org/it/password/"%s>piú informazioni</a>.',
	'Default value' => 'Valore predefinito',
	'Full table scan' => 'Analizza intera tabella',
	'Too many unsuccessful logins, try again in %d minute(s).' => array('Troppi tentativi infruttuosi di login, si prega di riprovare in %d minuto.', 'Troppi tentativi infruttuosi di login, si prega di riprovare in %d minuti.'),
	'Master password expired. <a href="https://www.adminer.org/en/extension/"%s>Implement</a> %s method to make it permanent.' => 'La password principale é scaduta. <a href="https://www.adminer.org/it/extension/"%s>Implementare</a> %s come metodo per renderla permanente.',
	'The action will be performed after successful login with the same credentials.' => 'La azione verrá eseguita dopo un login valido con le stesse credenziali.',
	'Connecting to privileged ports is not allowed.' => 'LA connessione a porte privilegiate non é permessa.',
	'There is a space in the input password which might be the cause.' => 'Esiste uno spazio nella passoword inserita che potrebbe essere la causa.',
	'If you did not send this request from Adminer then close this page.' => 'Se non hai inviato tu la richiesta tramite Adminer puoi chiudere la pagina.',
	'You can upload a big SQL file via FTP and import it from server.' => 'Puoi caricare un grande file SQL tramite FTP ed impirtarlo dal server.',
	'Size' => 'Taglia',
	'Compute' => 'Elabora',
	'You are offline.' => 'Sei disconnesso.',
	'You have no privileges to update this table.' => 'Non hai i privilegi per aggiornare questa tabella.',
	'Saving' => 'Salvataggio',
	'Unknown error.' => 'Errore sconosciuto.',
	'Database does not support password.' => 'Il database non supporta password.',
	'Disable %s or enable %s or %s extensions.' => 'Disabilita %s o abilita %s oppure %s estensioni.',
	'yes' => 'si',
	'no' => 'no',
);

// run `php ../../lang.php it` to update this file
