<?php
namespace Adminer;

Lang::$translations = array(
	'Login' => 'লগইন',
	'Logout successful.' => 'সফলভাবে লগআউট হয়েছে।',
	'Invalid credentials.' => 'ভুল পাসওয়ার্ড।',
	'Server' => 'সার্ভার',
	'Username' => 'ইউজারের নাম',
	'Password' => 'পাসওয়ার্ড',
	'Select database' => 'ডাটাবেজ নির্বাচন করুন',
	'Invalid database.' => 'অকার্যকর ডাটাবেজ।',
	'Table has been dropped.' => 'টেবিল মুছে ফেলা হয়েছে।',
	'Table has been altered.' => 'টেবিল পরিবর্তন করা হয়েছে।',
	'Table has been created.' => 'টেবিল তৈরী করা হয়েছে।',
	'Alter table' => 'টেবিল পরিবর্তন করুন',
	'Create table' => 'টেবিল তৈরী করুন',
	'Table name' => 'টেবিলের নাম',
	'engine' => 'ইন্জিন',
	'collation' => 'সমষ্টি',
	'Column name' => 'কলামের নাম',
	'Type' => 'ধরণ',
	'Length' => 'দৈর্ঘ্য',
	'Auto Increment' => 'স্বয়ংক্রিয় বৃদ্ধি',
	'Options' => 'বিকল্পসমূহ',
	'Save' => 'সংরক্ষণ করুন',
	'Drop' => 'মুছে ফেলো',
	'Database has been dropped.' => 'ডাটাবেজ মুছে ফেলা হয়েছে।',
	'Database has been created.' => 'ডাটাবেজ তৈরী করা হয়েছে।',
	'Database has been renamed.' => 'ডাটাবেজের নতুন নামকরণ করা হয়েছে।',
	'Database has been altered.' => 'ডাটাবেজ পরিবর্তন করা হয়েছে।',
	'Alter database' => 'ডাটাবেজ পরিবর্তন করুন',
	'Create database' => 'ডাটাবেজ তৈরী করুন',
	'SQL command' => 'SQL-কমান্ড',
	'Logout' => 'লগআউট',
	'Use' => 'ব্যবহার',
	'No tables.' => 'কোন টেবিল নাই।',
	'select' => 'নির্বাচন',
	'Item has been deleted.' => 'বিষয়বস্তু মুছে ফেলা হয়েছে।',
	'Item has been updated.' => 'বিষয়বস্তু হালনাগাদ করা হয়েছে।',
	'Item%s has been inserted.' => 'বিষয়বস্তুসমূহ%s সংযোজন করা হয়েছে।',
	'Edit' => 'সম্পাদনা',
	'Insert' => 'সংযোজন',
	'Save and insert next' => 'সংরক্ষন ও পরবর্তী সংযোজন করুন',
	'Delete' => 'মুছে ফেলুন',
	'Database' => 'ডাটাবেজ',
	'Routines' => 'রুটিনসমূহ',
	'Indexes have been altered.' => 'সূচীসমূহ সম্পাদনা করা হয়েছে।',
	'Indexes' => 'সূচীসমূহ',
	'Alter indexes' => 'সূচীসমূহ পরিবর্তন করুন',
	'Add next' => 'পরবর্তী সংযোজন করুন',
	'Language' => 'ভাষা',
	'Select' => 'নির্বাচন',
	'New item' => 'নতুন বিষয়বস্তু',
	'Search' => 'খোঁজ',
	'Sort' => 'সাজানো',
	'descending' => 'ক্রমহ্রাস',
	'Limit' => 'সীমা',
	'No rows.' => 'কোন সারি নাই।',
	'Action' => 'ক্রিয়া',
	'edit' => 'সম্পাদনা',
	'Page' => 'পৃষ্ঠা',
	'Query executed OK, %d row(s) affected.' => array('কোয়্যারী সম্পাদন হয়েছে, %d সারি প্রভাবিত হয়েছে।', 'কোয়্যারী সম্পাদন হয়েছে, %d সারি প্রভাবিত হয়েছে।'),
	'Error in query' => 'অনুসন্ধানে ভুল আছে',
	'Execute' => 'সম্পাদন করো',
	'Table' => 'টেবিল',
	'Foreign keys' => 'ফরেন কী',
	'Triggers' => 'ট্রিগার',
	'View' => 'ভিউ',
	'Unable to select the table' => 'টেবিল নির্বাচন করতে অক্ষম',
	'Invalid CSRF token. Send the form again.' => 'অবৈধ CSRF টোকেন। ফর্মটি আবার পাঠান।',
	'Comment' => 'মন্তব্য',
	'Default values' => 'ডিফল্ট মান',
	'%d byte(s)' => array('%d বাইট', '%d বাইটসমূহ'),
	'No commands to execute.' => 'সম্পাদন করার মত কোন নির্দেশ নেই।',
	'Unable to upload a file.' => 'ফাইল আপলোড করা সম্ভব হচ্ছে না।',
	'File upload' => 'ফাইল আপলোড',
	'File uploads are disabled.' => 'ফাইল আপলোড নিষ্ক্রিয় করা আছে।',
	'Routine has been called, %d row(s) affected.' => array('রুটিন কল করা হয়েছে, %d টি সারি(সমূহ) প্রভাবিত হয়েছে।', 'রুটিন কল করা হয়েছে, %d টি সারি(সমূহ) প্রভাবিত হয়েছে।'),
	'Call' => 'কল',
	'No extension' => 'কোন এক্সটেনশান নাই',
	'None of the supported PHP extensions (%s) are available.' => 'কোন PHP সমর্থিত এক্সটেনশন (%s) পাওয়া যায় নাই।',
	'Session support must be enabled.' => 'সেশন সমর্থন সক্রিয় করা আবশ্যক।',
	'Session expired, please login again.' => 'সেশনের মেয়াদ শেষ হয়েছে, আবার লগইন করুন।',
	'Text length' => 'টেক্সট দৈর্ঘ্য',
	'Foreign key has been dropped.' => 'ফরেন কী মুছে ফেলা হয়েছে।',
	'Foreign key has been altered.' => 'ফরেন কী পরিবর্তন করা হয়েছে।',
	'Foreign key has been created.' => 'ফরেন কী তৈরী করা হয়েছে।',
	'Foreign key' => 'ফরেন কী ',
	'Target table' => 'টার্গেট টেবিল',
	'Change' => 'পরিবর্তন',
	'Source' => 'উৎস',
	'Target' => 'লক্ষ্য',
	'Add column' => 'কলাম সংযোজন করুন',
	'Alter' => 'পরিবর্তন',
	'Add foreign key' => 'ফরেন কী সংযোজন করুন',
	'ON DELETE' => 'অন ডিলিট',
	'ON UPDATE' => 'অন আপডেট',
	'Index Type' => 'সূচী-ধরণ',
	'length' => 'দৈর্ঘ্য',
	'View has been dropped.' => 'ভিউ মুছে ফেলা হয়েছে।',
	'View has been altered.' => 'ভিউ পরিবর্তন করা হয়েছে।',
	'View has been created.' => 'ভিউ তৈরী করা হয়েছে।',
	'Alter view' => 'ভিউ পরিবর্তন করুন',
	'Create view' => 'ভিউ তৈরী করুন',
	'Name' => 'নাম',
	'Process list' => 'প্রসেস তালিকা',
	'%d process(es) have been killed.' => array('%d টি প্রসেস(সমূহ) বিনষ্ট করা হয়েছে।', '%d টি প্রসেস(সমূহ) বিনষ্ট করা হয়েছে।'),
	'Kill' => 'বিনষ্ট করো',
	'Parameter name' => 'প্যারামিটারের নাম',
	'Database schema' => 'ডাটাবেজ স্কিমা',
	'Create procedure' => 'কার্যপ্রণালী তৈরী করুন',
	'Create function' => 'ফাংশন তৈরী করুন',
	'Routine has been dropped.' => 'রুটিন মুছে ফেলা হয়েছে।',
	'Routine has been altered.' => 'রুটিন পরিবর্তন করা হয়েছে।',
	'Routine has been created.' => 'রুটিন তৈরী করা হয়েছে।',
	'Alter function' => 'ফাংশন পরিবর্তন করুন',
	'Alter procedure' => 'কার্যপ্রণালী পরিবর্তন করুন',
	'Return type' => 'রিটার্ন টাইপ',
	'Add trigger' => 'ট্রিগার সংযোজন করুন',
	'Trigger has been dropped.' => 'ট্রিগার মুছে ফেলা হয়েছে।',
	'Trigger has been altered.' => 'ট্রিগার পরিবর্তন করা হয়েছে।',
	'Trigger has been created.' => 'ট্রিগার তৈরী করা হয়েছে।',
	'Alter trigger' => 'ট্রিগার পরিবর্তন করুন',
	'Create trigger' => 'ট্রিগার তৈরী করুন',
	'Time' => 'সময়',
	'Event' => 'ইভেন্ট',
	'%s version: %s through PHP extension %s' => 'ভার্সন %s: %s, %s PHP এক্সটেনশনের মধ্য দিয়ে',
	'%d row(s)' => array('%d সারি', '%d সারি সমূহ'),
	'Remove' => 'মুছে ফেলুন',
	'Are you sure?' => 'আপনি কি নিশ্চিত?',
	'Privileges' => 'প্রিভিলেজেস',
	'Create user' => 'ব্যবহারকারি তৈরী করুন',
	'User has been dropped.' => 'ব্যবহারকারি মুছে ফেলা হয়েছে।',
	'User has been altered.' => 'ব্যবহারকারি সম্পাদনা করা হয়েছে।',
	'User has been created.' => 'ব্যবহারকারি তৈরী করা হয়েছে।',
	'Hashed' => 'হ্যাশড',
	'Column' => 'কলাম',
	'Routine' => 'রুটিন',
	'Grant' => 'অনুমতি',
	'Revoke' => 'প্রত্যাহার',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'খুব বড় POST ডাটা। ডাটা সংক্ষিপ্ত করো অথবা %s কনফিগারেশন নির্দেশ বৃদ্ধি করো।',
	'Logged as: %s' => '%s হিসাবে লগড',
	'Move up' => 'উপরে স্থানান্তর',
	'Move down' => 'নীচে স্থানান্তর',
	'Functions' => 'ফাংশন সমূহ',
	'Aggregation' => 'সমষ্টি',
	'Export' => 'এক্সপোর্ট',
	'Output' => 'আউটপুট',
	'open' => 'খোলা',
	'save' => 'সংরক্ষণ',
	'Format' => 'বিন্যাস',
	'Tables' => 'টেবিলসমূহ',
	'Data' => 'ডাটা',
	'Event has been dropped.' => 'ইভেন্ট মুছে ফেলা হয়েছে।',
	'Event has been altered.' => 'ইভেন্ট সম্পাদনা করা হয়েছে।',
	'Event has been created.' => 'ইভেন্ট তৈরী করা হয়েছে।',
	'Alter event' => 'ইভেন্ট সম্পাদনা করো',
	'Create event' => 'ইভেন্ট তৈরী করো',
	'At given time' => 'প্রদত্ত সময়ে',
	'Every' => 'প্রত্যেক',
	'Events' => 'ইভেন্টসমূহ',
	'Schedule' => 'সময়সূচি',
	'Start' => 'শুরু',
	'End' => 'সমাপ্তি',
	'Status' => 'অবস্থা',
	'On completion preserve' => 'সমাপ্ত হওয়ার পর সংরক্ষন করুন',
	'Tables and views' => 'টেবিল এবং ভিউ সমূহ',
	'Data Length' => 'ডাটার দৈর্ঘ্য',
	'Index Length' => 'ইনডেক্স এর দৈর্ঘ্য',
	'Data Free' => 'তথ্য মুক্ত',
	'Collation' => 'কলোকেশন',
	'Analyze' => 'বিশ্লেষণ',
	'Optimize' => 'অপটিমাইজ',
	'Check' => 'পরীক্ষা',
	'Repair' => 'মেরামত',
	'Truncate' => 'ছাঁটাই',
	'Tables have been truncated.' => 'টেবিল ছাঁটাই করা হয়েছে।',
	'Rows' => 'সারিসমূহ',
	',' => ',',
	'0123456789' => '০১২৩৪৫৬৭৮৯',
	'Tables have been moved.' => 'টেবিল স্থানান্তর করা হয়েছে।',
	'Move to other database' => 'অন্য ডাটাবেজে স্থানান্তর করুন',
	'Move' => 'স্থানান্তর করুন',
	'Engine' => 'ইঞ্জিন',
	'Save and continue edit' => 'সংরক্ষণ করুন এবং সম্পাদনা চালিয়ে যান',
	'original' => 'প্রকৃত',
	'Tables have been dropped.' => 'টেবিলসমূহ মুছে ফেলা হয়েছে।',
	'%d item(s) have been affected.' => '%d টি বিষয়বস্তু প্রভাবিত হয়েছে।',
	'Whole result' => 'সম্পূর্ণ ফলাফল',
	'Clone' => 'ক্লোন',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'অনুমোদিত ফিল্ড এর সর্বাধিক সংখ্যা অতিক্রম করে গেছে। অনুগ্রহপূর্বক %s বৃদ্ধি করুন।',
	'Partition by' => 'পার্টিশন যার মাধ্যমে',
	'Partitions' => 'পার্টিশন',
	'Partition name' => 'পার্টিশনের নাম',
	'Values' => 'মানসমূহ',
	'%d row(s) have been imported.' => array('%d টি সারি(সমূহ) ইমপোর্ট করা হয়েছে।', '%d টি সারি(সমূহ) ইমপোর্ট করা হয়েছে।'),
	'anywhere' => 'যে কোন স্থানে',
	'Import' => 'ইমপোর্ট',
	'Stop on error' => 'ত্রুটি পেলে থেমে যান',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$6.$4.$1',
	'[yyyy]-mm-dd' => 't.m.[jjjj]',
	'History' => 'ইতিহাস',
	'Variables' => 'চলকসমূহ',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'সোর্স এবং টার্গেট কলামে একই ডাটা টাইপ থাকতে হবে, টার্গেট কলামসমূহে একটি সূচী এবং রেফারেন্সড ডেটার উপস্থিতি থাকা আবশ্যক।',
	'Relations' => 'সম্পর্ক',
	'Run file' => 'ফাইল চালাও',
	'Clear' => 'সাফ করো',
	'Maximum allowed file size is %sB.' => 'সর্বাধিক অনুমোদিত ফাইল সাইজ %sB।',
	'Numbers' => 'সংখ্যা',
	'Date and time' => 'তারিখ এবং সময়',
	'Strings' => 'স্ট্রিং',
	'Binary' => 'বাইনারি',
	'Lists' => 'তালিকা',
	'Editor' => 'সম্পাদক',
	'Webserver file %s' => 'ওয়েবসার্ভার ফাইল %s',
	'File does not exist.' => 'ফাইলটির কোন অস্তিত্ব নেই।',
	'%d in total' => 'সর্বমোটঃ %d টি',
	'Permanent login' => 'স্থায়ী লগইন',
	'Databases have been dropped.' => 'ডাটাবেজসমূহ মুছে ফেলা হয়েছে।',
	'Search data in tables' => 'টেবিলে তথ্য খুঁজুন',
	'Schema' => 'স্কিমা',
	'Alter schema' => 'স্কিমা পরিবর্তন করো',
	'Create schema' => 'স্কিমা তৈরী করো',
	'Schema has been dropped.' => 'স্কিমা মুছে ফেলা হয়েছে।',
	'Schema has been created.' => 'স্কিমা তৈরি করা হয়েছে।',
	'Schema has been altered.' => 'স্কিমা সম্পাদনা করা হয়েছে।',
	'Sequences' => 'অনুক্রম',
	'Create sequence' => 'অনুক্রম তৈরি করো',
	'Alter sequence' => 'অনুক্রম সম্পাদনা করো',
	'Sequence has been dropped.' => 'অনুক্রম মুছে ফেলা হয়েছে।',
	'Sequence has been created.' => 'অনুক্রম তৈরি করা হয়েছে।',
	'Sequence has been altered.' => 'অনুক্রম সম্পাদনা করা হয়েছে।',
	'User types' => 'ব্যবহারকারির ধরণ',
	'Create type' => 'ধরণ তৈরী করুন',
	'Alter type' => 'ধরণ পরিবর্তন করুন',
	'Type has been dropped.' => 'ধরণ মুছে ফেলা হয়েছে।',
	'Type has been created.' => 'ধরণ তৈরি করা হয়েছে।',
	'Use edit link to modify this value.' => 'এই মানটি পরিবর্তনের জন্য সম্পাদনা লিঙ্ক ব্যবহার করুন।',
	'last' => 'সর্বশেষ',
	'From server' => 'সার্ভার থেকে',
	'System' => 'সিস্টেম',
	'Select data' => 'তথ্য নির্বাচন করো',
	'Show structure' => 'গঠন দেখান',
	'empty' => 'খালি',
	'Network' => 'নেটওয়ার্ক',
	'Geometry' => 'জ্যামিতি',
	'File exists.' => 'ফাইল রয়েছে।',
	'%d query(s) executed OK.' => array('SQL-অনুসন্ধান সফলভাবে সম্পন্ন হয়েছে।', '%d SQL-অনুসন্ধানসমূহ সফলভাবে সম্পন্ন হয়েছে।'),
	'Show only errors' => 'শুধুমাত্র ত্রুটিগুলো দেখান',
	'Refresh' => 'রিফ্রেশ',
	'Invalid schema.' => 'অবৈধ স্কিমা।',
	'Please use one of the extensions %s.' => 'কোন একটা এক্সটেনশন %s ব্যবহার করুন।',
	'now' => 'এখন',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'টেবিলগুলো কপি করা হয়েছে।',
	'Copy' => 'কপি',
	'Permanent link' => 'স্থায়ী লিংক',
	'Edit all' => 'সবগুলো সম্পাদনা করুন',
	'HH:MM:SS' => 'HH:MM:SS',
);

// run `php ../../lang.php bn` to update this file
