<?php
namespace Adminer;

Lang::$translations = array(
	'Login' => 'התחברות',
	'Logout successful.' => 'ההתחברות הצליחה',
	'Invalid credentials.' => 'פרטי התחברות שגויים',
	'Server' => 'שרת',
	'Username' => 'שם משתמש',
	'Password' => 'סיסמה',
	'Select database' => 'בחר מסד נתונים',
	'Invalid database.' => 'מסד נתונים שגוי',
	'Table has been dropped.' => 'הטבלה הושלכה',
	'Table has been altered.' => 'הטבלה שונתה',
	'Table has been created.' => 'הטבלה נוצרה',
	'Alter table' => 'שנה טבלה',
	'Create table' => 'צור טבלה',
	'Table name' => 'שם הטבלה',
	'engine' => 'מנוע',
	'collation' => 'קולקציה',
	'Column name' => 'שם עמודה',
	'Type' => 'סוג',
	'Length' => 'אורך',
	'Auto Increment' => 'הגדלה אוטומטית',
	'Options' => 'אפשרויות',
	'Save' => 'שמור',
	'Drop' => 'השלך',
	'Database has been created.' => 'מסד הנתונים נוצר',
	'Database has been renamed.' => 'שם מסד הנתונים שונה',
	'Database has been altered.' => 'מסד הנתונים שונה',
	'Alter database' => 'שנה מסד נתונים',
	'Create database' => 'צור מסד נתונים',
	'SQL command' => 'שאילתת SQL',
	'Logout' => 'התנתק',
	'Use' => 'השתמש',
	'No tables.' => 'אין טבלאות',
	'select' => 'בחר',
	'Item has been deleted.' => 'הפריט נמחק',
	'Item has been updated.' => 'הפריט עודכן',
	'Edit' => 'ערוך',
	'Insert' => 'הכנס',
	'Save and insert next' => 'שמור והמשך להכניס',
	'Delete' => 'מחק',
	'Database' => 'מסד נתונים',
	'Routines' => 'רוטינות',
	'Indexes have been altered.' => 'האינדקסים שונו',
	'Indexes' => 'אינדקסים',
	'Alter indexes' => 'שנה אינדקסים',
	'Add next' => 'הוסף הבא',
	'Language' => 'שפה',
	'Select' => 'בחר',
	'New item' => 'פריט חדש',
	'Search' => 'חפש',
	'Sort' => 'מיין',
	'descending' => 'סדר הפוך',
	'Limit' => 'הגבל',
	'No rows.' => 'אין שורות',
	'Action' => 'פעולות',
	'edit' => 'ערוך',
	'Page' => 'עמוד',
	'Query executed OK, %d row(s) affected.' => 'השאילתה בוצעה כהלכה, %d שורות הושפעו',
	'Error in query' => 'שגיאה בשאילתה',
	'Execute' => 'הרץ',
	'Table' => 'טבלה',
	'Foreign keys' => 'מפתחות זרים',
	'Triggers' => 'מפעילים',
	'View' => 'הצג',
	'Unable to select the table' => 'בחירת הטבלה נכשלה',
	'Invalid CSRF token. Send the form again.' => 'כשל באבטחת נתונים, שלח טופס שוב',
	'Comment' => 'הערה',
	'Default values' => 'ערכי ברירת מחדל',
	'%d byte(s)' => '%d בתים',
	'No commands to execute.' => 'לא נמצאו פקודות להרצה',
	'Unable to upload a file.' => 'העלאת הקובץ נכשלה',
	'File upload' => 'העלה קובץ',
	'File uploads are disabled.' => 'העלאת קבצים מבוטלת',
	'Routine has been called, %d row(s) affected.' => 'הרוטינה נקראה, %d שורות הושפעו',
	'Call' => 'קרא',
	'No extension' => 'אין תוסף',
	'None of the supported PHP extensions (%s) are available.' => 'שום תוסף PHP (%s) זמין',
	'Session support must be enabled.' => 'חובה להפעיל תמיכה בסשן',
	'Session expired, please login again.' => 'תם זמן ההפעלה, אנא התחבר שוב',
	'Text length' => 'אורך הטקסט',
	'Foreign key has been dropped.' => 'המפתח הזר הושלך',
	'Foreign key has been altered.' => 'המפתח הזר שונה',
	'Foreign key has been created.' => 'המפתח הזר נוצר',
	'Foreign key' => 'מפתח זר',
	'Target table' => 'טבלת יעד',
	'Change' => 'שנה',
	'Source' => 'מקור',
	'Target' => 'יעד',
	'Add column' => 'הוסף עמודה',
	'Alter' => 'שנה',
	'Add foreign key' => 'הוסף מפתח זר',
	'ON DELETE' => 'בעת מחיקה',
	'ON UPDATE' => 'בעת עידכון',
	'Index Type' => 'סוג אינדקס',
	'length' => 'אורך',
	'View has been dropped.' => 'התצוגה הושלכה',
	'View has been altered.' => 'התצוגה שונתה',
	'View has been created.' => 'התצוגה נוצרה',
	'Alter view' => 'שנה תצוגה',
	'Create view' => 'צור תצוגה',
	'Name' => 'שם',
	'Process list' => 'רשימת תהליכים',
	'%d process(es) have been killed.' => '%d תהליכים חוסלו',
	'Kill' => 'חסל',
	'Parameter name' => 'שם הפרמטר',
	'Database schema' => 'סכמת מסד נתונים',
	'Create procedure' => 'צור פרוצדורה',
	'Create function' => 'צור פונקציה',
	'Routine has been dropped.' => 'הרוטינה הושלכה',
	'Routine has been altered.' => 'הרוטינה שונתה',
	'Routine has been created.' => 'הרוטינה נוצרה',
	'Alter function' => 'שנה פונקציה',
	'Alter procedure' => 'שנה פרוצדורה',
	'Return type' => 'סוג ערך מוחזר',
	'Add trigger' => 'הוסף טריגר',
	'Trigger has been dropped.' => 'הטריגר הושלך',
	'Trigger has been altered.' => 'הטריגר שונה',
	'Trigger has been created.' => 'הטריגר נוצר',
	'Alter trigger' => 'שנה טריגר',
	'Create trigger' => 'צור טריגר',
	'Time' => 'זמן',
	'Event' => 'אירוע',
	'%d row(s)' => '%d שורות',
	'Remove' => 'הסר',
	'Are you sure?' => 'האם אתה בטוח?',
	'Privileges' => 'פריווילגיות',
	'Create user' => 'צור משתמש',
	'User has been dropped.' => 'המשתמש הושלך',
	'User has been altered.' => 'המשתמש שונה',
	'User has been created.' => 'המשתמש נוצר',
	'Hashed' => 'הצפנה',
	'Column' => 'עמודה',
	'Routine' => 'רוטינה',
	'Grant' => 'הענק',
	'Revoke' => 'שלול',
	'%s version: %s through PHP extension %s' => '%s גרסה: %s דרך תוסף PHP %s',
	'Logged as: %s' => 'מחובר כ: %s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'מידע גדול מידי נשלח ב-POST. הקטן את את המידע הוא הגדלת את הגדרות ה-%s',
	'Move up' => 'הזז למעלה',
	'Move down' => 'הזז למטה',
	'Export' => 'יצא',
	'Tables' => 'טבלאות',
	'Data' => 'נתונים',
	'Output' => 'פלט',
	'open' => 'פתח',
	'save' => 'שמור',
	'Format' => 'פורמט',
	'Functions' => 'פונקציות',
	'Aggregation' => 'צבירה',
	'Event has been dropped.' => 'האירוע הושלך',
	'Event has been altered.' => 'האירוע שונה',
	'Event has been created.' => 'האירוע נוצר',
	'Alter event' => 'שנה אירוע',
	'Create event' => 'צור אירוע',
	'Start' => 'התחלה',
	'End' => 'סיום',
	'Every' => 'כל',
	'Status' => 'סטטוס',
	'On completion preserve' => 'בעת סיום שמור',
	'Events' => 'אירועים',
	'Schedule' => 'תזמן',
	'At given time' => 'לפי זמן נתון',
	'Save and continue edit' => 'שמור והמשך לערוך',
	'original' => 'מקורי',
	'Tables have been truncated.' => 'הטבלה קוצרה',
	'Tables have been moved.' => 'הטבלה הועברה',
	'Tables have been dropped.' => 'הטבלה הושלכה',
	'Tables and views' => 'טבלאות ותצוגות',
	'Engine' => 'מנוע',
	'Collation' => 'קולקציה',
	'Data Length' => 'אורך נתונים',
	'Index Length' => 'אורך אינדקס',
	'Data Free' => 'נתונים משוחררים',
	'Rows' => 'שורות',
	',' => ',',
	'0123456789' => '0123456789',
	'Analyze' => 'נתח',
	'Optimize' => 'יעל',
	'Check' => 'בדוק',
	'Repair' => 'תקן',
	'Truncate' => 'קצר',
	'Move to other database' => 'העבר למסד נתונים אחר',
	'Move' => 'העבר',
	'%d item(s) have been affected.' => '%d פריטים הושפעו',
	'Whole result' => 'כל התוצאות',
	'Clone' => 'שכפל',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'הגעת למספר השדות המרבי. בבקשה הגדל את %s',
	'Partition by' => 'מחיצות ע"י',
	'Partitions' => 'מחיצות',
	'Partition name' => 'שם מחיצה',
	'Values' => 'ערכים',
	'%d row(s) have been imported.' => '%d שורות יובאו',
	'anywhere' => 'בכל מקום',
	'Import' => 'יבא',
	'Stop on error' => 'עצור בעת שגיאה',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$1-$3-$5',
	'[yyyy]-mm-dd' => '[yyyy]-mm-dd',
	'History' => 'היסטוריה',
	'Variables' => 'משתנים',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'על עמודות המקור והיעד להיות מאותו טיפוס נתונים, חובה שיהיה אינדקס בעמודת היעד ושהמידע המתאים יהיה קיים',
	'Relations' => 'הקשרים',
	'Run file' => 'הרץ קובץ',
	'Clear' => 'נקה',
	'Maximum allowed file size is %sB.' => 'גודל מקסימלאי להעלאה: %sB',
	'Numbers' => 'מספרים',
	'Date and time' => 'תאריך ושעה',
	'Strings' => 'מחרוזות',
	'Binary' => 'בינארי',
	'Lists' => 'רשימות',
	'Editor' => 'עורך',
	'Webserver file %s' => 'קובץ השרת %s',
	'File does not exist.' => 'הקובץ אינו קיים',
	'%d in total' => '%d בסך הכל',
	'Permanent login' => 'התחבר לצמיתות',
	'Databases have been dropped.' => 'מסד הנתונים הושלך',
	'Database has been dropped.' => 'מסד הנתונים הושלך',
	'Search data in tables' => 'חפש מידע בטבלאות',
	'Schema' => 'סכמה',
	'Alter schema' => 'שנה סכמה',
	'Create schema' => 'צור סכמה',
	'Schema has been dropped.' => 'הסכמה הושלכה',
	'Schema has been created.' => 'הסכמה נוצרה',
	'Schema has been altered.' => 'הסכמה שונתה',
	'Sequences' => 'סדרות',
	'Create sequence' => 'צור סדרה',
	'Alter sequence' => 'שנה סדרה',
	'Sequence has been dropped.' => 'הסדרה הושלכה',
	'Sequence has been created.' => 'הסדרה נוצרה',
	'Sequence has been altered.' => 'הסדרה שונתה',
	'User types' => 'סוגי משתמשים',
	'Create type' => 'צור סוג',
	'Alter type' => 'שנה סוג',
	'Type has been dropped.' => 'הסוג הושלך',
	'Type has been created.' => 'הסוג נוצר',
	'Use edit link to modify this value.' => 'השתמש בקישור העריכה בשביל לשנות את הערך',
	'last' => 'אחרון',
	'From server' => 'משרת',
	'System' => 'מערכת',
	'Select data' => 'בחר נתונים',
	'Show structure' => 'הראה מבנה',
	'empty' => 'ריק',
	'Network' => 'רשת',
	'Geometry' => 'גיאומטריה',
	'File exists.' => 'קובץ קיים',
	'Item%s has been inserted.' => 'הפריט %s הוזן בהצלחה',
	'now' => 'כעת',
	'%d query(s) executed OK.' => '%d שאילתות בוצעו בהצלחה',
	'Show only errors' => 'הראה שגיאות בלבד',
	'Refresh' => 'רענן',
	'Invalid schema.' => 'סכמה שגויה',
	'Please use one of the extensions %s.' => 'בבקשה השתמש באחד מהתוספים %s',
	'ltr' => 'rtl',
	'Tables have been copied.' => 'הטבלה הועתקה',
	'Copy' => 'העתק',
	'Permanent link' => 'קישור סופי',
	'Edit all' => 'ערוך הכל',
	'HH:MM:SS' => 'HH:MM:SS',
	'Tables have been optimized.' => 'הטבלאות עברו אופטימיזציה',
	'Materialized view' => 'תצוגת מימוש ',
	'Vacuum' => 'וואקום',
	'Selected' => 'נבחרים',
	'Ctrl+click on a value to modify it.' => 'לחץ ctrl + לחיצת עכבר לערוך ערך זה',
	'File must be in UTF-8 encoding.' => 'על הקובץ להיות בקידוד utf-8',
	'Modify' => 'ערוך',
	'Loading' => 'טוען',
	'Load more data' => 'טען נתונים נוספים',
	'ATTACH queries are not supported.' => 'שאילתת ATTACH אינה נתמכת',
	'%d / ' => '%d / ',
	'Limit rows' => 'הגבל שורות',
	'Default value' => 'ערך ברירת מחדל',
	'Full table scan' => 'סריקה טבלה מלאה',
	'Too many unsuccessful logins, try again in %d minute(s).' => 'יותר מידי נסיונות כניסה נכשלו, אנא נסה עוד %d דקות',
	'Thanks for using Adminer, consider <a href="https://www.adminer.org/en/donation/">donating</a>.' => 'תודה שהשתמש ב-adminer אנא שקול <a href="https://www.adminer.org/en/donation/">לתרום</a>',
	'Master password expired. <a href="https://www.adminer.org/en/extension/"%s>Implement</a> %s method to make it permanent.' => 'סיסמת המאסטר פגה <a href="https://www.adminer.org/en/extension/"%s>התקן תוסף</a> על מנת להפוך את זה לתמידי',
	'If you did not send this request from Adminer then close this page.' => 'אם לא אתה שלחת בקשה ל-Adminer הינך יכול לסגור חלון זה',
	'You can upload a big SQL file via FTP and import it from server.' => 'ניתן לעלות קבצים ב-FTP ואז למשוך אותם מהשרת',
	'Size' => 'גודל',
	'Compute' => 'חישוב',
	'You are offline.' => 'הינך לא מקוון',
	'You have no privileges to update this table.' => 'אין לך ההרשאות המתאימות לעדכן טבלה זו',
	'Saving' => 'שומר',
	'yes' => 'כן',
	'no' => 'לא',
);

// run `php ../../lang.php he` to update this file
