<?php
namespace Adminer;

Lang::$translations = array(
	'Login' => 'நுழை',
	'Logout successful.' => 'வெற்றிக‌ர‌மாய் வெளியேறியாயிற்று.',
	'Invalid credentials.' => 'ச‌ரியான‌ விப‌ர‌ங்க‌ள் இல்லை.',
	'Server' => 'வ‌ழ‌ங்கி (Server)',
	'Username' => 'ப‌ய‌னாள‌ர் (User)',
	'Password' => 'க‌ட‌வுச்சொல்',
	'Select database' => 'த‌க‌வ‌ல்த‌ள‌த்தை தேர்வு செய்',
	'Invalid database.' => 'த‌க‌வ‌ல்த‌ள‌ம் ச‌ரியானதல்ல‌.',
	'Table has been dropped.' => 'அட்ட‌வ‌ணை நீக்க‌ப்ப‌ட்ட‌து.',
	'Table has been altered.' => 'அட்ட‌வணை மாற்ற‌ப்ப‌ட்ட‌து.',
	'Table has been created.' => 'அட்ட‌வ‌ணை உருவாக்க‌ப்ப‌ட்ட‌து.',
	'Alter table' => 'அட்ட‌வ‌ணையை மாற்று',
	'Create table' => 'அட்ட‌வ‌ணையை உருவாக்கு',
	'Table name' => 'அட்ட‌வ‌ணைப் பெய‌ர்',
	'engine' => 'எஞ்சின்',
	'collation' => 'கொலேச‌ன்',
	'Column name' => 'நெடுவ‌ரிசையின் பெய‌ர்',
	'Type' => 'வ‌கை',
	'Length' => 'நீளம்',
	'Auto Increment' => 'ஏறுமான‌ம்',
	'Options' => 'வேண்டிய‌வ‌ற்றை ',
	'Save' => 'சேமி',
	'Drop' => 'நீக்கு',
	'Database has been dropped.' => 'த‌க‌வ‌ல்த‌ள‌ம் நீக்க‌ப்ப‌ட்ட‌து.',
	'Database has been created.' => 'த‌க‌வ‌ல்த‌ள‌ம் உருவாக்க‌ப்ப‌ட்ட‌து.',
	'Database has been renamed.' => 'த‌க‌வ‌ல்த‌ள‌ம் பெய‌ர் மாற்ற‌ப்ப‌ட்ட‌து.',
	'Database has been altered.' => 'த‌க‌வ‌ல்த‌ள‌ம் மாற்ற‌ப்ப‌ட்ட‌து.',
	'Alter database' => 'த‌க‌வ‌ல்த‌ள‌த்தை மாற்று',
	'Create database' => 'த‌க‌வ‌ல்த‌ள‌த்தை உருவாக்கு',
	'SQL command' => 'SQL க‌ட்ட‌ளை',
	'Logout' => 'வெளியேறு',
	'Use' => 'உப‌யோகி',
	'No tables.' => 'அட்ட‌வ‌ணை இல்லை.',
	'select' => 'தேர்வு செய்',
	'Item has been deleted.' => 'உருப்படி நீக்க‌ப்ப‌ட்ட‌து.',
	'Item has been updated.' => 'உருப்ப‌டி புதுப்பிக்க‌ப்ப‌ட்ட‌து.',
	'Edit' => 'தொகு',
	'Insert' => 'புகுத்து',
	'Save and insert next' => 'சேமித்த‌ப் பின் அடுத்த‌தை புகுத்து',
	'Delete' => 'நீக்கு',
	'Database' => 'த‌க‌வ‌ல்த‌ள‌ம்',
	'Routines' => 'ரொட்டீன் ',
	'Indexes have been altered.' => 'அக‌வ‌ரிசைக‌ள் (Indexes) மாற்ற‌ப்பட்ட‌து.',
	'Indexes' => 'அக‌வ‌ரிசைக‌ள் (Index) ',
	'Alter indexes' => 'அக‌வ‌ரிசையை (Index) மாற்று',
	'Add next' => 'அடுத்த‌தை சேர்க்க‌வும்',
	'Language' => 'மொழி',
	'Select' => 'தேர்வு செய்',
	'New item' => 'புதிய‌ உருப்ப‌டி',
	'Search' => 'தேடு',
	'Sort' => 'த‌ர‌ம் பிரி',
	'descending' => 'இற‌ங்குமுக‌மான‌',
	'Limit' => 'வ‌ர‌ம்பு',
	'No rows.' => 'வ‌ரிசை இல்லை.',
	'Action' => 'செய‌ல்',
	'edit' => 'தொகு',
	'Page' => 'ப‌க்க‌ம்',
	'Query executed OK, %d row(s) affected.' => array('வின‌வ‌ல் செய‌ல்ப‌டுத்த‌ப்ப‌ட்ட‌து, %d வ‌ரிசை மாற்ற‌ப்ப‌ட்ட‌து.', 'வின‌வ‌ல் செய‌ல்ப‌டுத்த‌ப்ப‌ட்ட‌து, %d வ‌ரிசைக‌ள் மாற்றப்ப‌ட்ட‌ன‌.'),
	'Error in query' => 'வின‌வ‌லில் த‌வ‌றுள்ள‌து',
	'Execute' => 'செய‌ல்ப‌டுத்து',
	'Table' => 'அட்ட‌வ‌ணை',
	'Foreign keys' => 'வேற்று விசைக‌ள்',
	'Triggers' => 'தூண்டுத‌ல்க‌ள்',
	'View' => 'தோற்றம்',
	'Unable to select the table' => 'அட்ட‌வ‌ணையை தேர்வு செய்ய‌ முடிய‌வில்லை',
	'Invalid CSRF token. Send the form again.' => 'CSRF டோக்க‌ன் செல்லாது. ப‌டிவ‌த்தை மீண்டும் அனுப்ப‌வும்.',
	'Comment' => 'குறிப்பு',
	'Default values' => 'உள்ளிருக்கும் (Default) ம‌திப்புக‌ள் ',
	'%d byte(s)' => array('%d பைட்', '%d பைட்டுக‌ள்'),
	'No commands to execute.' => 'செய‌ல் ப‌டுத்த‌ எந்த‌ க‌ட்ட‌ளைக‌ளும் இல்லை.',
	'Unable to upload a file.' => 'கோப்பை மேலேற்ற‌ம் (upload) செய்ய‌ இயல‌வில்லை.',
	'File upload' => 'கோப்பை மேலேற்று (upload) ',
	'File uploads are disabled.' => 'கோப்புக‌ள் மேலேற்றம் (upload)முட‌க்க‌ப்ப‌ட்டுள்ள‌ன‌.',
	'Routine has been called, %d row(s) affected.' => array('ரொட்டீன்க‌ள் அழைக்க‌ப்பட்டுள்ள‌ன‌, %d வ‌ரிசை மாற்ற‌ம் அடைந்த‌து.', 'ரொட்டீன்க‌ள் அழைக்க‌ப்ப‌ட்டுள்ள‌ன‌, %d வ‌ரிசைக‌ள் மாற்றம் அடைந்துள்ள‌ன‌.'),
	'Call' => 'அழை',
	'None of the supported PHP extensions (%s) are available.' => 'PHP ஆத‌ர‌வு விரிவுக‌ள் (%s) இல்லை.',
	'Session support must be enabled.' => 'செஷ‌ன் ஆத‌ர‌வு இய‌க்க‌ப்ப‌ட‌ வேண்டும்.',
	'Session expired, please login again.' => 'செஷ‌ன் காலாவ‌தியாகி விட்ட‌து. மீண்டும் நுழைய‌வும்.',
	'Text length' => 'உரை நீள‌ம்',
	'Foreign key has been dropped.' => 'வேற்று விசை நீக்க‌ப்ப‌ட்ட‌து.',
	'Foreign key has been altered.' => 'வேற்று விசை மாற்ற‌ப்ப‌ட்ட‌து.',
	'Foreign key has been created.' => 'வேற்று விசை உருவாக்க‌ப்ப‌ட்ட‌து.',
	'Foreign key' => 'வேற்று விசை',
	'Target table' => 'அட்ட‌வ‌ணை இல‌க்கு',
	'Change' => 'மாற்று',
	'Source' => 'மூல‌ம்',
	'Target' => 'இல‌க்கு',
	'Add column' => 'நெடு வ‌ரிசையை சேர்க்க‌வும்',
	'Alter' => 'மாற்று',
	'Add foreign key' => 'வேற்று விசை சேர்க்க‌வும்',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'அக‌வ‌ரிசை வ‌கை (Index Type)',
	'length' => 'நீள‌ம்',
	'View has been dropped.' => 'தோற்ற‌ம் நீக்க‌ப்ப‌ட்ட‌து.',
	'View has been altered.' => 'தோற்றம் மாற்றப்ப‌ட்ட‌து.',
	'View has been created.' => 'தோற்ற‌ம் உருவாக்க‌ப்ப‌ட்ட‌து.',
	'Alter view' => 'தோற்ற‌த்தை மாற்று',
	'Create view' => 'தோற்றத்தை உருவாக்கு',
	'Name' => 'பெய‌ர்',
	'Process list' => 'வேலைக‌ளின் ப‌ட்டி',
	'%d process(es) have been killed.' => array('%d வேலை வ‌லுவில் நிறுத்த‌ப‌ட்ட‌து.', '%d வேலைக‌ள் வ‌லுவில் நிறுத்த‌ப‌ட்ட‌ன‌.'),
	'Kill' => 'வ‌லுவில் நிறுத்து',
	'Parameter name' => 'அள‌புரு (Parameter) பெய‌ர்',
	'Database schema' => 'த‌க‌வ‌ல்த‌ள‌ அமைப்பு முறைக‌ள்',
	'Create procedure' => 'செய்முறையை உருவாக்கு',
	'Create function' => 'Function உருவாக்கு',
	'Routine has been dropped.' => 'ரொட்டீன் நீக்க‌ப்ப‌ட்ட‌து.',
	'Routine has been altered.' => 'ரொட்டீன் மாற்ற‌ப்ப‌ட்டது.',
	'Routine has been created.' => 'ரொட்டீன் உருவாக்க‌ப்ப‌ட்ட‌து.',
	'Alter function' => 'Function மாற்று',
	'Alter procedure' => 'செய‌ல்முறையை மாற்று',
	'Return type' => 'திரும்பு வ‌கை',
	'Add trigger' => 'தூண்டு விசையை சேர்',
	'Trigger has been dropped.' => 'தூண்டு விசை நீக்க‌ப்ப‌ட்ட‌து.',
	'Trigger has been altered.' => 'தூண்டு விசை மாற்ற‌ப்ப‌ட்ட‌து.',
	'Trigger has been created.' => 'தூண்டு விசை உருவாக்க‌ப்ப‌ட்ட‌து.',
	'Alter trigger' => 'தூண்டு விசையை மாற்று',
	'Create trigger' => 'தூண்டு விசையை உருவாக்கு',
	'Time' => 'நேர‌ம்',
	'Event' => 'நிக‌ழ்ச்சி',
	'%d row(s)' => array('%d வ‌ரிசை', '%d வ‌ரிசைக‌ள்'),
	'Remove' => 'நீக்கு',
	'Are you sure?' => 'நிச்ச‌ய‌மாக‌ ?',
	'Privileges' => 'ச‌லுகைக‌ள் / சிற‌ப்புரிமைக‌ள்',
	'Create user' => 'ப‌ய‌னாள‌ரை உருவாக்கு',
	'User has been dropped.' => 'ப‌யனீட்டாள‌ர் நீக்க‌ப்ப‌ட்டார்.',
	'User has been altered.' => 'ப‌யனீட்டாள‌ர் மாற்றப்ப‌ட்டார்.',
	'User has been created.' => 'ப‌ய‌னீட்டாள‌ர் உருவாக்க‌ப்ப‌ட்ட‌து.',
	'Hashed' => 'Hashed',
	'Column' => 'நெடுவ‌ரிசை',
	'Routine' => 'ரொட்டீன்',
	'Grant' => 'அனும‌திய‌ளி',
	'Revoke' => 'இர‌த்துச்செய்',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'மிக‌ அதிக‌மான‌ POST த‌க‌வ‌ல். த‌க‌வ‌லை குறைக்க‌வும் அல்ல‌து %s வ‌டிவ‌மைப்பை (configuration directive) மாற்ற‌வும்.',
	'Logged as: %s' => 'ப‌ய‌னாளர்: %s',
	'Move up' => 'மேலே ந‌க‌ர்த்து',
	'Move down' => 'கீழே நக‌ர்த்து',
	'Functions' => 'Functions',
	'Aggregation' => 'திர‌ள்வு (Aggregation)',
	'Export' => 'ஏற்றும‌தி',
	'Output' => 'வெளியீடு',
	'open' => 'திற‌',
	'save' => 'சேமி',
	'Format' => 'ஃபார்ம‌ட் (Format)',
	'Tables' => 'அட்ட‌வ‌ணை',
	'Data' => 'த‌க‌வ‌ல்',
	'Event has been dropped.' => 'நிக‌ழ்ச்சி (Event) நீக்க‌ப்ப‌ட்ட‌து.',
	'Event has been altered.' => 'நிக‌ழ்ச்சி (Event) மாற்றப்ப‌ட்ட‌து.',
	'Event has been created.' => 'நிக‌ழ்ச்சி (Event) உருவாக்க‌‌ப்ப‌ட்ட‌து.',
	'Alter event' => 'நிக‌ழ்ச்சியை (Event) மாற்று',
	'Create event' => 'நிக‌ழ்ச்சியை (Event) உருவாக்கு',
	'At given time' => 'குறித்த‌ நேர‌த்தில்',
	'Every' => 'ஒவ்வொரு',
	'Events' => 'நிக‌ழ்ச்சிக‌ள்',
	'Schedule' => 'கால‌ அட்ட‌வ‌ணை',
	'Start' => 'தொட‌ங்கு',
	'End' => 'முடி (வு)',
	'Status' => 'நிக‌ழ்நிலை (Status)',
	'On completion preserve' => 'முடிந்த‌தின் பின் பாதுகாக்க‌வும்',
	'Tables and views' => 'அட்ட‌வ‌ணைக‌ளும் பார்வைக‌ளும்',
	'Data Length' => 'த‌க‌வ‌ல் நீள‌ம்',
	'Index Length' => 'Index நீள‌ம்',
	'Data Free' => 'Data Free',
	'Collation' => 'கொலேச‌ன்',
	'Analyze' => 'நுணுகி ஆராய‌வும்',
	'Optimize' => 'உக‌ப்பாக்கு (Optimize)',
	'Check' => 'ப‌ரிசோதி',
	'Repair' => 'ப‌ழுது பார்',
	'Truncate' => 'குறை (Truncate)',
	'Tables have been truncated.' => 'அட்ட‌வ‌ணை குறைக்க‌ப்ப‌ட்ட‌து (truncated).',
	'Rows' => 'வ‌ரிசைக‌ள்',
	',' => ',',
	'0123456789' => '0123456789',
	'Tables have been moved.' => 'அட்ட‌வ‌ணை ந‌க‌ர்த்த‌ப்ப‌ட்ட‌து.',
	'Move to other database' => 'ம‌ற்ற‌ த‌க‌வ‌ல் தள‌த்திற்க்கு ந‌க‌ர்த்து',
	'Move' => 'ந‌க‌ர்த்து',
	'Engine' => 'எஞ்சின் (Engine)',
	'Save and continue edit' => 'சேமித்த‌ பிற‌கு தொகுப்ப‌தை தொட‌ர‌வும்',
	'original' => 'அச‌ல்',
	'Tables have been dropped.' => 'அட்ட‌வ‌ணை நீக்க‌ப்ப‌ட்ட‌து.',
	'%d item(s) have been affected.' => array('%d உருப்ப‌டி மாற்ற‌ம‌டைந்தது.', '%d உருப்ப‌டிக‌ள் மாற்ற‌ம‌டைந்த‌ன‌.'),
	'Whole result' => 'முழுமையான‌ முடிவு',
	'Clone' => 'ந‌க‌லி (Clone)',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'அனும‌திக்க‌ப்ப‌ட்ட‌ அதிக‌ப‌ட்ச‌ கோப்புக‌ளின் எண்ணிக்கை மீற‌ப்ப‌ட்ட‌து. த‌ய‌வு செய்து %s ம‌ற்றும் %s யை அதிக‌ரிக்க‌வும்.',
	'Partition by' => 'பிரித்த‌து',
	'Partitions' => 'பிரிவுக‌ள்',
	'Partition name' => 'பிரிவின் பெய‌ர்',
	'Values' => 'ம‌திப்புக‌ள்',
	'%d row(s) have been imported.' => array('%d வ‌ரிசை இற‌க்கும‌தி (Import) செய்ய‌ப்ப‌ட்ட‌து.', '%d வ‌ரிசைக‌ள் இற‌க்கும‌தி (Import) செய்ய‌ப்ப‌ட்டன‌.'),
	'Show structure' => 'க‌ட்ட‌மைப்பை காண்பிக்க‌வும்',
	'Import' => 'இற‌க்கும‌தி (Import)',
	'Stop on error' => 'பிழை ஏற்ப‌டின் நிற்க‌',
	'Select data' => 'த‌க‌வ‌லை தேர்வு செய்',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'dd/mm/[yyyy]',
	'History' => 'வ‌ர‌லாறு',
	'Variables' => 'மாறிலிக‌ள் (Variables)',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'இல‌க்கு நெடுவ‌ரிசையில் அக‌வ‌ரிசை (Index) ம‌ற்றும் குறிக்க‌ப்ப‌ட்ட‌ த‌க‌வல் (Referenced DATA) க‌ண்டிப்பாக‌ இருத்த‌ல் வேண்டும். மூல‌ நெடுவ‌ரிசை ம‌ற்றும் இலக்கு நெடுவ‌ரிசையின் த‌க‌வ‌ல் வ‌டிவ‌ம் (DATA TYPE) ஒன்றாக‌ இருக்க‌ வேண்டும்.',
	'Relations' => 'உற‌வுக‌ள் (Relations)',
	'Run file' => 'கோப்பினை இய‌க்க‌வும்',
	'Clear' => 'துடை (Clear)',
	'Maximum allowed file size is %sB.' => 'கோப்பின் அதிக‌ப‌ட்ச‌ அள‌வு %sB.',
	'Numbers' => 'எண்க‌ள்',
	'Date and time' => 'தேதி ம‌ற்றும் நேர‌ம்',
	'Strings' => 'ச‌ர‌ம் (String)',
	'Binary' => 'பைன‌ரி',
	'Lists' => 'ப‌ட்டிய‌ல்',
	'Editor' => 'தொகுப்பாளர்',
	'Webserver file %s' => 'வெப் ச‌ர்வ‌ர் கோப்பு %s',
	'File does not exist.' => 'கோப்பு இல்லை.',
	'%d in total' => 'மொத்தம் %d ',
	'Permanent login' => 'நிர‌ந்த‌ர‌மாக‌ நுழைய‌வும்',
	'Schema' => 'அமைப்புமுறை',
	'Alter schema' => 'அமைப்புமுறையை மாற்று',
	'Create schema' => 'அமைப்புமுறையை உருவாக்கு',
	'Search data in tables' => 'த‌க‌வ‌லை அட்ட‌வ‌ணையில் தேடு',
	'Sequences' => 'வ‌ரிசைமுறை',
	'Create sequence' => 'வ‌ரிசைமுறையை உருவாக்கு',
	'User types' => 'ப‌ய‌னாள‌ர் வ‌கைக‌ள்',
	'Create type' => 'வ‌கையை உருவாக்கு',
	'Item%s has been inserted.' => 'உருப்ப‌டி (Item%s) சேர்க்க‌ப்ப‌ட்ட‌து.',
	'Schema has been dropped.' => 'அமைப்புமுறை நீக்க‌ப்ப‌ட்ட‌து.',
	'Schema has been created.' => 'அமைப்புமுறை உருவாக்க‌ப்ப‌ட்ட‌து.',
	'Schema has been altered.' => 'அமைப்புமுறை மாற்ற‌ப்ப‌ட்ட‌து.',
	'Use edit link to modify this value.' => 'இந்த‌ ம‌திப்பினை மாற்ற‌, தொகுப்பு இணைப்பினை உப‌யோகிக்க‌வும்.',
	'last' => 'க‌டைசி',
	'Sequence has been dropped.' => 'வ‌ரிசைமுறை நீக்க‌ப்ப‌ட்ட‌து.',
	'Sequence has been created.' => 'வ‌ரிசைமுறை உருவாக்க‌ப்ப‌ட்ட‌து.',
	'Sequence has been altered.' => 'வ‌ரிசைமுறை மாற்ற‌ப்ப‌ட்ட‌து.',
	'Alter sequence' => 'வ‌ரிசைமுறையை மாற்று',
	'From server' => 'செர்வ‌ரில் இருந்து',
	'Type has been dropped.' => 'வ‌கை (type) நீக்க‌ப்ப‌ட்ட‌து.',
	'Type has been created.' => 'வ‌கை (type) உருவாக்க‌ப்ப‌ட்ட‌து.',
	'Alter type' => 'வ‌கையினை (type) மாற்று',
	'System' => 'சிஸ்ட‌ம் (System)',
	'anywhere' => 'எங்காயினும்',
	'empty' => 'வெறுமை (empty)',
	'No extension' => 'விரிவு (extensஇஒன்) இல்லை ',
	'Databases have been dropped.' => 'த‌க‌வ‌ல் த‌ள‌ங்க‌ள் நீக்க‌ப்ப‌ட்டன‌.',
	'%s version: %s through PHP extension %s' => '%s ப‌திப்பு: %s through PHP extension %s',
	'Network' => 'நெட்வொர்க்',
	'Geometry' => 'வ‌டிவ‌விய‌ல் (Geometry)',
	'File exists.' => 'கோப்பு உள்ள‌து.',
	'now' => 'இப்பொழுது',
	'%d query(s) executed OK.' => array('%d வின‌வ‌ல் செய‌ல்ப‌டுத்த‌ப்ப‌ட்ட‌து.', '%d வின‌வ‌ல்க‌ள் செய‌ல்ப‌டுத்த‌ப்ப‌ட்ட‌ன‌.'),
	'Show only errors' => 'பிழைக‌ளை ம‌ட்டும் காண்பிக்க‌வும்',
	'Refresh' => 'புதுப்பி (Refresh)',
	'Invalid schema.' => 'அமைப்புமுறை ச‌ரியான‌த‌ல்ல‌ (Invalid Schema).',
	'Please use one of the extensions %s.' => 'த‌ய‌வு செய்து ஒரு விரிவினை %s (extension) உப‌யோகிக்க‌வும்.',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'அட்டவணைகள் நகலெடுக்கப் பட்டது.',
	'Copy' => 'நகல்',
	'Permanent link' => 'நிரந்தர இணைப்பு',
	'Edit all' => 'அனைத்தையும் தொகு',
	'HH:MM:SS' => 'HH:MM:SS',
);

// run `php ../../lang.php ta` to update this file
