<?php
namespace Adminer;

Lang::$translations = array(
	'Login' => 'Aanmelden',
	'Logout successful.' => 'Successvol afgemeld.',
	'Invalid credentials.' => 'Ongeldige gebruikersgegevens.',
	'Server' => 'Server',
	'Username' => 'Gebruikersnaam',
	'Password' => 'Wachtwoord',
	'Select database' => 'Database selecteren',
	'Invalid database.' => 'Ongeldige database.',
	'Table has been dropped.' => 'Tabel verwijderd.',
	'Table has been altered.' => 'Tabel aangepast.',
	'Table has been created.' => 'Tabel aangemaakt.',
	'Alter table' => 'Tabel aanpassen',
	'Create table' => 'Tabel aanmaken',
	'Table name' => 'Tabelnaam',
	'engine' => 'engine',
	'collation' => 'collation',
	'Column name' => 'Kolomnaam',
	'Type' => 'Type',
	'Length' => 'Lengte',
	'Auto Increment' => 'Auto nummering',
	'Options' => 'Opties',
	'Save' => 'Opslaan',
	'Drop' => 'Verwijderen',
	'Databases have been dropped.' => 'Databases verwijderd.',
	'Database has been dropped.' => 'Database verwijderd.',
	'Database has been created.' => 'Database aangemaakt.',
	'Database has been renamed.' => 'Database hernoemd.',
	'Database has been altered.' => 'Database aangepast.',
	'Alter database' => 'Database aanpassen',
	'Create database' => 'Database aanmaken',
	'SQL command' => 'SQL opdracht',
	'Logout' => 'Afmelden',
	'Use' => 'Gebruik',
	'No tables.' => 'Geen tabellen.',
	'select' => 'kies',
	'Item has been deleted.' => 'Item verwijderd.',
	'Item has been updated.' => 'Item aangepast.',
	'Item%s has been inserted.' => 'Item%s toegevoegd.',
	'Edit' => 'Bewerk',
	'Insert' => 'Toevoegen',
	'Save and insert next' => 'Opslaan en volgende toevoegen',
	'Delete' => 'Verwijderen',
	'Database' => 'Database',
	'Routines' => 'Procedures',
	'Indexes have been altered.' => 'Index aangepast.',
	'Indexes' => 'Indexen',
	'Alter indexes' => 'Indexen aanpassen',
	'Add next' => 'Volgende toevoegen',
	'Language' => 'Taal',
	'Select' => 'Kies',
	'New item' => 'Nieuw item',
	'Search' => 'Zoeken',
	'Sort' => 'Sorteren',
	'descending' => 'Aflopend',
	'Limit' => 'Beperk',
	'No rows.' => 'Geen rijen.',
	'Action' => 'Acties',
	'edit' => 'bewerk',
	'Page' => 'Pagina',
	'Query executed OK, %d row(s) affected.' => array('Query uitgevoerd, %d rij aangepast.', 'Query uitgevoerd, %d rijen aangepast.'),
	'Error in query' => 'Fout in query',
	'Execute' => 'Uitvoeren',
	'Table' => 'Tabel',
	'Foreign keys' => 'Foreign keys',
	'Triggers' => 'Triggers',
	'View' => 'View',
	'Unable to select the table' => 'Onmogelijk tabel te selecteren',
	'Invalid CSRF token. Send the form again.' => 'Ongeldig CSRF token. Verstuur het formulier opnieuw.',
	'Comment' => 'Commentaar',
	'Default values' => 'Standaard waarden',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'Geen opdrachten uit te voeren.',
	'Unable to upload a file.' => 'Onmogelijk bestand te uploaden.',
	'File upload' => 'Bestand uploaden',
	'File uploads are disabled.' => 'Bestanden uploaden is uitgeschakeld.',
	'Routine has been called, %d row(s) affected.' => array('Procedure uitgevoerd, %d rij geraakt.', 'Procedure uitgevoerd, %d rijen geraakt.'),
	'Call' => 'Uitvoeren',
	'No extension' => 'Geen extensie',
	'None of the supported PHP extensions (%s) are available.' => 'Geen geldige PHP extensies beschikbaar (%s).',
	'Session support must be enabled.' => 'Sessies moeten geactiveerd zijn.',
	'Session expired, please login again.' => 'Uw sessie is verlopen. Gelieve opnieuw aan te melden.',
	'Text length' => 'Tekst lengte',
	'Foreign key has been dropped.' => 'Foreign key verwijderd.',
	'Foreign key has been altered.' => 'Foreign key aangepast.',
	'Foreign key has been created.' => 'Foreign key aangemaakt.',
	'Foreign key' => 'Foreign key',
	'Target table' => 'Doeltabel',
	'Change' => 'Veranderen',
	'Source' => 'Bron',
	'Target' => 'Doel',
	'Add column' => 'Kolom toevoegen',
	'Alter' => 'Aanpassen',
	'Add foreign key' => 'Foreign key aanmaken',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Index type',
	'length' => 'lengte',
	'View has been dropped.' => 'View verwijderd.',
	'View has been altered.' => 'View aangepast.',
	'View has been created.' => 'View aangemaakt.',
	'Alter view' => 'View aanpassen',
	'Create view' => 'View aanmaken',
	'Name' => 'Naam',
	'Process list' => 'Proceslijst',
	'%d process(es) have been killed.' => array('%d proces gestopt.', '%d processen gestopt.'),
	'Kill' => 'Stoppen',
	'Parameter name' => 'Parameternaam',
	'Database schema' => 'Database schema',
	'Create procedure' => 'Procedure aanmaken',
	'Create function' => 'Functie aanmaken',
	'Routine has been dropped.' => 'Procedure verwijderd.',
	'Routine has been altered.' => 'Procedure aangepast.',
	'Routine has been created.' => 'Procedure aangemaakt.',
	'Alter function' => 'Functie aanpassen',
	'Alter procedure' => 'Procedure aanpassen',
	'Return type' => 'Return type',
	'Add trigger' => 'Trigger aanmaken',
	'Trigger has been dropped.' => 'Trigger verwijderd.',
	'Trigger has been altered.' => 'Trigger aangepast.',
	'Trigger has been created.' => 'Trigger aangemaakt.',
	'Alter trigger' => 'Trigger aanpassen',
	'Create trigger' => 'Trigger aanmaken',
	'Time' => 'Time',
	'Event' => 'Event',
	'%s version: %s through PHP extension %s' => '%s versie: %s met PHP extensie %s',
	'%d row(s)' => array('%d rij', '%d rijen'),
	'Remove' => 'Verwijderen',
	'Are you sure?' => 'Weet u het zeker?',
	'Privileges' => 'Rechten',
	'Create user' => 'Gebruiker aanmaken',
	'User has been dropped.' => 'Gebruiker verwijderd.',
	'User has been altered.' => 'Gebruiker aangepast.',
	'User has been created.' => 'Gebruiker aangemaakt.',
	'Hashed' => 'Gehashed',
	'Column' => 'Kolom',
	'Routine' => 'Routine',
	'Grant' => 'Toekennen',
	'Revoke' => 'Intrekken',
	'Logged as: %s' => 'Aangemeld als: %s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST-data is te groot. Verklein de hoeveelheid data of verhoog de %s configuratie.',
	'Move up' => 'Omhoog',
	'Move down' => 'Omlaag',
	'Export' => 'Exporteren',
	'Tables' => 'Tabellen',
	'Data' => 'Data',
	'Output' => 'Uitvoer',
	'open' => 'openen',
	'save' => 'opslaan',
	'Format' => 'Formaat',
	'Functions' => 'Functies',
	'Aggregation' => 'Totalen',
	'Event has been dropped.' => 'Event werd verwijderd.',
	'Event has been altered.' => 'Event werd aangepast.',
	'Event has been created.' => 'Event werd aangemaakt.',
	'Alter event' => 'Event aanpassen',
	'Create event' => 'Event aanmaken',
	'Start' => 'Start',
	'End' => 'Stop',
	'Every' => 'Iedere',
	'Status' => 'Status',
	'On completion preserve' => 'Bewaren na voltooiing',
	'Events' => 'Events',
	'Schedule' => 'Schedule',
	'At given time' => 'Op aangegeven tijd',
	'Save and continue edit' => 'Opslaan en verder bewerken',
	'original' => 'origineel',
	'Tables have been truncated.' => 'Tabellen werden geleegd.',
	'Tables have been moved.' => 'Tabellen werden verplaatst.',
	'Tables have been dropped.' => 'Tabellen werden verwijderd.',
	'Tables and views' => 'Tabellen en views',
	'Engine' => 'Engine',
	'Collation' => 'Collatie',
	'Data Length' => 'Data lengte',
	'Index Length' => 'Index lengte',
	'Data Free' => 'Data Vrij',
	'Rows' => 'Rijen',
	',' => '.',
	'0123456789' => '0123456789',
	'Analyze' => 'Analyseer',
	'Optimize' => 'Optimaliseer',
	'Check' => 'Controleer',
	'Repair' => 'Herstel',
	'Truncate' => 'Legen',
	'Move to other database' => 'Verplaats naar andere database',
	'Move' => 'Verplaats',
	'%d item(s) have been affected.' => array('%d item aangepast.', '%d items aangepast.'),
	'Whole result' => 'Volledig resultaat',
	'Clone' => 'Dupliceer',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Maximum aantal velden bereikt. Verhoog %s.',
	'Partition by' => 'Partitioneren op',
	'Partitions' => 'Partities',
	'Partition name' => 'Partitie naam',
	'Values' => 'Waarden',
	'%d row(s) have been imported.' => array('%d rij werd geïmporteerd.', '%d rijen werden geïmporteerd.'),
	'anywhere' => 'overal',
	'Import' => 'Importeren',
	'Stop on error' => 'Stoppen bij fout',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5-$3-$1',
	'[yyyy]-mm-dd' => 'dd-mm-[jjjj]',
	'History' => 'Geschiedenis',
	'Variables' => 'Variabelen',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Bron- en doelkolommen moeten van hetzelfde data type zijn, er moet een index bestaan op de gekozen kolommen en er moet gerelateerde data bestaan.',
	'Relations' => 'Relaties',
	'Run file' => 'Bestand uitvoeren',
	'Clear' => 'Wissen',
	'Maximum allowed file size is %sB.' => 'Maximum toegelaten bestandsgrootte is %sB.',
	'Numbers' => 'Getallen',
	'Date and time' => 'Datum en tijd',
	'Strings' => 'Tekst',
	'Binary' => 'Binaire gegevens',
	'Lists' => 'Lijsten',
	'Editor' => 'Editor',
	'Webserver file %s' => 'Webserver bestand %s',
	'File does not exist.' => 'Bestand niet gevonden.',
	'%d in total' => '%d in totaal',
	'Permanent login' => 'Blijf aangemeld',
	'Search data in tables' => 'Zoeken in database',
	'Schema' => 'Schema',
	'Alter schema' => 'Schema wijzigen',
	'Create schema' => 'Schema maken',
	'Schema has been dropped.' => 'Schema verwijderd.',
	'Schema has been created.' => 'Schema aangemaakt.',
	'Schema has been altered.' => 'Schema gewijzigd.',
	'Sequences' => 'Sequences',
	'Create sequence' => 'Sequence maken',
	'Alter sequence' => 'Sequence wijzigen',
	'Sequence has been dropped.' => 'Sequence verwijderd.',
	'Sequence has been created.' => 'Sequence aangemaakt.',
	'Sequence has been altered.' => 'Sequence gewijzigd.',
	'User types' => 'Gebruikersgedefiniëerde types',
	'Create type' => 'Type maken',
	'Alter type' => 'Type wijzigen',
	'Type has been dropped.' => 'Type verwijderd.',
	'Type has been created.' => 'Type aangemaakt.',
	'Ctrl+click on a value to modify it.' => 'Ctrl+klik op een waarde om deze te bewerken.',
	'Use edit link to modify this value.' => 'Gebruik de link \'bewerk\' om deze waarde te wijzigen.',
	'last' => 'laatste',
	'From server' => 'Van server',
	'System' => 'Databasesysteem',
	'Select data' => 'Gegevens selecteren',
	'Show structure' => 'Toon structuur',
	'empty' => 'leeg',
	'Network' => 'Netwerk',
	'Geometry' => 'Geometrie',
	'File exists.' => 'Bestand bestaat reeds.',
	'%d query(s) executed OK.' => array('%d query succesvol uitgevoerd.', '%d querys succesvol uitgevoerd.'),
	'Show only errors' => 'Enkel fouten tonen',
	'Refresh' => 'Vernieuwen',
	'Invalid schema.' => 'Ongeldig schema.',
	'Please use one of the extensions %s.' => 'Gebruik 1 van volgende extensies: %s.',
	'now' => 'nu',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'De tabellen zijn gekopieerd.',
	'Copy' => 'Kopieren',
	'Permanent link' => 'Permanente link',
	'Edit all' => 'Alles bewerken',
	'HH:MM:SS' => 'HH:MM:SS',
	'Drop %s?' => 'Verwijder %s?',
	'Tables have been optimized.' => 'Tabellen zijn geoptimaliseerd.',
	'Materialized view' => 'Materialized view',
	'Vacuum' => 'Vacuum',
	'Selected' => 'Geselecteerd',
	'overwrite' => 'overschrijven',
	'DB' => 'DB',
	'File must be in UTF-8 encoding.' => 'Het bestand moet met UTF-8 encodering zijn opgeslagen.',
	'Modify' => 'Aanpassen',
	'Load more data' => 'Meer data inladen',
	'Loading' => 'Aan het laden',
	'ATTACH queries are not supported.' => 'ATTACH queries worden niet ondersteund.',
	'Warnings' => 'Waarschuwingen',
	'%d / ' => '%d / ',
	'Limit rows' => 'Rijen beperken',
	'Adminer does not support accessing a database without a password, <a href="https://www.adminer.org/en/password/"%s>more information</a>.' => 'Adminer ondersteunt geen toegang tot databases zonder wachtwoord, <a href="https://www.adminer.org/en/password/"%s>meer informatie</a>.',
	'Default value' => 'Standaardwaarde',
	'Full table scan' => 'Full table scan',
	'Too many unsuccessful logins, try again in %d minute(s).' => array('Teveel foutieve aanmeldpogingen, probeer opnieuw binnen %d minuut.', 'Teveel foutieve aanmeldpogingen, probeer opnieuw binnen %d minuten.'),
	'Master password expired. <a href="https://www.adminer.org/en/extension/"%s>Implement</a> %s method to make it permanent.' => 'Master wachtwoord verlopen. <a href="https://www.adminer.org/en/extension/"%s>Implementeer</a> de %s methode om het permanent te maken.',
	'The action will be performed after successful login with the same credentials.' => 'Deze actie zal uitgevoerd worden na het succesvol aanmelden met dezelfde gebruikersgegevens.',
	'Connecting to privileged ports is not allowed.' => 'Verbindingen naar geprivilegieerde poorten is niet toegestaan.',
	'There is a space in the input password which might be the cause.' => 'Er staat een spatie in het wachtwoord, wat misschien de oorzaak is.',
	'If you did not send this request from Adminer then close this page.' => 'Als u deze actie niet via Adminer hebt gedaan, gelieve deze pagina dan te sluiten.',
	'You can upload a big SQL file via FTP and import it from server.' => 'U kan een groot SQL-bestand uploaden via FTP en het importeren via de server.',
	'Size' => 'Grootte',
	'Compute' => 'Bereken',
	'You are offline.' => 'U bent offline.',
	'You have no privileges to update this table.' => 'U bent niet gemachtigd om deze tabel aan te passen.',
	'Saving' => 'Opslaan',
	'Unknown error.' => 'Onbekende fout.',
	'Database does not support password.' => 'Database ondersteunt het wachtwoord niet.',
	'Disable %s or enable %s or %s extensions.' => 'Schakel %s uit or schakel extensies %s of %s in.',
	'yes' => 'ja',
	'no' => 'neen',
);

// run `php ../../lang.php nl` to update this file
