<?php
namespace Adminer;

Lang::$translations = array(
	'Login' => 'Entrar',
	'Logout successful.' => 'Sessão terminada com sucesso.',
	'Invalid credentials.' => 'Identificação inválida.',
	'Server' => 'Servidor',
	'Username' => 'Nome de utilizador',
	'Password' => 'Senha',
	'Select database' => 'Selecionar Base de dados',
	'Invalid database.' => 'Base de dados inválida.',
	'Table has been dropped.' => 'Tabela eliminada.',
	'Table has been altered.' => 'Tabela modificada.',
	'Table has been created.' => 'Tabela criada.',
	'Alter table' => 'Modificar estrutura',
	'Create table' => 'Criar tabela',
	'Table name' => 'Nome da tabela',
	'engine' => 'motor',
	'collation' => 'collation',
	'Column name' => 'Nome da coluna',
	'Type' => 'Tipo',
	'Length' => 'Tamanho',
	'Auto Increment' => 'Incremento Automático',
	'Options' => 'Opções',
	'Save' => 'Guardar',
	'Drop' => 'Remover',
	'Database has been dropped.' => 'Base de dados eliminada.',
	'Database has been created.' => 'Base de dados criada.',
	'Database has been renamed.' => 'Base de dados renomeada.',
	'Database has been altered.' => 'Base de dados modificada.',
	'Alter database' => 'Modificar Base de dados',
	'Create database' => 'Criar Base de dados',
	'SQL command' => 'Comando SQL',
	'Logout' => 'Terminar sessão',
	'Use' => 'Usar',
	'No tables.' => 'Não existem tabelas.',
	'select' => 'registos',
	'Item has been deleted.' => 'Registo eliminado.',
	'Item has been updated.' => 'Registo modificado.',
	'Item%s has been inserted.' => 'Registo%s inserido.',
	'Edit' => 'Modificar',
	'Insert' => 'Inserir',
	'Save and insert next' => 'Guardar e inserir outro',
	'Delete' => 'Eliminar',
	'Database' => 'Base de dados',
	'Routines' => 'Procedimentos',
	'Indexes have been altered.' => 'Índices modificados.',
	'Indexes' => 'Índices',
	'Alter indexes' => 'Modificar índices',
	'Add next' => 'Adicionar próximo',
	'Language' => 'Idioma',
	'Select' => 'Selecionar',
	'New item' => 'Novo Registo',
	'Search' => 'Procurar',
	'Sort' => 'Ordenar',
	'descending' => 'decrescente',
	'Limit' => 'Limite',
	'No rows.' => 'Não existem registos.',
	'Action' => 'Ação',
	'edit' => 'modificar',
	'Page' => 'Página',
	'Query executed OK, %d row(s) affected.' => array('Consulta executada, %d registo afetado.', 'Consulta executada, %d registos afetados.'),
	'Error in query' => 'Erro na consulta',
	'Execute' => 'Executar',
	'Table' => 'Tabela',
	'Foreign keys' => 'Chaves estrangeiras',
	'Triggers' => 'Triggers',
	'View' => 'Visualizar',
	'Unable to select the table' => 'Não é possivel selecionar a Tabela',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF inválido. Enviar o formulario novamente.',
	'Comment' => 'Comentário',
	'Default values' => 'Valores predeterminados',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'Nenhum comando para executar.',
	'Unable to upload a file.' => 'Não é possível enviar o ficheiro.',
	'File upload' => 'Importar ficheiro',
	'File uploads are disabled.' => 'Importação de ficheiros desativada.',
	'Routine has been called, %d row(s) affected.' => array('Consulta executada, %d registo afetado.', 'Consulta executada, %d registos afetados.'),
	'Call' => 'Chamar',
	'No extension' => 'Não há extensão',
	'None of the supported PHP extensions (%s) are available.' => 'Nenhuma das extensões PHP suportadas (%s) está disponivel.',
	'Session support must be enabled.' => 'As sessões devem estar ativas.',
	'Session expired, please login again.' => 'Sessão expirada, por favor entre de novo.',
	'Text length' => 'Tamanho do texto',
	'Foreign key has been dropped.' => 'Chave estrangeira eliminada.',
	'Foreign key has been altered.' => 'Chave estrangeira modificada.',
	'Foreign key has been created.' => 'Chave estrangeira criada.',
	'Foreign key' => 'Chave estrangeira',
	'Target table' => 'Tabela de destino',
	'Change' => 'Modificar',
	'Source' => 'Origem',
	'Target' => 'Destino',
	'Add column' => 'Adicionar coluna',
	'Alter' => 'Modificar',
	'Add foreign key' => 'Adicionar Chave estrangeira',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Tipo de índice',
	'length' => 'tamanho',
	'View has been dropped.' => 'Vista eliminada.',
	'View has been altered.' => 'Vista modificada.',
	'View has been created.' => 'Vista criada.',
	'Alter view' => 'Modificar vista',
	'Create view' => 'Criar vista',
	'Name' => 'Nome',
	'Process list' => 'Lista de processos',
	'%d process(es) have been killed.' => array('%d processo terminado.', '%d processos terminados.'),
	'Kill' => 'Parar',
	'Parameter name' => 'Nome de Parâmetro',
	'Database schema' => 'Esquema de Base de dados',
	'Create procedure' => 'Criar procedimento',
	'Create function' => 'Criar função',
	'Routine has been dropped.' => 'Procedimento eliminado.',
	'Routine has been altered.' => 'Procedimento modificado.',
	'Routine has been created.' => 'Procedimento criado.',
	'Alter function' => 'Modificar Função',
	'Alter procedure' => 'Modificar procedimento',
	'Return type' => 'Tipo de valor de regresso',
	'Add trigger' => 'Adicionar trigger',
	'Trigger has been dropped.' => 'Trigger eliminado.',
	'Trigger has been altered.' => 'Trigger modificado.',
	'Trigger has been created.' => 'Trigger criado.',
	'Alter trigger' => 'Modificar Trigger',
	'Create trigger' => 'Adicionar Trigger',
	'Time' => 'Tempo',
	'Event' => 'Evento',
	'%s version: %s through PHP extension %s' => 'Versão %s: %s através da extensão PHP %s',
	'%d row(s)' => array('%d registo', '%d registos'),
	'Remove' => 'Remover',
	'Are you sure?' => 'Tem a certeza?',
	'Privileges' => 'Privilégios',
	'Create user' => 'Criar utilizador',
	'User has been dropped.' => 'Utilizador eliminado.',
	'User has been altered.' => 'Utilizador modificado.',
	'User has been created.' => 'Utilizador criado.',
	'Hashed' => 'Hash',
	'Column' => 'Coluna',
	'Routine' => 'Rotina',
	'Grant' => 'Conceder',
	'Revoke' => 'Impedir',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST data demasiado grande. Reduza o tamanho ou aumente a diretiva de configuração %s.',
	'Logged as: %s' => 'Ligado como: %s',
	'Move up' => 'Mover para cima',
	'Move down' => 'Mover para baixo',
	'Functions' => 'Funções',
	'Aggregation' => 'Adições',
	'Export' => 'Exportar',
	'Output' => 'Saída',
	'open' => 'abrir',
	'save' => 'guardar',
	'Format' => 'Formato',
	'Tables' => 'Tabelas',
	'Data' => 'Dados',
	'Event has been dropped.' => 'Evento eliminado.',
	'Event has been altered.' => 'Evento modificado.',
	'Event has been created.' => 'Evento criado.',
	'Alter event' => 'Modificar Evento',
	'Create event' => 'Criar Evento',
	'At given time' => 'À hora determinada',
	'Every' => 'Cada',
	'Events' => 'Eventos',
	'Schedule' => 'Agenda',
	'Start' => 'Início',
	'End' => 'Fim',
	'Status' => 'Estado',
	'On completion preserve' => 'Preservar ao completar',
	'Tables and views' => 'Tabelas e vistas',
	'Data Length' => 'Tamanho de dados',
	'Index Length' => 'Tamanho de índice',
	'Data Free' => 'Espaço Livre',
	'Collation' => 'Colação',
	'Analyze' => 'Analizar',
	'Optimize' => 'Otimizar',
	'Check' => 'Verificar',
	'Repair' => 'Reparar',
	'Truncate' => 'Truncar',
	'Tables have been truncated.' => 'Tabelas truncadas (truncate).',
	'Rows' => 'Registos',
	',' => ' ',
	'0123456789' => '0123456789',
	'Tables have been moved.' => 'As Tabelas foram movidas.',
	'Move to other database' => 'Mover outra Base de dados',
	'Move' => 'Mover',
	'Engine' => 'Motor',
	'Save and continue edit' => 'Guardar e continuar a edição',
	'original' => 'original',
	'Tables have been dropped.' => 'As tabelas foram eliminadas.',
	'%d item(s) have been affected.' => array('%d item afetado.', '%d itens afetados.'),
	'Whole result' => 'Resultado completo',
	'Clone' => 'Clonar',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Quantidade máxima de campos permitidos excedidos. Por favor aumente %s.',
	'Partition by' => 'Particionar por',
	'Partitions' => 'Partições',
	'Partition name' => 'Nome da Partição',
	'Values' => 'Valores',
	'%d row(s) have been imported.' => array('%d registo importado.', '%d registos importados.'),
	'anywhere' => 'qualquer local',
	'Import' => 'Importar',
	'Stop on error' => 'Parar em caso de erro',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'dd/mm/[aaaa]',
	'History' => 'Histórico',
	'Variables' => 'Variáveis',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'As colunas de origen e destino devem ser do mesmo tipo, deve existir um índice entre as colunas de destino e o registo referenciado deve existir.',
	'Relations' => 'Relações',
	'Run file' => 'Executar ficheiro',
	'Clear' => 'Limpar',
	'Maximum allowed file size is %sB.' => 'Tamanho máximo do ficheiro é %sB.',
	'Numbers' => 'Números',
	'Date and time' => 'Data e hora',
	'Strings' => 'Cadeia',
	'Binary' => 'Binário',
	'Lists' => 'Listas',
	'Editor' => 'Editor',
	'Webserver file %s' => 'Ficheiro do servidor web %s',
	'File does not exist.' => 'Ficheiro não existe.',
	'%d in total' => '%d no total',
	'Permanent login' => 'Memorizar a senha',
	'Databases have been dropped.' => 'Bases de dados eliminadas.',
	'Search data in tables' => 'Pesquisar dados nas Tabelas',
	'Schema' => 'Esquema',
	'Alter schema' => 'Modificar esquema',
	'Create schema' => 'Criar esquema',
	'Schema has been dropped.' => 'Esquema eliminado.',
	'Schema has been created.' => 'Esquema criado.',
	'Schema has been altered.' => 'Esquema modificado.',
	'Sequences' => 'Sequências',
	'Create sequence' => 'Criar sequências',
	'Alter sequence' => 'Modificar sequência',
	'Sequence has been dropped.' => 'Sequência eliminada.',
	'Sequence has been created.' => 'Sequência criada.',
	'Sequence has been altered.' => 'Sequência modificada.',
	'User types' => 'Tipos definidos pelo utilizador',
	'Create type' => 'Criar tipo',
	'Alter type' => 'Modificar tipo',
	'Type has been dropped.' => 'Tipo eliminado.',
	'Type has been created.' => 'Tipo criado.',
	'Ctrl+click on a value to modify it.' => 'Ctrl+clique vezes sobre o valor para edita-lo.',
	'Use edit link to modify this value.' => 'Utilize o link modificar para alterar.',
	'last' => 'último',
	'From server' => 'Do servidor',
	'System' => 'Motor de Base de dados',
	'Select data' => 'Selecionar dados',
	'Show structure' => 'Mostrar estrutura',
	'empty' => 'vazio',
	'Network' => 'Rede',
	'Geometry' => 'Geometria',
	'File exists.' => 'Ficheiro já existe.',
	'%d query(s) executed OK.' => array('%d consulta sql executada corretamente.', '%d consultas sql executadas corretamente.'),
	'Show only errors' => 'Mostrar somente erros',
	'Refresh' => 'Atualizar',
	'Invalid schema.' => 'Esquema inválido.',
	'Please use one of the extensions %s.' => 'Por favor use uma das extensões %s.',
	'now' => 'agora',
	'ltr' => 'ltr',
);

// run `php ../../lang.php pt` to update this file
