/**
 * Alternative style for Adminer by Frank Bültge
 *
 * @link     http://bueltge.de/
 * @version  02/18/2014
 */

html {
	--bg: #F9F9F9;
	--fg: #333;
}

body {
margin: 0;
font-size: 12px;
line-height: 1.4em;
background: #F9F9F9;
color: #333;
}
body, select, option, optgroup, button {
font-family: "Lucida Grande",Verdana,Arial,"Bitstream Vera Sans",sans-serif;
} /* IE6 */
input[type='submit'], input[type='reset'], input[type='button'], input[type='file'] {
font-family: "Lucida Grande",Verdana,Arial,"Bitstream Vera Sans",sans-serif;
}
input, textarea, pre, code, samp, kbd, var {
font-family: "Lucida Grande",Verdana,Arial,"Bitstream Vera Sans",sans-serif;
font-size: 12px;
}

pre {
white-space: pre-wrap;
}

p {
margin: 0.8em 20px 0 5px
}

a {
color: #21759B;
background: none !important;
}
a:visited {
color: #21759B;
}
a:hover, a:hover {
text-decoration: none;
color: #d54e21;
}
a:focus {
	background: #c7e7fd;
	color: #124964;
}
a:active {
	background: none;
	outline: thin dotted;
}

a.active, a.active + a {
	text-decoration: none;
	font-weight: 700;
}
.icon {
	background-color: #21759B;
}
form {
margin: 0;
padding: 0 0 0 5px;
}
table {
width: 100%;
clear: both;
margin: 0;
border-spacing: 0;
border-collapse: separate;
border-color: gray;
}
table, thead, tbody {
margin: 10px 12px 0 0;
border: 1px #BBB solid;
font-size: 90%;
}
thead th, thead td {
text-align: center;
}
td {
white-space: normal;
overflow: hidden;
padding: 0 4px;
}
th {
text-align: left;
font-weight: 400;
}
td, th {
background-color: #fff;
padding: 1px 2px;
border: 1px #DfDfDf solid;
border-width: 1px 0 0 1px;
}
tr:first-child td, tr:first-child th {
border-top-width: 0;
}
td:first-child, th:first-child {
border-left-width: 0;
}
thead {
display: table-header-group;
vertical-align: middle;
border-color: inherit;
}
thead td, thead th {
background-color: #DFDFDF;
border: none;
border-bottom: 1px #BBB solid;
}
thead tr:hover td, thead tr:hover th {
background-color: #DDD !important;
}
tr:nth-child(2n) td, tr:nth-child(2n) th {
background-color: #F1F1F1;
}
tr:hover td, tr:hover th {
background-color: #BCD;
}

.footer {
border-image:linear-gradient(rgba(249, 249, 249, .2), #F9F9F9) 100% 0;
}
.footer > div {
background-color: #F9F9F9;
}

fieldset {
display: inline;
vertical-align: top;
padding: 2px 12px;
margin: 25px 12px 12px 0;
border: none;
background-color: #F1F1F1;
border: 1px solid #E3E3E3;
position: relative;
padding-top: 14px;
}
fieldset, x:-moz-any-link {
padding-top: 4px;
}
fieldset {
padding-top: 14px;
}
legend {
font-weight: 900;
color: #000;
top: -1.666em;
left: -1em;
padding: 0 4px;
}
input {
padding: 2px 5px 1px 5px;
}
input[name='limit'], input[name='length'] {
width: 3em;
text-align: right;
}
input[name='text_length'] {
width: 5em;
}
select + input, select + select {
margin-left: 2px;
}
textarea, input, select {
border-width: 1px;
border-style: solid;
-moz-border-radius: 3px;
-khtml-border-radius: 3px;
-webkit-border-radius: 3px;
border-radius: 3px;
border-color: #DFDFDF;
}
select {
margin: 0 0 1px 0;
}
input[type="checkbox"], input[type="radio"], input[type="image"] {
border: 0 none;
}
input[type=button], input[type=submit] {
	display: inline-block;
	text-decoration: none;
	font-size: 12px;
	line-height: 15px;
	padding: 1px 0 0 0;
	cursor: pointer;
	border-width: 1px;
	border-style: solid;
	-webkit-border-radius: 3px;
	border-radius: 3px;
	-webkit-box-sizing: content-box;
	-moz-box-sizing:    content-box;
	box-sizing:         content-box;
	white-space: nowrap;
	border-color: #dfdfdf;
	background-color: #fff;
	color: #333;
}
input[type="button"]:focus, input[type=submit] {
	border-color: #a1a1a1;
	-webkit-box-shadow: 1px 1px 2px rgba(0,0,0,0.1);
	box-shadow: 1px 1px 2px rgba(0,0,0,0.1);
}
input[type=button], input[type=submit] {
	padding: 2px 5px 1px 5px;
	background: #ececec;
	background-image: -webkit-gradient(linear, left top, left bottom, from(#fff), to(#eee));
	background-image: -webkit-linear-gradient(top, #fff, #eee);
	background-image:    -moz-linear-gradient(top, #fff, #eee);
	background-image:      -o-linear-gradient(top, #fff, #eee);
	background-image:   linear-gradient(to bottom, #fff, #eee);
	border-color: #ccc;
	-webkit-box-shadow: inset 0 0 1px 1px rgba(255,255,255, 0.9);
 	box-shadow: inset 0 0 1px 1px rgba(255,255,255, 0.9);
 	color: #464646;
	text-shadow: 1px 1px 0 #fff;
}
input[type=button]:hover, input[type=submit]:hover,
input[type=button]:focus, input[type=submit]:focus  {
	background: #ececec;
	background-image: -webkit-gradient(linear, left top, left bottom, from(#fff), to(#eee));
	background-image: -webkit-linear-gradient(top, #fff, #eee);
	background-image:    -moz-linear-gradient(top, #fff, #eee);
	background-image:      -o-linear-gradient(top, #fff, #eee);
	background-image:   linear-gradient(to bottom, #fff, #eee);
	border-color: #bbb;
	-webkit-box-shadow: 0px 1px 1px rgba(0,0,0,.1);
	box-shadow: 0px 1px 1px rgba(0,0,0,.1);
	color: #000;
}
input[type=button]:active, input[type=submit]:active {
	background: #eee;
	background-image: -webkit-gradient(linear, left top, left bottom, from(#eee), to(#f9f9f9));
	background-image: -webkit-linear-gradient(top, #eee, #f9f9f9);
	background-image:    -moz-linear-gradient(top, #eee, #f9f9f9);
	background-image:      -o-linear-gradient(top, #eee, #f9f9f9);
	background-image:   linear-gradient(to bottom, #eee, #f9f9f9);
	border-color: #999 #ddd #ddd #999;
	color: #555;
	-webkit-box-shadow: inset 1px 1px 0 rgba(50,50,50,0.1);
	box-shadow: inset 1px 1px 0 rgba(50,50,50,0.1);
}
input[type=button]:focus, input[type=submit]:focus {
	border-color: #aaa;
}
input + label input, select + label input {
margin-left: 4px;
}
td input[type='checkbox']:first-child, td input[type='radio']:first-child {
margin-left: 2px;
}
label:hover {
text-decoration: underline;
}
fieldset div {
margin-bottom: 2px;
}
input[name='Comment'] { /* !!! */
width: 24em;
}
input[name='Auto_increment'] { /* !!! */
width: 6em;
}

img {
vertical-align: middle;
margin: 0;
padding: 0;
}
.js .column {
position: relative;
background: none;
padding: 0;
}
.error {
padding: 8px;
color: red;
background-color: #FEE;
}
.message {
padding: 8px;
background-color: #DDD;
}
.char {
color: #070;
}
.date {
color: #707;
}
.enum {
color: #077;
}
.binary {
color: red;
}
.jush-sql {
padding: 2px 4px;
margin-right: 4px;
font-size: 11px;
}
.time {
color: #333;
}

#content {
margin: 2px 0 0 270px;
padding: 10px 20px 20px 0;
}
#lang {
font-size:10px;
height: 23px;
width: 255px;
display: block;
margin-top: -28px;
padding: 1px 0;
position: absolute;
top: 0;
left: 0;
text-align: center;
background-color: #f1f1f1;
border: 1px solid #E3E3E3;
line-height: 1.25em;
}
#lang select {
font-size: 10px;
}
#breadcrumb {
margin: 0;
height: 21px;
display: block;
position: absolute;
top: 0;
left: 270px;
background-color: #f1f1f1;
border: 1px solid #E3E3E3;
padding: 2px 12px;
line-height: 1.25em }
#menu {
position: absolute;
margin: 0;
top: 28px;
left: 0;
width: 255px;
background-color: #f1f1f1;
border: 1px solid #E3E3E3;
}
#menu form {
margin: 0;
}
#menu p, #logins, #tables, .tables-filter {
padding-left: 8px;
}
#menu form p {
padding-left: 0;
text-align: left;
}
#dbs {
	border-bottom: none !important;
	padding-left: 3px !important;
}
h1 .h1:hover {
text-decoration: underline;
}
h1, h2 {
font: italic normal normal 24px/29px Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
margin: 0;
padding: 14px 15px 3px 10px;
line-height: 35px;
text-shadow: rgba(255,255,255,1) 0 1px 0px;
background: none;
}
h1 .h1 {
font-size: 12px;
}
h2 {
padding: 22px 0 0 10px;
}
h3 {
font: normal normal normal 18px/22px Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
margin: 20px 0 0 5px;
}
#schema {
margin: 1.5em 0 0 220px;
position: relative;
}
#schema .table {
border: 1px solid #E3E3E3;
background-color: #F1F1F1;
padding: 0 2px;
cursor: move;
position: absolute;
}
#schema .references {
position: absolute;
}
.js .hidden {
display: hidden;
}
.js td.hidden, .js input.hidden {
display: none;
}
legend a {
color: #333;
text-decoration: none;
cursor: default;
}
legend a:hover {
color: #333;
}
code {
background: transparent;
}
fieldset, legend, table, thead, tbody, .error, .message {
-moz-border-radius: 3px;
-khtml-border-radius: 3px;
-webkit-border-radius: 3px;
border-radius: 3px;
}
#breadcrumb, #lang, #menu {
-moz-border-radius-bottomright: 3px;
-khtml-border-bottom-right-radius: 3px;
-webkit-border-bottom-right-radius: 3px;
border-bottom-right-radius: 3px;
}
#breadcrumb {
-moz-border-radius-bottomleft: 3px;
-khtml-border-bottom-left-radius: 3px;
-webkit-border-bottom-left-radius: 3px;
border-bottom-left-radius: 3px;
}
#menu {
-moz-border-radius-topright: 5px;
-khtml-border-top-right-radius: 3px;
-webkit-border-top-right-radius: 3px;
border-top-right-radius: 3px;
}
