<?php
namespace Adminer;

Lang::$translations = array(
	'Login' => 'შესვლა',
	'Logout successful.' => 'გამოხვედით სისტემიდან.',
	'Invalid credentials.' => 'არასწორი მომხმარებელი ან პაროლი.',
	'Server' => 'სერვერი',
	'Username' => 'მომხმარებელი',
	'Password' => 'პაროლი',
	'Select database' => 'ბაზა',
	'Invalid database.' => 'არასწორი ბაზა.',
	'Table has been dropped.' => 'ცხრილი წაიშალა.',
	'Table has been altered.' => 'ცხრილი შეიცვალა.',
	'Table has been created.' => 'ცხრილი შეიქმნა.',
	'Alter table' => 'ცხრილის შეცვლა',
	'Create table' => 'ცხრილის შექმნა',
	'Table name' => 'სახელი',
	'engine' => 'სახეობა',
	'collation' => 'კოდირება',
	'Column name' => 'ველი',
	'Type' => 'სახეობა',
	'Length' => 'სიგრძე',
	'Auto Increment' => 'ავტომატურად გაზრდა',
	'Options' => 'მოქმედება',
	'Save' => 'შენახვა',
	'Drop' => 'წაშლა',
	'Database has been dropped.' => 'ბაზა წაიშალა.',
	'Database has been created.' => 'ბაზა შეიქმნა.',
	'Database has been renamed.' => 'ბაზას გადაერქვა.',
	'Database has been altered.' => 'ბაზა შეიცვალა.',
	'Alter database' => 'ბაზის შეცვლა',
	'Create database' => 'ბაზის შექმნა',
	'SQL command' => 'SQL-ბრძანება',
	'Logout' => 'გასვლა',
	'Use' => 'არჩევა',
	'No tables.' => 'ბაზაში ცხრილი არაა.',
	'select' => 'არჩევა',
	'Item has been deleted.' => 'ჩანაწერი წაიშალა.',
	'Item has been updated.' => 'ჩანაწერი განახლდა.',
	'Item%s has been inserted.' => 'ჩანაწერი%s ჩაჯდა.',
	'Edit' => 'შეცვლა',
	'Insert' => 'ჩასმა',
	'Save and insert next' => 'შენახვა და სხვის ჩასმა',
	'Delete' => 'წაშლა',
	'Database' => 'ბაზა',
	'Indexes have been altered.' => 'შეიცვალა ინდექსები.',
	'Indexes' => 'ინდექსები',
	'Alter indexes' => 'ინდექსის შეცვლა',
	'Add next' => 'კიდევ დამატება',
	'Language' => 'ენა',
	'Select' => 'არჩევა',
	'New item' => 'ახალი ჩანაწერი',
	'Search' => 'ძებნა',
	'Sort' => 'დალაგება',
	'descending' => 'კლებადობით',
	'Limit' => 'ზღვარი',
	'No rows.' => 'ჩანაწერი არაა.',
	'Action' => 'მოქმედება',
	'edit' => 'რედაქტირება',
	'Page' => 'გვერდი',
	'Query executed OK, %d row(s) affected.' => 'მოთხოვდა შესრულდა, შეიცვალა %d ჩანაწერი.',
	'Error in query' => 'შეცდომა მოთხოვნაში',
	'Execute' => 'შესრულება',
	'Table' => 'ცხრილი',
	'Foreign keys' => 'გარე გასაღები',
	'Triggers' => 'ტრიგერები',
	'View' => 'ნახვა',
	'Unable to select the table' => 'ცხრილიდან ინფორმაცია ვერ მოვიპოვე',
	'Invalid CSRF token. Send the form again.' => 'უმოქმედო CSRF-ტოკენი. ფორმის კიდევ ერთხელ გაგზავნა.',
	'Comment' => 'კომენტარები',
	'Default values' => 'სტანდარტული მნიშვნელობა',
	'%d byte(s)' => '%d ბაიტი',
	'No commands to execute.' => 'შესასრულებელი ბრძანება არაა.',
	'Unable to upload a file.' => 'ფაილი არ აიტვირთა სერვერზე.',
	'File upload' => 'ფაილის ატვირთვა სერვერზე',
	'File uploads are disabled.' => 'ფაილის სერვერზე ატვირთვა გათიშულია.',
	'Routine has been called, %d row(s) affected.' => 'გამოძახებულია პროცედურა, შეიცვალა %d ჩანაწერი.',
	'Call' => 'გამოძახეება',
	'No extension' => 'გაფართოება არაა',
	'None of the supported PHP extensions (%s) are available.' => 'არც ერთი მხარდაჭერილი გაფართოება არ მოიძებნა (%s).',
	'Session support must be enabled.' => 'ჩართული უნდა იყოს სესია.',
	'Session expired, please login again.' => 'სესიის მოქმედების დრო ამოიწურა, გაიარეთ ხელახალი ავტორიზაცია.',
	'Text length' => 'ტექსტის სიგრძე',
	'Foreign key has been dropped.' => 'გარე გასაღები წაიშალა.',
	'Foreign key has been altered.' => 'გარე გასაღები შეიცვალა.',
	'Foreign key has been created.' => 'გარე გასაღები შეიქმნა.',
	'Foreign key' => 'გარე გასაღები',
	'Change' => 'შეცვლა',
	'Source' => 'წყარო',
	'Target' => 'სამიზნე',
	'Add column' => 'ველის დამატება',
	'Alter' => 'შეცვლა',
	'Add foreign key' => 'გარე გასაღები დამატება',
	'ON DELETE' => 'წაშლისას',
	'ON UPDATE' => 'განახლებისას',
	'Index Type' => 'ინდექსის სახეობა',
	'length' => 'სიგრძე',
	'View has been dropped.' => 'წარმოდგენა წაიშალა.',
	'View has been altered.' => 'წარმოდგენა შეიცვალა.',
	'View has been created.' => 'წარმოდგენა შეიქმნა.',
	'Alter view' => 'წარმოდგენის შეცვლა',
	'Create view' => 'წარმოდგენის შექმნა',
	'Name' => 'სახელი',
	'Process list' => 'პროცესების სია',
	'%d process(es) have been killed.' => 'გაითიშა %d პროცესი.',
	'Kill' => 'დასრულება',
	'Parameter name' => 'პარამეტრი',
	'Database schema' => 'ბაზის სქემა',
	'Create procedure' => 'პროცედურის შექმნა',
	'Create function' => 'ფუნქციის შექმნა',
	'Routine has been dropped.' => 'პროცედურა წაიშალა.',
	'Routine has been altered.' => 'პროცედურა შეიცვალა.',
	'Routine has been created.' => 'პროცედურა შეიქმნა.',
	'Alter function' => 'ფუნქციის შეცვლა',
	'Alter procedure' => 'პროცედურის შეცვლა',
	'Return type' => 'დაბრუნების სახეობა',
	'Add trigger' => 'ტრიგერის დამატება',
	'Trigger has been dropped.' => 'ტრიგერი წაიშალა.',
	'Trigger has been altered.' => 'ტრიგერი შეიცვალა.',
	'Trigger has been created.' => 'ტრიგერი შეიქმნა.',
	'Alter trigger' => 'ტრიგერის შეცვლა',
	'Create trigger' => 'ტრიგერის შექმნა',
	'Time' => 'დრო',
	'Event' => 'ღონისძიება',
	'%s version: %s through PHP extension %s' => 'ვერსია %s: %s PHP-გაფართოება %s',
	'%d row(s)' => '%d რიგი',
	'Remove' => 'წაშლა',
	'Are you sure?' => 'ნამდვილად?',
	'Privileges' => 'უფლებამოსილება',
	'Create user' => 'მომხმარებლის შექმან',
	'User has been dropped.' => 'მომხმარებელი წაიშალა.',
	'User has been altered.' => 'მომხმარებელი შეიცვალა.',
	'User has been created.' => 'მომხმარებელი შეიქმნა.',
	'Hashed' => 'ჰეშირებული',
	'Column' => 'ველი',
	'Routine' => 'პროცედურა',
	'Grant' => 'დაშვება',
	'Revoke' => 'შეზღუდვა',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST ინფორმაცია ძალიან დიდია. შეამცირეთ ზომა ან გაზარდეს POST ინფორმაციის ზომა პარამეტრებიდან %s.',
	'Logged as: %s' => 'შესული ხართ როგორც: %s',
	'Move up' => 'ზემოთ ატანა',
	'Move down' => 'ქვემოთ ჩატანა',
	'Functions' => 'ფუნქციები',
	'Aggregation' => 'აგრეგაცია',
	'Export' => 'ექსპორტი',
	'Output' => 'გამომავალი ინფორმაცია',
	'open' => 'გახსნა',
	'save' => 'შენახვა',
	'Format' => 'ფორმატი',
	'Tables' => 'ცხრილები',
	'Data' => 'ინფორმაცია',
	'Event has been dropped.' => 'ღონისძიება წაიშალა.',
	'Event has been altered.' => 'ღონისძიება შეიცვალა.',
	'Event has been created.' => 'ღონისძიება შეიქმნა.',
	'Alter event' => 'ღონისძიების შეცვლა',
	'Create event' => 'ღონისძიების შექმნა',
	'At given time' => 'მოცემულ დროში',
	'Every' => 'ყოველ',
	'Events' => 'ღონისძიება',
	'Schedule' => 'განრიგი',
	'Start' => 'დასაწყისი',
	'End' => 'დასასრული',
	'Status' => 'მდგომარეობა',
	'On completion preserve' => 'შენახვა დასრულებისას',
	'Tables and views' => 'ცხრილები და წარმოდგენები',
	'Data Length' => 'ინფორმაციის მოცულობა',
	'Index Length' => 'ინდექსების მოცულობა',
	'Data Free' => 'თავისუფალი სივრცე',
	'Collation' => 'კოდირება',
	'Analyze' => 'ანალიზი',
	'Optimize' => 'ოპტიმიზაცია',
	'Check' => 'შემოწმება',
	'Repair' => 'გასწორება',
	'Truncate' => 'გასუფთავება',
	'Tables have been truncated.' => 'ცხრილი გასუფთავდა.',
	'Rows' => 'რიგი',
	',' => ' ',
	'0123456789' => '0123456789',
	'Tables have been moved.' => 'ცხრილი გადაადგილდა.',
	'Move to other database' => 'გადატანა სხვა ბაზაში',
	'Move' => 'გადატანა',
	'Engine' => 'ძრავი',
	'Save and continue edit' => 'შენახვა და ცვლილების გაგრძელება',
	'original' => 'საწყისი',
	'%d item(s) have been affected.' => 'შეიცვალა %d ჩანაწერი.',
	'Whole result' => 'სრული შედეგი',
	'Tables have been dropped.' => 'ცხრილები წაიშალა.',
	'Clone' => 'კლონირება',
	'Partition by' => 'დაყოფა',
	'Partitions' => 'დანაყოფები',
	'Partition name' => 'დანაყოფის სახელი',
	'Values' => 'პარამეტრები',
	'%d row(s) have been imported.' => 'დაიმპორტდა %d რიგი.',
	'Import' => 'იმპორტი',
	'Stop on error' => 'გაჩერება შეცდომისას',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'მიღწეულია დაშვებული ველების მაქსიმალური რაოდენობა, გაზარდეთ %s.',
	'anywhere' => 'ნებისმიერ ადგილას',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5.$3.$1',
	'[yyyy]-mm-dd' => 'დდ.თთ.[წწწწ]',
	'History' => 'ისტორია',
	'Variables' => 'ცვლადები',
	'Relations' => 'ურთიერთობა',
	'Run file' => 'ფაილის გაშვება',
	'Clear' => 'გასუფთავება',
	'Maximum allowed file size is %sB.' => 'ფაილის მაქსიმალური ზომა - %sB.',
	'Numbers' => 'ციფრები',
	'Date and time' => 'დრო და თარიღი',
	'Binary' => 'ორობითი',
	'Lists' => 'სია',
	'Editor' => 'რედაქტორი',
	'Webserver file %s' => 'ფაილი %s ვებსერვერზე',
	'File does not exist.' => 'ასეთი ფაილი არ არსებობს.',
	'%d in total' => 'სულ %d',
	'Permanent login' => 'სისტემაში დარჩენა',
	'Databases have been dropped.' => 'ბაზა წაიშალა.',
	'Search data in tables' => 'ცხრილებში ძებნა',
	'Schema' => 'სქემა',
	'Alter schema' => 'სქემის შეცვლა',
	'Create schema' => 'ახალი სქემა',
	'Schema has been dropped.' => 'სქემა წაიშალა.',
	'Schema has been created.' => 'შეიქმნა ახალი სქემა.',
	'Schema has been altered.' => 'სქემა შეიცვალა.',
	'Sequences' => 'მიმდევრობა',
	'Create sequence' => 'მიმდევრობის შექმნა',
	'Alter sequence' => 'მიმდევრობის შეცვლა',
	'Sequence has been dropped.' => 'მიმდევრობა წაიშალა.',
	'Sequence has been created.' => 'მიმდევრობა შეიქმნა.',
	'Sequence has been altered.' => 'მიმდევრობა შეიცვალა.',
	'User types' => 'მომხმარებლის სახეობა',
	'Create type' => 'სახეობის შექმნა',
	'Alter type' => 'სახეობის შეცვლა',
	'Type has been dropped.' => 'სახეობა წაიშალა.',
	'Type has been created.' => 'სახეობა შეიქმნა.',
	'Ctrl+click on a value to modify it.' => 'შესაცვლელად გამოიყენეთ Ctrl+თაგვის ღილაკი.',
	'Use edit link to modify this value.' => 'ამ მნიშვნელობის შესაცვლელად გამოიყენეთ ბმული «შეცვლა».',
	'last' => 'ბოლო',
	'From server' => 'სერვერიდან',
	'System' => 'სისტემა',
	'Select data' => 'არჩევა',
	'Show structure' => 'სტრუქტურის ჩვენება',
	'empty' => 'ცარიელი',
	'Network' => 'ქსელი',
	'Geometry' => 'გეომეტრია',
	'File exists.' => 'ფაილი უკვე არსებობს.',
	'%d query(s) executed OK.' => '%d მოთხოვნა შესრულდა.',
	'Show only errors' => 'მხოლოდ შეცდომები',
	'Refresh' => 'განახლება',
	'Invalid schema.' => 'არასწორი სქემა.',
	'Please use one of the extensions %s.' => 'გამოიყენეთ ერთ-ერთი გაფართოება %s.',
	'now' => 'ახლა',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'ცხრილი დაკოპირდა.',
	'Copy' => 'კოპირება',
	'Permanent link' => 'მუდმივი ბმული',
	'Edit all' => 'ყველას შეცვლა',
	'HH:MM:SS' => 'სთ:წთ:წმ',
	'Tables have been optimized.' => 'ცხრილებს გაუკეთდა ოპტიმიზაცია.',
	'Materialized view' => 'მატერიალური ხედი',
	'Vacuum' => 'ვაკუუმი',
	'Selected' => 'არჩეული',
	'File must be in UTF-8 encoding.' => 'ფაილი უნდა იყოს კოდირებაში UTF-8.',
	'Modify' => 'შეცვლა',
	'Loading' => 'ჩატვირთვა',
	'Load more data' => 'მეტი ინფორმაციის ჩატვირთვა',
	'ATTACH queries are not supported.' => 'ATTACH-მოთხოვნები არაა მხარდაჭერილი.',
	'%d / ' => '%d / ',
	'Limit rows' => 'რიგების შეზღუდვა',
	'Default value' => 'სტანდარტული მნიშვნელობა',
	'Full table scan' => 'სრული ცხრილის ანალიზი',
	'Too many unsuccessful logins, try again in %d minute(s).' => 'ძალიან ბევრჯერ შეგეშალათ მომხმარებელი და პაროლი. სცადეთ %d წუთში.',
	'Master password expired. <a href="https://www.adminer.org/en/extension/"%s>Implement</a> %s method to make it permanent.' => 'ძირითად პაროლს ვადა გაუვიდა. <a href="https://www.adminer.org/en/extension/"%s>გამოიყენეთ</a> მეთოდი %s, რათა ის მუდმივი გახადოთ.',
	'If you did not send this request from Adminer then close this page.' => 'ეს მოთხოვნა თქვენ თუ არ გაგიგზავნაით Adminer-იდან, დახურეთ ეს ფანჯარა..',
	'You can upload a big SQL file via FTP and import it from server.' => 'დიდი ფაილი უნდა ატვირტოთ FTP-თი და შემდეგ გაუკეთოთ იმპორტი სერვერიდან.',
	'Size' => 'ზომა',
	'Compute' => 'გამოთვლა',
	'You are offline.' => 'არ გაგივლიათ ავტორიზაცია.',
	'You have no privileges to update this table.' => 'ამ ცხრილის განახლების უფლება არ გაქვთ.',
	'Saving' => 'შენახვა',
	'yes' => 'კი',
	'no' => 'არა',
	'Routines' => 'რუტინები',
	'Target table' => 'მიზნობრივი ცხრილი',
	'Strings' => 'ველები',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'საწყისი და მიზნობრივი ველები უნდა იყოს ერთიდაიგივე სახეობის, მიზნობრივ ველზე უნდა იყოს ინდექსი და უნდა არსებობდეს შესაბამისი ინფორმაცია.',
	'Drop %s?' => 'წაიშალოს %s?',
	'Warnings' => 'გაფრთხილება',
	'Adminer does not support accessing a database without a password, <a href="https://www.adminer.org/en/password/"%s>more information</a>.' => 'უპაროლო წვდომა ბაზასთან არაა დაშვებული Adminer-ში, მეტი ინფორმაციისთვის ეწვიეთ <a href="https://www.adminer.org/en/password/"%s>ბმულს</a>.',
	'DB' => 'ბაზა',
	'Thanks for using Adminer, consider <a href="https://www.adminer.org/en/donation/">donating</a>.' => 'მადლობას გიხდით Adminer-ით სარგებლობისთვის, გადახედეთ ბმულს <a href="https://www.adminer.org/en/donation/">შემოწირულობა</a>.',
	'The action will be performed after successful login with the same credentials.' => 'მოქმედება შესრულდება იგივე მომხმარებლით წარმატებული ავტორიზაციის შემდეგ.',
	'Connecting to privileged ports is not allowed.' => 'პრივილეგირებულ პორტთან წვდომა დაუშვებელია.',
	'There is a space in the input password which might be the cause.' => 'პაროლში არის გამოტოვება, შეიძლება ეს ქმნის პრობლემას.',
	'Unknown error.' => 'უცნობი შეცდომა.',
	'Database does not support password.' => 'ბაზაში არაა მხარდაჭერილი პაროლი.',
	'Disable %s or enable %s or %s extensions.' => 'გათიშეთ %s ან ჩართეთ %s ან %s გაფართოება.',
);

// run `php ../../lang.php ka` to update this file
