<?php
namespace Adminer;

Lang::$translations = array(
	'System' => 'System',
	'Server' => 'Server',
	'Username' => 'Brugernavn',
	'Password' => 'Kodeord',
	'Permanent login' => 'Permanent login',
	'Login' => 'Log ind',
	'Logout' => 'Log ud',
	'Logged as: %s' => 'Logget ind som: %s',
	'Logout successful.' => 'Log af vellykket.',
	'Invalid credentials.' => 'Ugyldige log ind oplysninger.',
	'Master password expired. <a href="https://www.adminer.org/en/extension/"%s>Implement</a> %s method to make it permanent.' => 'Master-kodeordet er udløbet. <a href="https://www.adminer.org/en/extension/"%s>Implementer</a> en metode for %s for at gøre det permanent.',
	'Language' => 'Sprog',
	'Invalid CSRF token. Send the form again.' => 'Ugyldigt CSRF-token - Genindsend formen.',
	'No extension' => 'Ingen udvidelse',
	'None of the supported PHP extensions (%s) are available.' => 'Ingen af de understøttede PHP-udvidelser (%s) er tilgængelige.',
	'Session support must be enabled.' => 'Session support skal være slået til.',
	'Session expired, please login again.' => 'Sessionen er udløbet - Log venligst ind igen.',
	'%s version: %s through PHP extension %s' => '%s version: %s via PHP-udvidelse %s',
	'Refresh' => 'Genindlæs',
	'ltr' => 'ltr',
	'Privileges' => 'Privilegier',
	'Create user' => 'Opret bruger',
	'User has been dropped.' => 'Brugeren slettet.',
	'User has been altered.' => 'Brugeren ændret.',
	'User has been created.' => 'Brugeren oprettet.',
	'Hashed' => 'Hashet',
	'Column' => 'Kolonne',
	'Routine' => 'Rutine',
	'Grant' => 'Giv privilegier',
	'Revoke' => 'Træk tilbage',
	'Process list' => 'Procesliste',
	'%d process(es) have been killed.' => array('%d proces afsluttet.', '%d processer afsluttet.'),
	'Kill' => 'Afslut',
	'Variables' => 'Variabler',
	'Status' => 'Status',
	'SQL command' => 'SQL-kommando',
	'%d query(s) executed OK.' => array('%d kald udført OK.', '%d kald udført OK.'),
	'Query executed OK, %d row(s) affected.' => array('Kald udført OK, %d række påvirket.', 'Kald udført OK, %d rækker påvirket.'),
	'No commands to execute.' => 'Ingen kommandoer at udføre.',
	'Error in query' => 'Fejl i forespørgelse',
	'Execute' => 'Kør',
	'Stop on error' => 'Stop ved fejl',
	'Show only errors' => 'Vis kun fejl',
	'%.3f s' => '%.3f s',
	'History' => 'Historik',
	'Clear' => 'Tøm',
	'Edit all' => 'Rediger alle',
	'File upload' => 'Fil upload',
	'From server' => 'Fra server',
	'Webserver file %s' => 'Webserver-fil %s',
	'Run file' => 'Kør fil',
	'File does not exist.' => 'Filen eksisterer ikke.',
	'File uploads are disabled.' => 'Fil upload er slået fra.',
	'Unable to upload a file.' => 'Kunne ikke uploade fil.',
	'Maximum allowed file size is %sB.' => 'Maksimum tilladte filstørrelse er %sB.',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Maks POST data er overskredet. Reducer mængden af data eller øg størrelsen i %s-konfigurationen.',
	'You can upload a big SQL file via FTP and import it from server.' => 'Du kan uploade en stor SQL-fil via FTP og importere den fra serveren.',
	'Export' => 'Eksport',
	'Output' => 'Resultat',
	'open' => 'Åben',
	'save' => 'Gem',
	'Format' => 'Format',
	'Data' => 'Data',
	'Database' => 'Database',
	'Use' => 'Brug',
	'Select database' => 'Vælg database',
	'Invalid database.' => 'Ugyldig database.',
	'Database has been dropped.' => 'Databasen er blevet slettet.',
	'Databases have been dropped.' => 'Databasene er blevet slettet.',
	'Database has been created.' => 'Databasen er oprettet.',
	'Database has been renamed.' => 'Databasen har fået nyt navn.',
	'Database has been altered.' => 'Databasen er ændret.',
	'Alter database' => 'Ændre database',
	'Create database' => 'Opret database',
	'Database schema' => 'Databaseskema',
	'Permanent link' => 'Permanent link',
	',' => ' ',
	'0123456789' => '0123456789',
	'Engine' => 'Motor',
	'Collation' => 'Tekstsortering',
	'Data Length' => 'Datalængde',
	'Index Length' => 'Indekslængde',
	'Data Free' => 'Fri data',
	'Rows' => 'Rader',
	'%d in total' => '%d total',
	'Analyze' => 'Analyser',
	'Optimize' => 'Optimaliser',
	'Vacuum' => 'Støvsug',
	'Check' => 'Tjek',
	'Repair' => 'Reparer',
	'Truncate' => 'Afkort',
	'Tables have been truncated.' => 'Tabellerne er blevet afkortet.',
	'Move to other database' => 'Flyt til anden database',
	'Move' => 'Flyt',
	'Tables have been moved.' => 'Tabellerne er blevet flyttet.',
	'Copy' => 'Kopier',
	'Tables have been copied.' => 'Tabellerne er blevet kopiert.',
	'Routines' => 'Rutiner',
	'Routine has been called, %d row(s) affected.' => array('Rutinen er udført, %d række påvirket.', 'Rutinen er udført, %d rækker påvirket.'),
	'Call' => 'Kald',
	'Parameter name' => 'Parameternavn',
	'Create procedure' => 'Opret procedure',
	'Create function' => 'Opret funktion',
	'Routine has been dropped.' => 'Rutinen er slettet.',
	'Routine has been altered.' => 'Rutinen er ændret.',
	'Routine has been created.' => 'Rutinen er oprettet.',
	'Alter function' => 'Ændre funktion',
	'Alter procedure' => 'Ændre procedure',
	'Return type' => 'Returtype',
	'Events' => 'Hændelser',
	'Event has been dropped.' => 'Hændelsen er slettet.',
	'Event has been altered.' => 'Hændelsen er ændret.',
	'Event has been created.' => 'Hændelsen er oprettet.',
	'Alter event' => 'Ændre hændelse',
	'Create event' => 'Opret hændelse',
	'At given time' => 'På givne tid',
	'Every' => 'Hver',
	'Schedule' => 'Tidsplan',
	'Start' => 'Start',
	'End' => 'Slut',
	'On completion preserve' => 'Ved fuldførelse bevar',
	'Tables' => 'Tabeller',
	'Tables and views' => 'Tabeller og views',
	'Table' => 'Tabel',
	'No tables.' => 'Ingen tabeller.',
	'Alter table' => 'Ændre tabel',
	'Create table' => 'Opret tabel',
	'Table has been dropped.' => 'Tabellen er slettet.',
	'Tables have been dropped.' => 'Tabellerne er slettet.',
	'Tables have been optimized.' => 'Tabellerne er blevet optimaliseret.',
	'Table has been altered.' => 'Tabellen er ændret.',
	'Table has been created.' => 'Tabellen er oprettet.',
	'Table name' => 'Tabelnavn',
	'Show structure' => 'Vis struktur',
	'engine' => 'motor',
	'collation' => 'sortering',
	'Column name' => 'Kolonnenavn',
	'Type' => 'Type',
	'Length' => 'Længde',
	'Auto Increment' => 'Auto Increment',
	'Options' => 'Valg',
	'Comment' => 'Kommentarer',
	'Default values' => 'Standardværdier',
	'Drop' => 'Drop',
	'Are you sure?' => 'Er du sikker?',
	'Move up' => 'Flyt op',
	'Move down' => 'Flyt ned',
	'Remove' => 'Fjern',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Maksimum antal feltnavne overskredet - øg venligst %s.',
	'Partition by' => 'Partition ved',
	'Partitions' => 'Partitioner',
	'Partition name' => 'Partitionsnavn',
	'Values' => 'Værdier',
	'View' => 'View',
	'View has been dropped.' => 'Viewet er slettet.',
	'View has been altered.' => 'Viewet er ændret.',
	'View has been created.' => 'Viewet er oprettet.',
	'Alter view' => 'Ændre view',
	'Create view' => 'Nyt view',
	'Indexes' => 'Indekser',
	'Indexes have been altered.' => 'Indekserne er ændret.',
	'Alter indexes' => 'Ændre indekser',
	'Add next' => 'Læg til næste',
	'Index Type' => 'Indekstype',
	'length' => 'længde',
	'Foreign keys' => 'Fremmednøgler',
	'Foreign key' => 'Fremmednøgle',
	'Foreign key has been dropped.' => 'Fremmednøglen er slettet.',
	'Foreign key has been altered.' => 'Fremmednøglen er ændret.',
	'Foreign key has been created.' => 'Fremmednøglen er oprettet.',
	'Target table' => 'Måltabel',
	'Change' => 'Ændre',
	'Source' => 'Kilde',
	'Target' => 'Mål',
	'Add column' => 'Tilføj kolonne',
	'Alter' => 'Ændre',
	'Add foreign key' => 'Tilføj fremmednøgle',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Kilde- og målkolonner skal have samme datatype, der skal være en indeks på mål-kolonnen, og data som refereres til skal eksistere.',
	'Triggers' => 'Triggere',
	'Add trigger' => 'Tilføj trigger',
	'Trigger has been dropped.' => 'Triggeren er slettet.',
	'Trigger has been altered.' => 'Triggeren er ændret.',
	'Trigger has been created.' => 'Triggeren er oprettet.',
	'Alter trigger' => 'Ændre trigger',
	'Create trigger' => 'Opret trigger',
	'Time' => 'Tid',
	'Event' => 'Hændelse',
	'Name' => 'Navn',
	'select' => 'Vis',
	'Select' => 'Vælg',
	'Select data' => 'Vælg data',
	'Functions' => 'Funktioner',
	'Aggregation' => 'Sammenfatning',
	'Search' => 'Søg',
	'anywhere' => 'hvorsomhelst',
	'Search data in tables' => 'Søg data i tabeller',
	'Sort' => 'Sorter',
	'descending' => 'faldende',
	'Limit' => 'Limit',
	'Text length' => 'Tekstlængde',
	'Action' => 'Handling',
	'Full table scan' => 'Fuld tabel-scan',
	'Unable to select the table' => 'Kan ikke vælge tabellen',
	'No rows.' => 'Ingen rækker.',
	'%d row(s)' => array('%d række', '%d rækker'),
	'Page' => 'Side',
	'last' => 'sidste',
	'Load more data' => 'Indlæs mere data',
	'Loading' => 'Indlæser',
	'Whole result' => 'Hele resultatet',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'Import' => 'Importer',
	'%d row(s) have been imported.' => array('%d række er importeret.', '%d rækker er importeret.'),
	'File must be in UTF-8 encoding.' => 'Filen skal være i UTF8-tegnkoding.',
	'Modify' => 'Ændre',
	'Ctrl+click on a value to modify it.' => 'Ctrl+klik på en værdi for at ændre den.',
	'Use edit link to modify this value.' => 'Brug rediger-link for at ændre dennne værdi.',
	'Item%s has been inserted.' => 'Emne%s er sat ind.',
	'Item has been deleted.' => 'Emnet er slettet.',
	'Item has been updated.' => 'Emnet er opdateret.',
	'%d item(s) have been affected.' => array('%d emne påvirket.', '%d emner påvirket.'),
	'New item' => 'Nyt emne',
	'original' => 'original',
	'empty' => 'tom',
	'edit' => 'rediger',
	'Edit' => 'Rediger',
	'Insert' => 'Indsæt',
	'Save' => 'Gem',
	'Save and continue edit' => 'Gem og fortsæt redigering',
	'Save and insert next' => 'Gem og indsæt næste',
	'Selected' => 'Valgt',
	'Clone' => 'Klon',
	'Delete' => 'Slet',
	'You have no privileges to update this table.' => 'Du mangler rettigheder til at ændre denne tabellen.',
	'Numbers' => 'Nummer',
	'Date and time' => 'Dato og tid',
	'Strings' => 'Strenge',
	'Binary' => 'Binær',
	'Lists' => 'Lister',
	'Network' => 'Netværk',
	'Geometry' => 'Geometri',
	'Relations' => 'Relationer',
	'Editor' => 'Redigering',
	'$1-$3-$5' => '$6/$4 $1',
	'[yyyy]-mm-dd' => 'd/m [åååå]',
	'HH:MM:SS' => 'HH:MM:SS',
	'now' => 'nu',
	'yes' => 'ja',
	'no' => 'nej',
	'File exists.' => 'Filen findes.',
	'Please use one of the extensions %s.' => 'Brug venligst en af filendelserne %s.',
	'Alter schema' => 'Ændre skema',
	'Create schema' => 'Opret skema',
	'Schema has been dropped.' => 'Skemaet er slettet.',
	'Schema has been created.' => 'Skemaet er oprettet.',
	'Schema has been altered.' => 'Skemaet er ændret.',
	'Schema' => 'Skema',
	'Invalid schema.' => 'Ugyldigt skema.',
	'Sequences' => 'Sekvenser',
	'Create sequence' => 'Opret sekvens',
	'Sequence has been dropped.' => 'Sekvensen er slettet.',
	'Sequence has been created.' => 'Sekvensen er oprettet.',
	'Sequence has been altered.' => 'Sekvensen er ændret.',
	'Alter sequence' => 'Ændre sekvens',
	'User types' => 'Brugertyper',
	'Create type' => 'Opret type',
	'Type has been dropped.' => 'Typen er slettet.',
	'Type has been created.' => 'Typen er oprettet.',
	'Alter type' => 'Ændre type',
	'Saving' => 'Gemmer',
);

// run `php ../../lang.php da` to update this file
