<?php
namespace Adminer;

Lang::$translations = array(
	'Login' => 'Login',
	'Logout successful.' => 'Sesión finalizada con éxito.',
	'Invalid credentials.' => 'Usuario y/o clave de acceso incorrecta.',
	'Server' => 'Servidor',
	'Username' => 'Usuario',
	'Password' => 'Contraseña',
	'Select database' => 'Seleccionar Base de datos',
	'Invalid database.' => 'Base de datos incorrecta.',
	'Table has been dropped.' => 'Tabla eliminada.',
	'Table has been altered.' => 'Tabla modificada.',
	'Table has been created.' => 'Tabla creada.',
	'Alter table' => 'Modificar tabla',
	'Create table' => 'Crear tabla',
	'Table name' => 'Nombre de la tabla',
	'engine' => 'motor',
	'collation' => 'colación',
	'Column name' => 'Nombre de columna',
	'Type' => 'Tipo',
	'Length' => 'Longitud',
	'Auto Increment' => 'Incremento automático',
	'Options' => 'Opciones',
	'Save' => 'Guardar',
	'Drop' => 'Eliminar',
	'Database has been dropped.' => 'Base de datos eliminada.',
	'Database has been created.' => 'Base de datos creada.',
	'Database has been renamed.' => 'Base de datos renombrada.',
	'Database has been altered.' => 'Base de datos modificada.',
	'Alter database' => 'Modificar Base de datos',
	'Create database' => 'Crear Base de datos',
	'SQL command' => 'Comando SQL',
	'Logout' => 'Cerrar sesión',
	'Use' => 'Usar',
	'No tables.' => 'No existen tablas.',
	'select' => 'registros',
	'Item has been deleted.' => 'Registro eliminado.',
	'Item has been updated.' => 'Registro modificado.',
	'Item%s has been inserted.' => 'Registro%s insertado.',
	'Edit' => 'Modificar',
	'Insert' => 'Agregar',
	'Save and insert next' => 'Guardar e insertar siguiente',
	'Delete' => 'Eliminar',
	'Database' => 'Base de datos',
	'DB' => 'BD',
	'Routines' => 'Procedimientos',
	'Indexes have been altered.' => 'Índices actualizados.',
	'Indexes' => 'Índices',
	'Alter indexes' => 'Modificar índices',
	'Add next' => 'Agregar',
	'Language' => 'Idioma',
	'Select' => 'Mostrar',
	'New item' => 'Nuevo Registro',
	'Search' => 'Condición',
	'Sort' => 'Ordenar',
	'descending' => 'descendiente',
	'Limit' => 'Limite',
	'No rows.' => 'No existen registros.',
	'Action' => 'Acción',
	'edit' => 'modificar',
	'Page' => 'Página',
	'Query executed OK, %d row(s) affected.' => array('Consulta ejecutada, %d registro afectado.', 'Consulta ejecutada, %d registros afectados.'),
	'Error in query' => 'Error al ejecutar consulta',
	'Unknown error.' => 'Error desconocido.',
	'Warnings' => 'Advertencias',
	'ATTACH queries are not supported.' => 'Consultas tipo ATTACH no soportadas.',
	'Execute' => 'Ejecutar',
	'Table' => 'Tabla',
	'Foreign keys' => 'Claves externas',
	'Triggers' => 'Disparadores',
	'View' => 'Vista',
	'Materialized view' => 'Vista materializada',
	'Unable to select the table' => 'No es posible seleccionar la tabla',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF inválido. Vuelva a enviar los datos del formulario.',
	'Comment' => 'Comentario',
	'Default values' => 'Valores predeterminados',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'Ningún comando para ejecutar.',
	'Unable to upload a file.' => 'No es posible cargar el archivo.',
	'File upload' => 'Importar archivo',
	'File uploads are disabled.' => 'Importación de archivos deshablilitada.',
	'Routine has been called, %d row(s) affected.' => array('Consulta ejecutada, %d registro afectado.', 'Consulta ejecutada, %d registros afectados.'),
	'Call' => 'Llamar',
	'No extension' => 'No hay extensión',
	'None of the supported PHP extensions (%s) are available.' => 'Ninguna de las extensiones PHP soportadas (%s) está disponible.',
	'Session support must be enabled.' => 'Deben estar habilitadas las sesiones.',
	'Session expired, please login again.' => 'Sesión caducada, por favor escriba su clave de nuevo.',
	'Text length' => 'Longitud de texto',
	'Foreign key has been dropped.' => 'Clave foranea eliminada.',
	'Foreign key has been altered.' => 'Clave foranea modificada.',
	'Foreign key has been created.' => 'Clave foranea creada.',
	'Foreign key' => 'Clave externa',
	'Target table' => 'Tabla de destino',
	'Change' => 'Modificar',
	'Source' => 'Origen',
	'Target' => 'Destino',
	'Add column' => 'Agregar columna',
	'Alter' => 'Modificar',
	'Add foreign key' => 'Agregar clave externa',
	'ON DELETE' => 'AL BORRAR',
	'ON UPDATE' => 'AL ACTUALIZAR',
	'Index Type' => 'Tipo de índice',
	'length' => 'longitud',
	'View has been dropped.' => 'Vista eliminada.',
	'View has been altered.' => 'Vista modificada.',
	'View has been created.' => 'Vista creada.',
	'Alter view' => 'Modificar vista',
	'Create view' => 'Crear vista',
	'Name' => 'Nombre',
	'Process list' => 'Lista de procesos',
	'%d process(es) have been killed.' => array('%d proceso detenido.', '%d procesos detenidos.'),
	'Kill' => 'Detener',
	'Parameter name' => 'Nombre de Parámetro',
	'Database schema' => 'Esquema de base de datos',
	'Create procedure' => 'Crear procedimiento',
	'Create function' => 'Crear función',
	'Routine has been dropped.' => 'Procedimiento eliminado.',
	'Routine has been altered.' => 'Procedimiento modificado.',
	'Routine has been created.' => 'Procedimiento creado.',
	'Alter function' => 'Modificar función',
	'Alter procedure' => 'Modificar procedimiento',
	'Return type' => 'Tipo de valor de vuelta',
	'Add trigger' => 'Agregar disparador',
	'Trigger has been dropped.' => 'Disparador eliminado.',
	'Trigger has been altered.' => 'Disparador modificado.',
	'Trigger has been created.' => 'Disparador creado.',
	'Alter trigger' => 'Modificar Disparador',
	'Create trigger' => 'Agregar Disparador',
	'Time' => 'Tiempo',
	'Event' => 'Evento',
	'%s version: %s through PHP extension %s' => 'Versión %s: %s a través de la extensión de PHP %s',
	'%d row(s)' => array('%d registro', '%d registros'),
	'Remove' => 'Eliminar',
	'Are you sure?' => '¿Está seguro?',
	'Privileges' => 'Privilegios',
	'Create user' => 'Crear Usuario',
	'User has been dropped.' => 'Usuario eliminado.',
	'User has been altered.' => 'Usuario modificado.',
	'User has been created.' => 'Usuario creado.',
	'Hashed' => 'Hash',
	'Column' => 'Columna',
	'Routine' => 'Rutina',
	'Grant' => 'Conceder',
	'Revoke' => 'Impedir',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST data demasiado grande. Reduzca el tamaño o aumente la directiva de configuración %s.',
	'You can upload a big SQL file via FTP and import it from server.' => 'Usted puede cargar un SQL grande mediante FTP e importarlo desde el servidor.',
	'You are offline.' => 'Usted no esta en linea.',
	'Logged as: %s' => 'Logueado como: %s',
	'Move up' => 'Mover arriba',
	'Move down' => 'Mover abajo',
	'Functions' => 'Funciones',
	'Aggregation' => 'Agregados',
	'Export' => 'Exportar',
	'Output' => 'Salida',
	'open' => 'abrir',
	'save' => 'guardar',
	'Format' => 'Formato',
	'Tables' => 'Tablas',
	'Data' => 'Datos',
	'Event has been dropped.' => 'Evento eliminado.',
	'Event has been altered.' => 'Evento modificado.',
	'Event has been created.' => 'Evento creado.',
	'Alter event' => 'Modificar Evento',
	'Create event' => 'Crear Evento',
	'At given time' => 'En el momento indicado',
	'Every' => 'Cada',
	'Events' => 'Eventos',
	'Schedule' => 'Agenda',
	'Start' => 'Inicio',
	'End' => 'Fin',
	'Status' => 'Estado',
	'On completion preserve' => 'Al completar mantener',
	'Tables and views' => 'Tablas y vistas',
	'Data Length' => 'Longitud de datos',
	'Index Length' => 'Longitud de índice',
	'Data Free' => 'Espacio libre',
	'Collation' => 'Colación',
	'Analyze' => 'Analizar',
	'Optimize' => 'Optimizar',
	'Check' => 'Comprobar',
	'Repair' => 'Reparar',
	'Truncate' => 'Vaciar',
	'Tables have been truncated.' => 'Las tablas han sido vaciadas.',
	'Rows' => 'Registros',
	',' => ' ',
	'0123456789' => '0123456789',
	'Tables have been moved.' => 'Se movieron las tablas.',
	'Move to other database' => 'Mover a otra base de datos',
	'Move' => 'Mover',
	'Engine' => 'Motor',
	'Save and continue edit' => 'Guardar y continuar editando',
	'original' => 'original',
	'Tables have been dropped.' => 'Tablas eliminadas.',
	'%d item(s) have been affected.' => array('%d elemento afectado.', '%d elementos afectados.'),
	'Whole result' => 'Resultado completo',
	'Clone' => 'Clonar',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Excedida la cantidad máxima de campos permitidos. Por favor aumente %s.',
	'Partition by' => 'Particionar por',
	'Partitions' => 'Particiones',
	'Partition name' => 'Nombre de partición',
	'Values' => 'Valores',
	'%d row(s) have been imported.' => array('%d registro importado.', '%d registros importados.'),
	'File must be in UTF-8 encoding.' => 'El archivo tiene que ser codificacion UTF-8.',
	'anywhere' => 'donde sea',
	'Import' => 'Importar',
	'Stop on error' => 'Parar en caso de error',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'dd/mm/[aaaa]',
	'History' => 'Histórico',
	'Variables' => 'Variables',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Las columnas de origen y destino deben ser del mismo tipo, debe existir un índice entre las columnas del destino y el registro referenciado debe existir también.',
	'Relations' => 'Relaciones',
	'Run file' => 'Ejecutar Archivo',
	'Clear' => 'Vaciar',
	'Maximum allowed file size is %sB.' => 'El tamaño máximo de archivo es %sB.',
	'Numbers' => 'Números',
	'Date and time' => 'Fecha y hora',
	'Strings' => 'Cadena',
	'Binary' => 'Binario',
	'Lists' => 'Listas',
	'Editor' => 'Editor',
	'Webserver file %s' => 'Archivo de servidor web %s',
	'File does not exist.' => 'Ese archivo no existe.',
	'%d in total' => '%d en total',
	'Permanent login' => 'Guardar contraseña',
	'Databases have been dropped.' => 'Bases de datos eliminadas.',
	'Search data in tables' => 'Buscar datos en tablas',
	'Schema' => 'Esquema',
	'Alter schema' => 'Modificar esquema',
	'Create schema' => 'Crear esquema',
	'Schema has been dropped.' => 'Esquema eliminado.',
	'Schema has been created.' => 'Esquema creado.',
	'Schema has been altered.' => 'Esquema modificado.',
	'Sequences' => 'Secuencias',
	'Create sequence' => 'Crear secuencias',
	'Alter sequence' => 'Modificar secuencia',
	'Sequence has been dropped.' => 'Secuencia eliminada.',
	'Sequence has been created.' => 'Secuencia creada.',
	'Sequence has been altered.' => 'Secuencia modificada.',
	'User types' => 'Tipos definidos por el usuario',
	'Create type' => 'Crear tipo',
	'Alter type' => 'Modificar tipo',
	'Type has been dropped.' => 'Tipo eliminado.',
	'Type has been created.' => 'Tipo creado.',
	'Ctrl+click on a value to modify it.' => 'Ctrl+clic sobre el valor para editarlo.',
	'Use edit link to modify this value.' => 'Utilice el enlace de edición para realizar cambios.',
	'last' => 'último',
	'From server' => 'Desde servidor',
	'System' => 'Motor de base de datos',
	'Select data' => 'Visualizar contenido',
	'Show structure' => 'Mostrar estructura',
	'empty' => 'ninguno',
	'Network' => 'Red',
	'Geometry' => 'Geometría',
	'File exists.' => 'Ese archivo ya existe.',
	'%d query(s) executed OK.' => array('%d sentencia SQL ejecutada correctamente.', '%d sentencias SQL ejecutadas correctamente.'),
	'Show only errors' => 'Mostrar solamente errores',
	'Refresh' => 'Actualizar',
	'Invalid schema.' => 'Esquema inválido.',
	'Please use one of the extensions %s.' => 'Por favor, use una de las extensiones %s.',
	'now' => 'ahora',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'Tablas copiadas.',
	'Copy' => 'Copiar',
	'Permanent link' => 'Enlace permanente',
	'Edit all' => 'Editar todos',
	'HH:MM:SS' => 'HH:MM:SS',

	'Loaded plugins' => 'Plugins cargados',
	'%s must <a%s>return an array</a>.' => '%s tiene que <a%s>retornar un arreglo</a>.',
	'<a%s>Configure</a> %s in %s.' => '<a%s>Configurar</a> %s en %s.',
	'There is a space in the input password which might be the cause.' => 'Hay un espacio en el password, lo cual puede ser la causa.',
	'Adminer does not support accessing a database without a password, <a href="https://www.adminer.org/en/password/"%s>more information</a>.' => 'Adminer no soporta accesar una base de datos sin clave, <a href="https://www.adminer.org/en/password/"%s>Ver detalles</a>.',
	'Database does not support password.' => 'La base de datos no soporta password.',
	'Too many unsuccessful logins, try again in %d minute(s).' => array('Muchos intentos de acceso Intente en %d minutos.'),
	'Master password expired. <a href="https://www.adminer.org/en/extension/"%s>Implement</a> %s method to make it permanent.' => 'Password maestro expirado. <a href="https://www.adminer.org/en/extension/"%s>Implemente</a> %s metodo para hacerlo permanente.',
	'If you did not send this request from Adminer then close this page.' => 'Si no puede enviar la solicitud por Adminer entonces cierre esta pagina.',
	'Connecting to privileged ports is not allowed.' => 'Conexiones a puertos privilegiados no son permitidas.',
	'Disable %s or enable %s or %s extensions.' => 'Desactivar %s o activar %s o %s extensiones.',
	'The action will be performed after successful login with the same credentials.' => 'La operacion sera ejecutada despues de ingresar nuevamente con las mismas credenciales.',
	'You have no privileges to update this table.' => 'Usted no tiene privilegios para actualizar esta tabla.',

	// Table check constraints
	'Checks' => 'Chequeos',
	'Create check' => 'Crear chequeo',
	'Alter check' => 'Cambiar chequeo',
	'Check has been created.' => 'Chequeo creado.',
	'Check has been altered.' => 'Chequeo cambiado.',
	'Check has been dropped.' => 'Chequeo eliminado.',
);

// run `php ../../lang.php es` to update this file
