<?php
namespace Adminer;

Lang::$translations = array(
	'Too many unsuccessful logins, try again in %d minute(s).' => array('Too many unsuccessful logins, try again in %d minute.', 'Too many unsuccessful logins, try again in %d minutes.'),
	'Query executed OK, %d row(s) affected.' => array('Query executed OK, %d row affected.', 'Query executed OK, %d rows affected.'),
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'Routine has been called, %d row(s) affected.' => array('Routine has been called, %d row affected.', 'Routine has been called, %d rows affected.'),
	'%d process(es) have been killed.' => array('%d process has been killed.', '%d processes have been killed.'),
	'%d / ' => '%d / ',
	'%d row(s)' => array('%d row', '%d rows'),
	'%d item(s) have been affected.' => array('%d item has been affected.', '%d items have been affected.'),
	'%d row(s) have been imported.' => array('%d row has been imported.', '%d rows have been imported.'),
	'%d in total' => '%d in total',
	'%d query(s) executed OK.' => array('%d query executed OK.', '%d queries executed OK.'),
);

// run `php ../../lang.php en` to update this file
