<?php
namespace Adminer;

Lang::$translations = array(
	'Login' => 'Login',
	'Logout successful.' => 'Abmeldung erfolgreich.',
	'Thanks for using Adminer, consider <a href="https://www.adminer.org/en/donation/">donating</a>.' => 'Danke, dass Sie Adminer genutzt haben. <a href="https://www.adminer.org/de/donation/">Spenden willkommen!</a>.',
	'Invalid credentials.' => 'Ungültige Anmelde-Informationen.',
	'Server' => 'Server',
	'Username' => 'Benutzer',
	'Password' => 'Passwort',
	'Select database' => 'Datenbank auswählen',
	'Invalid database.' => 'Datenbank ungültig.',
	'Table has been dropped.' => 'Tabelle wurde entfernt.',
	'Table has been altered.' => 'Tabelle wurde geändert.',
	'Table has been created.' => 'Tabelle wurde erstellt.',
	'Alter table' => 'Tabelle ändern',
	'Create table' => 'Tabelle erstellen',
	'Table name' => 'Name der Tabelle',
	'engine' => 'Speicher-Engine',
	'collation' => 'Kollation',
	'Column name' => 'Spaltenname',
	'Type' => 'Typ',
	'Length' => 'Länge',
	'Auto Increment' => 'Auto-Inkrement',
	'Options' => 'Optionen',
	'Save' => 'Speichern',
	'Drop' => 'Entfernen',
	'Database has been dropped.' => 'Datenbank wurde entfernt.',
	'Database has been created.' => 'Datenbank wurde erstellt.',
	'Database has been renamed.' => 'Datenbank wurde umbenannt.',
	'Database has been altered.' => 'Datenbank wurde geändert.',
	'Alter database' => 'Datenbank ändern',
	'Create database' => 'Datenbank erstellen',
	'SQL command' => 'SQL-Kommando',
	'Logout' => 'Abmelden',
	'Use' => 'Auswählen',
	'No tables.' => 'Keine Tabellen.',
	'select' => 'zeigen',
	'Item has been deleted.' => 'Datensatz wurde gelöscht.',
	'Item has been updated.' => 'Datensatz wurde geändert.',
	'Item%s has been inserted.' => 'Datensatz%s wurde eingefügt.',
	'Edit' => 'Bearbeiten',
	'Insert' => 'Einfügen',
	'Save and insert next' => 'Speichern und nächsten einfügen',
	'Delete' => 'Entfernen',
	'Database' => 'Datenbank',
	'Routines' => 'Routinen',
	'Indexes have been altered.' => 'Indizes geändert.',
	'Indexes' => 'Indizes',
	'Alter indexes' => 'Indizes ändern',
	'Add next' => 'Hinzufügen',
	'Language' => 'Sprache',
	'Select' => 'Daten zeigen von',
	'New item' => 'Neuer Datensatz',
	'Search' => 'Suchen',
	'Sort' => 'Ordnen',
	'descending' => 'absteigend',
	'Limit' => 'Begrenzung',
	'No rows.' => 'Keine Datensätze.',
	'Action' => 'Aktion',
	'edit' => 'bearbeiten',
	'Page' => 'Seite',
	'Query executed OK, %d row(s) affected.' => array('Abfrage ausgeführt, %d Datensatz betroffen.', 'Abfrage ausgeführt, %d Datensätze betroffen.'),
	'Error in query' => 'Fehler in der SQL-Abfrage',
	'Execute' => 'Ausführen',
	'Table' => 'Tabelle',
	'Foreign keys' => 'Fremdschlüssel',
	'Triggers' => 'Trigger',
	'View' => 'View',
	'Unable to select the table' => 'Auswahl der Tabelle fehlgeschlagen',
	'Invalid CSRF token. Send the form again.' => 'CSRF Token ungültig. Bitte die Formulardaten erneut abschicken.',
	'Comment' => 'Kommentar',
	'Default values' => 'Vorgabewerte festlegen',
	'%d byte(s)' => array('%d Byte', '%d Bytes'),
	'No commands to execute.' => 'Kein Kommando vorhanden.',
	'Unable to upload a file.' => 'Hochladen von Datei fehlgeschlagen.',
	'File upload' => 'Datei importieren',
	'File uploads are disabled.' => 'Importieren von Dateien abgeschaltet.',
	'Routine has been called, %d row(s) affected.' => array('Routine wurde ausgeführt, %d Datensatz betroffen.', 'Routine wurde ausgeführt, %d Datensätze betroffen.'),
	'Call' => 'Aufrufen',
	'No extension' => 'Keine Erweiterungen installiert',
	'None of the supported PHP extensions (%s) are available.' => 'Keine der unterstützten PHP-Erweiterungen (%s) ist vorhanden.',
	'Session support must be enabled.' => 'Unterstüzung für PHP-Sessions muss aktiviert sein.',
	'Session expired, please login again.' => 'Sitzungsdauer abgelaufen, bitte erneut anmelden.',
	'Text length' => 'Textlänge',
	'Foreign key has been dropped.' => 'Fremdschlüssel wurde entfernt.',
	'Foreign key has been altered.' => 'Fremdschlüssel wurde geändert.',
	'Foreign key has been created.' => 'Fremdschlüssel wurde erstellt.',
	'Foreign key' => 'Fremdschlüssel',
	'Target table' => 'Zieltabelle',
	'Change' => 'Ändern',
	'Source' => 'Ursprung',
	'Target' => 'Ziel',
	'Add column' => 'Spalte hinzufügen',
	'Alter' => 'Ändern',
	'Add foreign key' => 'Fremdschlüssel hinzufügen',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Index-Typ',
	'length' => 'Länge',
	'View has been dropped.' => 'View wurde entfernt.',
	'View has been altered.' => 'View wurde geändert.',
	'View has been created.' => 'View wurde erstellt.',
	'Alter view' => 'View ändern',
	'Create view' => 'View erstellen',
	'Name' => 'Name',
	'Process list' => 'Prozessliste',
	'%d process(es) have been killed.' => array('%d Prozess gestoppt.', '%d Prozesse gestoppt.'),
	'Kill' => 'Anhalten',
	'Parameter name' => 'Name des Parameters',
	'Database schema' => 'Datenbankschema',
	'Create procedure' => 'Prozedur erstellen',
	'Create function' => 'Funktion erstellen',
	'Routine has been dropped.' => 'Routine wurde entfernt.',
	'Routine has been altered.' => 'Routine wurde geändert.',
	'Routine has been created.' => 'Routine wurde erstellt.',
	'Alter function' => 'Funktion ändern',
	'Alter procedure' => 'Prozedur ändern',
	'Return type' => 'Typ des Rückgabewertes',
	'Add trigger' => 'Trigger hinzufügen',
	'Trigger has been dropped.' => 'Trigger wurde entfernt.',
	'Trigger has been altered.' => 'Trigger wurde geändert.',
	'Trigger has been created.' => 'Trigger wurde erstellt.',
	'Alter trigger' => 'Trigger ändern',
	'Create trigger' => 'Trigger erstellen',
	'Time' => 'Zeitpunkt',
	'Event' => 'Ereignis',
	'%s version: %s through PHP extension %s' => 'Version %s: %s mit PHP-Erweiterung %s',
	'%d row(s)' => array('%d Datensatz', '%d Datensätze'),
	'Remove' => 'Entfernen',
	'Are you sure?' => 'Sind Sie sicher?',
	'Privileges' => 'Rechte',
	'Create user' => 'Benutzer erstellen',
	'User has been dropped.' => 'Benutzer wurde entfernt.',
	'User has been altered.' => 'Benutzer wurde geändert.',
	'User has been created.' => 'Benutzer wurde erstellt.',
	'Hashed' => 'Hashed',
	'Column' => 'Spalte',
	'Columns' => 'Spalten',
	'Routine' => 'Routine',
	'Grant' => 'Erlauben',
	'Revoke' => 'Widerrufen',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST-Daten sind zu groß. Reduzieren Sie die Größe oder vergrößern Sie den Wert %s in der Konfiguration.',
	'Logged as: %s' => 'Angemeldet als: %s',
	'Move up' => 'Nach oben',
	'Move down' => 'Nach unten',
	'Functions' => 'Funktionen',
	'Aggregation' => 'Aggregationen',
	'Export' => 'Exportieren',
	'Output' => 'Ergebnis',
	'open' => 'anzeigen',
	'save' => 'Datei',
	'Format' => 'Format',
	'Tables' => 'Tabellen',
	'Data' => 'Daten',
	'Event has been dropped.' => 'Ereignis wurde entfernt.',
	'Event has been altered.' => 'Ereignis wurde geändert.',
	'Event has been created.' => 'Ereignis wurde erstellt.',
	'Alter event' => 'Ereignis ändern',
	'Create event' => 'Ereignis erstellen',
	'At given time' => 'Zur angegebenen Zeit',
	'Every' => 'Jede',
	'Events' => 'Ereignisse',
	'Schedule' => 'Zeitplan',
	'Start' => 'Start',
	'End' => 'Ende',
	'Status' => 'Status',
	'On completion preserve' => 'Nach der Ausführung erhalten',
	'Tables and views' => 'Tabellen und Views',
	'Data Length' => 'Datengröße',
	'Index Length' => 'Indexgröße',
	'Data Free' => 'Freier Bereich',
	'Collation' => 'Kollation',
	'Analyze' => 'Analysieren',
	'Optimize' => 'Optimieren',
	'Check' => 'Prüfen',
	'Repair' => 'Reparieren',
	'Truncate' => 'Leeren (truncate)',
	'Tables have been truncated.' => 'Tabellen wurden geleert (truncate).',
	'Rows' => 'Datensätze',
	',' => ' ',
	'0123456789' => '0123456789',
	'Tables have been moved.' => 'Tabellen verschoben.',
	'Move to other database' => 'In andere Datenbank verschieben',
	'Move' => 'Verschieben',
	'Engine' => 'Speicher-Engine',
	'Save and continue edit' => 'Speichern und weiter bearbeiten',
	'original' => 'Original',
	'Tables have been dropped.' => 'Tabellen wurden entfernt (drop).',
	'%d item(s) have been affected.' => '%d Artikel betroffen.',
	'Whole result' => 'Gesamtergebnis',
	'Clone' => 'Klonen',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Die maximal erlaubte Anzahl der Felder ist überschritten. Bitte %s erhöhen.',
	'Partition by' => 'Partitionieren um',
	'Partitions' => 'Partitionen',
	'Partition name' => 'Name der Partition',
	'Values' => 'Werte',
	'%d row(s) have been imported.' => array('%d Datensatz wurde importiert.', '%d Datensätze wurden importiert.'),
	'anywhere' => 'beliebig',
	'Import' => 'Importieren',
	'Stop on error' => 'Bei Fehler anhalten',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$6.$4.$1',
	'[yyyy]-mm-dd' => 't.m.[jjjj]',
	'History' => 'History',
	'Variables' => 'Variablen',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Quell- und Zielspalten müssen vom gleichen Datentyp sein, es muss unter den Zielspalten ein Index existieren und die referenzierten Daten müssen existieren.',
	'Relations' => 'Relationen',
	'Run file' => 'Datei ausführen',
	'Clear' => 'Löschen',
	'Maximum allowed file size is %sB.' => 'Maximal erlaubte Dateigröße ist %sB.',
	'Numbers' => 'Zahlen',
	'Date and time' => 'Datum und Zeit',
	'Strings' => 'Zeichenketten',
	'Binary' => 'Binär',
	'Lists' => 'Listen',
	'Editor' => 'Editor',
	'Webserver file %s' => 'Webserver Datei %s',
	'File does not exist.' => 'Datei existiert nicht.',
	'%d in total' => '%d insgesamt',
	'Permanent login' => 'Passwort speichern',
	'Databases have been dropped.' => 'Datenbanken wurden entfernt.',
	'Search data in tables' => 'Suche in Tabellen',
	'Schema' => 'Schema',
	'Alter schema' => 'Schema ändern',
	'Create schema' => 'Schema erstellen',
	'Schema has been dropped.' => 'Schema wurde gelöscht.',
	'Schema has been created.' => 'Schema wurde erstellt.',
	'Schema has been altered.' => 'Schema wurde geändert.',
	'Sequences' => 'Sequenzen',
	'Create sequence' => 'Sequenz erstellen',
	'Alter sequence' => 'Sequenz ändern',
	'Sequence has been dropped.' => 'Sequenz wurde gelöscht.',
	'Sequence has been created.' => 'Sequenz wurde erstellt.',
	'Sequence has been altered.' => 'Sequenz wurde geändert.',
	'User types' => 'Benutzerdefinierte Typen',
	'Create type' => 'Typ erstellen',
	'Alter type' => 'Typ ändern',
	'Type has been dropped.' => 'Typ wurde gelöscht.',
	'Type has been created.' => 'Typ wurde erstellt.',
	'Ctrl+click on a value to modify it.' => 'Ctrl+Klick zum Bearbeiten des Wertes.',
	'Use edit link to modify this value.' => 'Benutzen Sie den Link zum Bearbeiten dieses Wertes.',
	'last' => 'letzte',
	'From server' => 'Vom Server',
	'System' => 'Datenbank System',
	'Select data' => 'Daten auswählen',
	'Show structure' => 'Struktur anzeigen',
	'empty' => 'leer',
	'Network' => 'Netzwerk',
	'Geometry' => 'Geometrie',
	'File exists.' => 'Datei existiert schon.',
	'%d query(s) executed OK.' => array('SQL-Abfrage erfolgreich ausgeführt.', '%d SQL-Abfragen erfolgreich ausgeführt.'),
	'Show only errors' => 'Nur Fehler anzeigen',
	'Refresh' => 'Aktualisieren',
	'Invalid schema.' => 'Schema nicht gültig.',
	'Please use one of the extensions %s.' => 'Bitte einen der Dateitypen %s benutzen.',
	'now' => 'jetzt',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'Tabellen wurden kopiert.',
	'Copy' => 'Kopieren',
	'Permanent link' => 'Dauerhafter Link',
	'Edit all' => 'Alle bearbeiten',
	'HH:MM:SS' => 'HH:MM:SS',
	'Compute' => 'kalkulieren',
	'Size' => 'Größe',
	'Modify' => 'Ändern',
	'Selected' => 'Ausgewählte',
	'Default value' => 'Vorgabewert festlegen',
	'Limit rows' => 'Datensätze begrenzen',
	'Tables have been optimized.' => 'Tabellen wurden optimiert.',
	'File must be in UTF-8 encoding.' => 'Die Datei muss UTF-8 kodiert sein.',
	'Loading' => 'Lade',
	'Load more data' => 'Mehr Daten laden',
	'Too many unsuccessful logins, try again in %d minute(s).' => array('Zu viele erfolglose Login-Versuche. Bitte probieren Sie es in %d Minute noch einmal.', 'Zu viele erfolglose Login-Versuche. Bitte probieren Sie es in %d Minuten noch einmal.'),
	'If you did not send this request from Adminer then close this page.' => 'Wenn Sie diese Anfrage nicht von Adminer gesendet haben, schließen Sie diese Seite.',
	'You can upload a big SQL file via FTP and import it from server.' => 'Sie können eine große SQL-Datei per FTP hochladen und dann vom Server importieren.',
	'You are offline.' => 'Sie sind offline.',
	'You have no privileges to update this table.' => 'Sie haben keine Rechte, diese Tabelle zu aktualisieren.',
	'Saving' => 'Speichere',
	'yes' => 'ja',
	'no' => 'nein',
	'Master password expired. <a href="https://www.adminer.org/en/extension/"%s>Implement</a> %s method to make it permanent.' => 'Das Master-Passwort ist abgelaufen. <a href="https://www.adminer.org/de/extension/"%s>Implementieren</a> Sie die %s Methode, um es permanent zu machen.',
	'%d / ' => '%d / ',
	'Drop %s?' => '%s entfernen?',
	'Materialized view' => 'Strukturierte Ansicht',
	'Vacuum' => 'Vacuum',
	'overwrite' => 'überschreiben',
	'DB' => 'DB',
	'ATTACH queries are not supported.' => 'ATTACH Abfragen werden nicht unterstützt.',
	'Warnings' => 'Warnungen',
	'Adminer does not support accessing a database without a password, <a href="https://www.adminer.org/en/password/"%s>more information</a>.' => 'Adminer unterstützt den Zugriff auf eine Datenbank ohne Passwort nicht, <a href="https://www.adminer.org/de/password/"%s>mehr Informationen</a>.',
	'Full table scan' => 'Vollständige Überprüfung der Tabelle',
	'The action will be performed after successful login with the same credentials.' => 'Die Aktion wird nach erfolgreicher Anmeldung mit denselben Anmeldedaten ausgeführt.',
	'Connecting to privileged ports is not allowed.' => 'Die Verbindung zu privilegierten Ports ist nicht erlaubt.',
	'There is a space in the input password which might be the cause.' => 'Es gibt ein Leerzeichen im Eingabepasswort, das die Ursache sein könnte.',
	'Unknown error.' => 'Unbekannter Fehler.',
	'Database does not support password.' => 'Die Datenbank unterstützt kein Passwort.',
	'Disable %s or enable %s or %s extensions.' => 'Deaktivieren Sie %s oder aktivieren Sie die Erweiterungen %s oder %s.',
	'Check has been dropped.' => 'Check wurde abgebrochen.',
	'Check has been altered.' => 'Check wurde geändert.',
	'Check has been created.' => 'Check wurde erstellt.',
	'Alter check' => 'Check ändern',
	'Create check' => 'Check erstellen',
	'Checks' => 'Checks',
	'Loaded plugins' => 'Geladene Plugins',
	'%s must <a%s>return an array</a>.' => '%s muss <a%s>ein Array zurückgeben</a>.',
	'<a%s>Configure</a> %s in %s.' => '<a%s>Konfigure</a> %s mit %s.',
	'screenshot' => 'Screenshot',
);

// run `php ../../lang.php de` to update this file
